
using namespace System.Management.Automation
using namespace System.Management.Automation.Language

Register-ArgumentCompleter -Native -CommandName 'rc' -ScriptBlock {
    param($wordToComplete, $commandAst, $cursorPosition)

    $commandElements = $commandAst.CommandElements
    $command = @(
        'rc'
        for ($i = 1; $i -lt $commandElements.Count; $i++) {
            $element = $commandElements[$i]
            if ($element -isnot [StringConstantExpressionAst] -or
                $element.StringConstantType -ne [StringConstantType]::BareWord -or
                $element.Value.StartsWith('-') -or
                $element.Value -eq $wordToComplete) {
                break
        }
        $element.Value
    }) -join ';'

    $completions = @(switch ($command) {
        'rc' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('alias', 'alias', [CompletionResultType]::ParameterValue, 'Manage storage service aliases')
            [CompletionResult]::new('admin', 'admin', [CompletionResultType]::ParameterValue, 'Manage IAM users, policies, groups, and service accounts')
            [CompletionResult]::new('bucket', 'bucket', [CompletionResultType]::ParameterValue, 'Manage bucket-oriented workflows')
            [CompletionResult]::new('object', 'object', [CompletionResultType]::ParameterValue, 'Manage object-oriented workflows')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket list` or `rc object list`')
            [CompletionResult]::new('mb', 'mb', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket create`')
            [CompletionResult]::new('rb', 'rb', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket remove`')
            [CompletionResult]::new('cat', 'cat', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object show`')
            [CompletionResult]::new('head', 'head', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object head`')
            [CompletionResult]::new('stat', 'stat', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object stat`')
            [CompletionResult]::new('cp', 'cp', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object copy`')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Download one remote object to the local filesystem')
            [CompletionResult]::new('put', 'put', [CompletionResultType]::ParameterValue, 'Upload one or more local paths to remote object storage')
            [CompletionResult]::new('mv', 'mv', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object move`')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object remove`')
            [CompletionResult]::new('undo', 'undo', [CompletionResultType]::ParameterValue, 'Restore a versioned PUT or DELETE operation without removing data history')
            [CompletionResult]::new('pipe', 'pipe', [CompletionResultType]::ParameterValue, 'Stream stdin to an object')
            [CompletionResult]::new('find', 'find', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object find`')
            [CompletionResult]::new('event', 'event', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket event`')
            [CompletionResult]::new('cors', 'cors', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket cors`')
            [CompletionResult]::new('diff', 'diff', [CompletionResultType]::ParameterValue, 'Show differences between locations')
            [CompletionResult]::new('mirror', 'mirror', [CompletionResultType]::ParameterValue, 'Mirror objects between locations')
            [CompletionResult]::new('tree', 'tree', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object tree`')
            [CompletionResult]::new('share', 'share', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object share`')
            [CompletionResult]::new('sql', 'sql', [CompletionResultType]::ParameterValue, 'Run S3 Select SQL on an object')
            [CompletionResult]::new('version', 'version', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket version`')
            [CompletionResult]::new('tag', 'tag', [CompletionResultType]::ParameterValue, 'Manage bucket and object tags')
            [CompletionResult]::new('anonymous', 'anonymous', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket anonymous`')
            [CompletionResult]::new('quota', 'quota', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket quota`')
            [CompletionResult]::new('ilm', 'ilm', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket lifecycle`')
            [CompletionResult]::new('replicate', 'replicate', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket replication`')
            [CompletionResult]::new('retention', 'retention', [CompletionResultType]::ParameterValue, 'Manage object retention with mc-compatible command syntax')
            [CompletionResult]::new('legalhold', 'legalhold', [CompletionResultType]::ParameterValue, 'Manage object legal hold with mc-compatible command syntax')
            [CompletionResult]::new('completions', 'completions', [CompletionResultType]::ParameterValue, 'Generate shell completion scripts')
            [CompletionResult]::new('du', 'du', [CompletionResultType]::ParameterValue, 'Summarize storage usage')
            [CompletionResult]::new('ping', 'ping', [CompletionResultType]::ParameterValue, 'Check service liveness and round-trip latency')
            [CompletionResult]::new('ready', 'ready', [CompletionResultType]::ParameterValue, 'Check whether required dependencies are ready')
            [CompletionResult]::new('watch', 'watch', [CompletionResultType]::ParameterValue, 'Stream live object notifications')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;alias' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Add or update an alias')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List all configured aliases')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove an alias')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export aliases as a portable JSON document')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import aliases from a portable JSON document')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;alias;set' {
            [CompletionResult]::new('--client-cert', '--client-cert', [CompletionResultType]::ParameterName, 'Path to PEM client certificate for mTLS')
            [CompletionResult]::new('--client-key', '--client-key', [CompletionResultType]::ParameterName, 'Path to PEM client private key for mTLS')
            [CompletionResult]::new('--region', '--region', [CompletionResultType]::ParameterName, 'AWS region (default: us-east-1)')
            [CompletionResult]::new('--signature', '--signature', [CompletionResultType]::ParameterName, 'Signature version (only v4 is currently supported)')
            [CompletionResult]::new('--bucket-lookup', '--bucket-lookup', [CompletionResultType]::ParameterName, 'Bucket lookup style: auto, path, or dns (default: auto)')
            [CompletionResult]::new('--ca-bundle', '--ca-bundle', [CompletionResultType]::ParameterName, 'Path to a PEM CA bundle used to verify the endpoint certificate')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--anonymous', '--anonymous', [CompletionResultType]::ParameterName, 'Send requests without SigV4 credentials')
            [CompletionResult]::new('--insecure', '--insecure', [CompletionResultType]::ParameterName, 'Allow insecure TLS connections')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;alias;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-l', '-l', [CompletionResultType]::ParameterName, 'Show full details including endpoints')
            [CompletionResult]::new('--long', '--long', [CompletionResultType]::ParameterName, 'Show full details including endpoints')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;alias;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;alias;export' {
            [CompletionResult]::new('-o', '-o', [CompletionResultType]::ParameterName, 'Write the export to a file instead of stdout')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write the export to a file instead of stdout')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--include-credentials', '--include-credentials', [CompletionResultType]::ParameterName, 'Include access keys and secret keys in the export')
            [CompletionResult]::new('--acknowledge-credentials', '--acknowledge-credentials', [CompletionResultType]::ParameterName, 'Acknowledge that the exported document contains plaintext credentials')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Replace an existing output file')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;alias;import' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--replace', '--replace', [CompletionResultType]::ParameterName, 'Replace aliases with conflicting names')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;alias;help' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Add or update an alias')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List all configured aliases')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove an alias')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export aliases as a portable JSON document')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import aliases from a portable JSON document')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;alias;help;set' {
            break
        }
        'rc;alias;help;list' {
            break
        }
        'rc;alias;help;remove' {
            break
        }
        'rc;alias;help;export' {
            break
        }
        'rc;alias;help;import' {
            break
        }
        'rc;alias;help;help' {
            break
        }
        'rc;admin' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('capabilities', 'capabilities', [CompletionResultType]::ParameterValue, 'Discover effective RustFS runtime capabilities')
            [CompletionResult]::new('diagnostics', 'diagnostics', [CompletionResultType]::ParameterValue, 'Read bounded snapshots or run explicitly confirmed RustFS diagnostic probes')
            [CompletionResult]::new('config', 'config', [CompletionResultType]::ParameterValue, 'Manage RustFS server configuration')
            [CompletionResult]::new('metrics', 'metrics', [CompletionResultType]::ParameterValue, 'Query bounded RustFS realtime metrics')
            [CompletionResult]::new('kms', 'kms', [CompletionResultType]::ParameterValue, 'Inspect KMS state and manage key lifecycle operations')
            [CompletionResult]::new('scanner', 'scanner', [CompletionResultType]::ParameterValue, 'Inspect scanner health and freshness')
            [CompletionResult]::new('ilm', 'ilm', [CompletionResultType]::ParameterValue, 'Manage lifecycle transition operations')
            [CompletionResult]::new('idp', 'idp', [CompletionResultType]::ParameterValue, 'Inspect, validate, and manage identity-provider configuration')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Display cluster information (servers, disks, usage)')
            [CompletionResult]::new('heal', 'heal', [CompletionResultType]::ParameterValue, 'Manage cluster healing operations')
            [CompletionResult]::new('pool', 'pool', [CompletionResultType]::ParameterValue, 'Manage server pools and expansion status')
            [CompletionResult]::new('expand', 'expand', [CompletionResultType]::ParameterValue, 'Manage post-expansion data rebalancing')
            [CompletionResult]::new('decommission', 'decommission', [CompletionResultType]::ParameterValue, 'Manage server pool decommissioning')
            [CompletionResult]::new('rebalance', 'rebalance', [CompletionResultType]::ParameterValue, 'Manage post-expansion rebalancing')
            [CompletionResult]::new('user', 'user', [CompletionResultType]::ParameterValue, 'Manage IAM users')
            [CompletionResult]::new('policy', 'policy', [CompletionResultType]::ParameterValue, 'Manage IAM policies')
            [CompletionResult]::new('group', 'group', [CompletionResultType]::ParameterValue, 'Manage IAM groups')
            [CompletionResult]::new('service-account', 'service-account', [CompletionResultType]::ParameterValue, 'Manage service accounts')
            [CompletionResult]::new('access-key', 'access-key', [CompletionResultType]::ParameterValue, 'Inspect access key identities')
            [CompletionResult]::new('bucket-metadata', 'bucket-metadata', [CompletionResultType]::ParameterValue, 'Export or import validated per-bucket metadata archives')
            [CompletionResult]::new('iam', 'iam', [CompletionResultType]::ParameterValue, 'Export or import versioned IAM archives')
            [CompletionResult]::new('service', 'service', [CompletionResultType]::ParameterValue, 'Control the server process (restart, stop, freeze, unfreeze)')
            [CompletionResult]::new('replicate', 'replicate', [CompletionResultType]::ParameterValue, 'Manage site replication across clusters')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;capabilities' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--refresh', '--refresh', [CompletionResultType]::ParameterName, 'Bypass the in-process capability cache')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;diagnostics' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('health', 'health', [CompletionResultType]::ParameterValue, 'Display authenticated host, process, and drive health observations')
            [CompletionResult]::new('cluster', 'cluster', [CompletionResultType]::ParameterValue, 'Display the read-only RustFS cluster snapshot')
            [CompletionResult]::new('extensions', 'extensions', [CompletionResultType]::ParameterValue, 'Display extension schemas and runtime capability summaries')
            [CompletionResult]::new('client-devnull', 'client-devnull', [CompletionResultType]::ParameterValue, 'Measure bounded client-to-server upload throughput without storing data')
            [CompletionResult]::new('inspect-archive', 'inspect-archive', [CompletionResultType]::ParameterValue, 'Retrieve and verify an encrypted drive-metadata archive')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;diagnostics;health' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;diagnostics;cluster' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;diagnostics;extensions' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;diagnostics;client-devnull' {
            [CompletionResult]::new('--size', '--size', [CompletionResultType]::ParameterName, 'Bytes uploaded by each request (for example 8MiB)')
            [CompletionResult]::new('--timeout', '--timeout', [CompletionResultType]::ParameterName, 'Active probe timeout in whole seconds (for example 30s)')
            [CompletionResult]::new('--concurrency', '--concurrency', [CompletionResultType]::ParameterName, 'Number of concurrent upload requests (1 through 4)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm generation of deliberate network load')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;diagnostics;inspect-archive' {
            [CompletionResult]::new('-o', '-o', [CompletionResultType]::ParameterName, 'Destination for the verified plaintext tar archive')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Destination for the verified plaintext tar archive')
            [CompletionResult]::new('--private-key', '--private-key', [CompletionResultType]::ParameterName, 'Read a caller-managed PKCS#8 RSA private key from a protected file')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;diagnostics;help' {
            [CompletionResult]::new('health', 'health', [CompletionResultType]::ParameterValue, 'Display authenticated host, process, and drive health observations')
            [CompletionResult]::new('cluster', 'cluster', [CompletionResultType]::ParameterValue, 'Display the read-only RustFS cluster snapshot')
            [CompletionResult]::new('extensions', 'extensions', [CompletionResultType]::ParameterValue, 'Display extension schemas and runtime capability summaries')
            [CompletionResult]::new('client-devnull', 'client-devnull', [CompletionResultType]::ParameterValue, 'Measure bounded client-to-server upload throughput without storing data')
            [CompletionResult]::new('inspect-archive', 'inspect-archive', [CompletionResultType]::ParameterValue, 'Retrieve and verify an encrypted drive-metadata archive')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;diagnostics;help;health' {
            break
        }
        'rc;admin;diagnostics;help;cluster' {
            break
        }
        'rc;admin;diagnostics;help;extensions' {
            break
        }
        'rc;admin;diagnostics;help;client-devnull' {
            break
        }
        'rc;admin;diagnostics;help;inspect-archive' {
            break
        }
        'rc;admin;diagnostics;help;help' {
            break
        }
        'rc;admin;config' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Read a subsystem or target configuration')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set one or more keys after showing a preflight diff')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Delete a target or selected keys after showing a preflight diff')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Show server-provided configuration help')
            [CompletionResult]::new('history', 'history', [CompletionResultType]::ParameterValue, 'List configuration mutation history')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Replace configuration from a history entry')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export the full server configuration to a file')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Replace the full server configuration from a file')
            [CompletionResult]::new('module-switch', 'module-switch', [CompletionResultType]::ParameterValue, 'Inspect or update event notification and audit module switches')
            break
        }
        'rc;admin;config;get' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;config;set' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'dry-run')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;config;delete' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'dry-run')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;config;help' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--env', '--env', [CompletionResultType]::ParameterName, 'env')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;config;history' {
            [CompletionResult]::new('--count', '--count', [CompletionResultType]::ParameterName, 'count')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;config;restore' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'dry-run')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm replacement of the complete server configuration')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;config;export' {
            [CompletionResult]::new('--file', '--file', [CompletionResultType]::ParameterName, 'file')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;config;import' {
            [CompletionResult]::new('--file', '--file', [CompletionResultType]::ParameterName, 'file')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'dry-run')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm replacement of the complete server configuration')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;config;module-switch' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'get')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'set')
            break
        }
        'rc;admin;config;module-switch;get' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;config;module-switch;set' {
            [CompletionResult]::new('--notify', '--notify', [CompletionResultType]::ParameterName, 'notify')
            [CompletionResult]::new('--audit', '--audit', [CompletionResultType]::ParameterName, 'audit')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'dry-run')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;metrics' {
            [CompletionResult]::new('--scope', '--scope', [CompletionResultType]::ParameterName, 'Comma-separated metric scopes: scanner,disk,os,batch-jobs,site-resync,network,memory,cpu,rpc,all')
            [CompletionResult]::new('--samples', '--samples', [CompletionResultType]::ParameterName, 'Number of snapshots to request')
            [CompletionResult]::new('--interval', '--interval', [CompletionResultType]::ParameterName, 'Interval between snapshots, such as 3s')
            [CompletionResult]::new('--host', '--host', [CompletionResultType]::ParameterName, 'Limit metrics to a host; may be repeated')
            [CompletionResult]::new('--disk', '--disk', [CompletionResultType]::ParameterName, 'Limit metrics to a disk path; may be repeated')
            [CompletionResult]::new('--job-id', '--job-id', [CompletionResultType]::ParameterName, 'Limit batch metrics to a job ID')
            [CompletionResult]::new('--deployment-id', '--deployment-id', [CompletionResultType]::ParameterName, 'Limit site metrics to a deployment ID')
            [CompletionResult]::new('--metrics-format', '--metrics-format', [CompletionResultType]::ParameterName, 'Select normalized v3 JSON Lines or bounded raw server records')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--by-host', '--by-host', [CompletionResultType]::ParameterName, 'Include metrics grouped by host')
            [CompletionResult]::new('--by-disk', '--by-disk', [CompletionResultType]::ParameterName, 'Include metrics grouped by disk')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;kms' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display KMS service health and non-secret configuration summary')
            [CompletionResult]::new('key', 'key', [CompletionResultType]::ParameterValue, 'Inspect KMS keys')
            [CompletionResult]::new('configure', 'configure', [CompletionResultType]::ParameterValue, 'Configure KMS from a protected JSON file or standard input')
            [CompletionResult]::new('reconfigure', 'reconfigure', [CompletionResultType]::ParameterValue, 'Replace KMS configuration from a protected JSON file or standard input')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start the configured KMS service')
            [CompletionResult]::new('restart', 'restart', [CompletionResultType]::ParameterValue, 'Restart the KMS service after explicit confirmation')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop the KMS service after explicit confirmation')
            [CompletionResult]::new('roundtrip', 'roundtrip', [CompletionResultType]::ParameterValue, 'Verify SSE-KMS write and read behavior with a temporary object')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;kms;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;kms;key' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List KMS keys')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display key lifecycle status; defaults to the configured KMS key')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a KMS key without exporting key material')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Schedule or immediately delete a KMS key')
            [CompletionResult]::new('cancel-deletion', 'cancel-deletion', [CompletionResultType]::ParameterValue, 'Cancel a scheduled KMS key deletion')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;kms;key;list' {
            [CompletionResult]::new('--limit', '--limit', [CompletionResultType]::ParameterName, 'Maximum number of keys to return')
            [CompletionResult]::new('--marker', '--marker', [CompletionResultType]::ParameterName, 'Pagination marker returned by a previous request')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;kms;key;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;kms;key;create' {
            [CompletionResult]::new('--name', '--name', [CompletionResultType]::ParameterName, 'Optional friendly key name stored in the reserved name tag')
            [CompletionResult]::new('--description', '--description', [CompletionResultType]::ParameterName, 'Optional key description')
            [CompletionResult]::new('--tag', '--tag', [CompletionResultType]::ParameterName, 'Key metadata tag in KEY=VALUE form; may be repeated')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;kms;key;delete' {
            [CompletionResult]::new('--pending-window-days', '--pending-window-days', [CompletionResultType]::ParameterName, 'Number of days before deletion; defaults to 7')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--immediate', '--immediate', [CompletionResultType]::ParameterName, 'Delete immediately instead of scheduling deletion')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm deletion without an interactive prompt')
            [CompletionResult]::new('--confirm-immediate', '--confirm-immediate', [CompletionResultType]::ParameterName, 'Acknowledge that immediate deletion cannot be cancelled')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;kms;key;cancel-deletion' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;kms;key;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List KMS keys')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display key lifecycle status; defaults to the configured KMS key')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a KMS key without exporting key material')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Schedule or immediately delete a KMS key')
            [CompletionResult]::new('cancel-deletion', 'cancel-deletion', [CompletionResultType]::ParameterValue, 'Cancel a scheduled KMS key deletion')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;kms;key;help;list' {
            break
        }
        'rc;admin;kms;key;help;status' {
            break
        }
        'rc;admin;kms;key;help;create' {
            break
        }
        'rc;admin;kms;key;help;delete' {
            break
        }
        'rc;admin;kms;key;help;cancel-deletion' {
            break
        }
        'rc;admin;kms;key;help;help' {
            break
        }
        'rc;admin;kms;configure' {
            [CompletionResult]::new('--config-file', '--config-file', [CompletionResultType]::ParameterName, 'Read the configuration from this protected regular file')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--stdin', '--stdin', [CompletionResultType]::ParameterName, 'Read the configuration from standard input')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;kms;reconfigure' {
            [CompletionResult]::new('--config-file', '--config-file', [CompletionResultType]::ParameterName, 'Read the configuration from this protected regular file')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--stdin', '--stdin', [CompletionResultType]::ParameterName, 'Read the configuration from standard input')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;kms;start' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;kms;restart' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm the disruptive service operation')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;kms;stop' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm the disruptive service operation')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;kms;roundtrip' {
            [CompletionResult]::new('--key-id', '--key-id', [CompletionResultType]::ParameterName, 'KMS key identifier; when omitted, use the configured default key')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm the temporary encrypted object mutation')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;kms;help' {
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display KMS service health and non-secret configuration summary')
            [CompletionResult]::new('key', 'key', [CompletionResultType]::ParameterValue, 'Inspect KMS keys')
            [CompletionResult]::new('configure', 'configure', [CompletionResultType]::ParameterValue, 'Configure KMS from a protected JSON file or standard input')
            [CompletionResult]::new('reconfigure', 'reconfigure', [CompletionResultType]::ParameterValue, 'Replace KMS configuration from a protected JSON file or standard input')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start the configured KMS service')
            [CompletionResult]::new('restart', 'restart', [CompletionResultType]::ParameterValue, 'Restart the KMS service after explicit confirmation')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop the KMS service after explicit confirmation')
            [CompletionResult]::new('roundtrip', 'roundtrip', [CompletionResultType]::ParameterValue, 'Verify SSE-KMS write and read behavior with a temporary object')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;kms;help;status' {
            break
        }
        'rc;admin;kms;help;key' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List KMS keys')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display key lifecycle status; defaults to the configured KMS key')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a KMS key without exporting key material')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Schedule or immediately delete a KMS key')
            [CompletionResult]::new('cancel-deletion', 'cancel-deletion', [CompletionResultType]::ParameterValue, 'Cancel a scheduled KMS key deletion')
            break
        }
        'rc;admin;kms;help;key;list' {
            break
        }
        'rc;admin;kms;help;key;status' {
            break
        }
        'rc;admin;kms;help;key;create' {
            break
        }
        'rc;admin;kms;help;key;delete' {
            break
        }
        'rc;admin;kms;help;key;cancel-deletion' {
            break
        }
        'rc;admin;kms;help;configure' {
            break
        }
        'rc;admin;kms;help;reconfigure' {
            break
        }
        'rc;admin;kms;help;start' {
            break
        }
        'rc;admin;kms;help;restart' {
            break
        }
        'rc;admin;kms;help;stop' {
            break
        }
        'rc;admin;kms;help;roundtrip' {
            break
        }
        'rc;admin;kms;help;help' {
            break
        }
        'rc;admin;scanner' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display scanner health, freshness, and current cycle details')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;scanner;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;scanner;help' {
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display scanner health, freshness, and current cycle details')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;scanner;help;status' {
            break
        }
        'rc;admin;scanner;help;help' {
            break
        }
        'rc;admin;ilm' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('transition', 'transition', [CompletionResultType]::ParameterValue, 'Manage lifecycle transition operations')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;ilm;transition' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('run', 'run', [CompletionResultType]::ParameterValue, 'Run bounded lifecycle transition evaluation for existing objects')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show durable lifecycle transition job status')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Request cancellation for a durable lifecycle transition job')
            [CompletionResult]::new('wait', 'wait', [CompletionResultType]::ParameterValue, 'Wait until a durable lifecycle transition job reaches a terminal state')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;ilm;transition;run' {
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Limit evaluation to this object key prefix')
            [CompletionResult]::new('--tier', '--tier', [CompletionResultType]::ParameterName, 'Limit evaluation to lifecycle transitions targeting this storage tier')
            [CompletionResult]::new('--max-objects', '--max-objects', [CompletionResultType]::ParameterName, 'Maximum number of object versions to scan')
            [CompletionResult]::new('--max-duration-seconds', '--max-duration-seconds', [CompletionResultType]::ParameterName, 'Best-effort seconds budget checked between listed object versions')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Report eligible objects without enqueueing transition tasks')
            [CompletionResult]::new('--async', '--async', [CompletionResultType]::ParameterName, 'Start a durable background job and return its job endpoints')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;ilm;transition;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;ilm;transition;cancel' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;ilm;transition;wait' {
            [CompletionResult]::new('--poll-interval-seconds', '--poll-interval-seconds', [CompletionResultType]::ParameterName, 'Seconds between status polls')
            [CompletionResult]::new('--timeout-seconds', '--timeout-seconds', [CompletionResultType]::ParameterName, 'Maximum seconds to wait before returning an error')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;ilm;transition;help' {
            [CompletionResult]::new('run', 'run', [CompletionResultType]::ParameterValue, 'Run bounded lifecycle transition evaluation for existing objects')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show durable lifecycle transition job status')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Request cancellation for a durable lifecycle transition job')
            [CompletionResult]::new('wait', 'wait', [CompletionResultType]::ParameterValue, 'Wait until a durable lifecycle transition job reaches a terminal state')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;ilm;transition;help;run' {
            break
        }
        'rc;admin;ilm;transition;help;status' {
            break
        }
        'rc;admin;ilm;transition;help;cancel' {
            break
        }
        'rc;admin;ilm;transition;help;wait' {
            break
        }
        'rc;admin;ilm;transition;help;help' {
            break
        }
        'rc;admin;ilm;help' {
            [CompletionResult]::new('transition', 'transition', [CompletionResultType]::ParameterValue, 'Manage lifecycle transition operations')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;ilm;help;transition' {
            [CompletionResult]::new('run', 'run', [CompletionResultType]::ParameterValue, 'Run bounded lifecycle transition evaluation for existing objects')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show durable lifecycle transition job status')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Request cancellation for a durable lifecycle transition job')
            [CompletionResult]::new('wait', 'wait', [CompletionResultType]::ParameterValue, 'Wait until a durable lifecycle transition job reaches a terminal state')
            break
        }
        'rc;admin;ilm;help;transition;run' {
            break
        }
        'rc;admin;ilm;help;transition;status' {
            break
        }
        'rc;admin;ilm;help;transition;cancel' {
            break
        }
        'rc;admin;ilm;help;transition;wait' {
            break
        }
        'rc;admin;ilm;help;help' {
            break
        }
        'rc;admin;idp' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('openid', 'openid', [CompletionResultType]::ParameterValue, 'Inspect and validate OpenID Connect providers')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;idp;openid' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List effective OIDC provider configurations')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Display one effective OIDC provider configuration')
            [CompletionResult]::new('validate', 'validate', [CompletionResultType]::ParameterValue, 'Validate OIDC discovery without saving configuration')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Create or replace an OIDC provider while preserving omitted fields')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing OIDC provider while preserving omitted fields')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable an existing OIDC provider')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable an existing OIDC provider')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Delete an editable OIDC provider after explicit confirmation')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;idp;openid;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;idp;openid;get' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;idp;openid;validate' {
            [CompletionResult]::new('--config-url', '--config-url', [CompletionResultType]::ParameterName, 'Provider issuer or discovery base URL')
            [CompletionResult]::new('--client-id', '--client-id', [CompletionResultType]::ParameterName, 'OIDC client identifier')
            [CompletionResult]::new('--issuer', '--issuer', [CompletionResultType]::ParameterName, 'Expected issuer URL, when it must differ from the configuration URL')
            [CompletionResult]::new('--scope', '--scope', [CompletionResultType]::ParameterName, 'Requested scope; may be repeated and must include openid')
            [CompletionResult]::new('--other-audience', '--other-audience', [CompletionResultType]::ParameterName, 'Additional trusted token audience; may be repeated')
            [CompletionResult]::new('--redirect-uri', '--redirect-uri', [CompletionResultType]::ParameterName, 'Explicit callback URI')
            [CompletionResult]::new('--claim-name', '--claim-name', [CompletionResultType]::ParameterName, 'Policy claim name')
            [CompletionResult]::new('--claim-prefix', '--claim-prefix', [CompletionResultType]::ParameterName, 'Prefix applied to policy claims')
            [CompletionResult]::new('--role-policy', '--role-policy', [CompletionResultType]::ParameterName, 'Fixed fallback policy')
            [CompletionResult]::new('--groups-claim', '--groups-claim', [CompletionResultType]::ParameterName, 'Group claim name')
            [CompletionResult]::new('--roles-claim', '--roles-claim', [CompletionResultType]::ParameterName, 'Roles claim name')
            [CompletionResult]::new('--email-claim', '--email-claim', [CompletionResultType]::ParameterName, 'Email claim name')
            [CompletionResult]::new('--username-claim', '--username-claim', [CompletionResultType]::ParameterName, 'Username claim name')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--static-redirect', '--static-redirect', [CompletionResultType]::ParameterName, 'Require the explicit callback URI instead of a server-derived URI')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;idp;openid;set' {
            [CompletionResult]::new('--config-url', '--config-url', [CompletionResultType]::ParameterName, 'Provider issuer or discovery base URL')
            [CompletionResult]::new('--client-id', '--client-id', [CompletionResultType]::ParameterName, 'OIDC client identifier')
            [CompletionResult]::new('--display-name', '--display-name', [CompletionResultType]::ParameterName, 'Human-readable provider name')
            [CompletionResult]::new('--issuer', '--issuer', [CompletionResultType]::ParameterName, 'Expected issuer URL')
            [CompletionResult]::new('--scope', '--scope', [CompletionResultType]::ParameterName, 'Requested scope; may be repeated and must include openid')
            [CompletionResult]::new('--other-audience', '--other-audience', [CompletionResultType]::ParameterName, 'Additional trusted token audience; may be repeated')
            [CompletionResult]::new('--redirect-uri', '--redirect-uri', [CompletionResultType]::ParameterName, 'Explicit callback URI')
            [CompletionResult]::new('--claim-name', '--claim-name', [CompletionResultType]::ParameterName, 'Policy claim name')
            [CompletionResult]::new('--claim-prefix', '--claim-prefix', [CompletionResultType]::ParameterName, 'Prefix applied to policy claims')
            [CompletionResult]::new('--role-policy', '--role-policy', [CompletionResultType]::ParameterName, 'Fixed fallback policy')
            [CompletionResult]::new('--groups-claim', '--groups-claim', [CompletionResultType]::ParameterName, 'Group claim name')
            [CompletionResult]::new('--roles-claim', '--roles-claim', [CompletionResultType]::ParameterName, 'Roles claim name')
            [CompletionResult]::new('--email-claim', '--email-claim', [CompletionResultType]::ParameterName, 'Email claim name')
            [CompletionResult]::new('--username-claim', '--username-claim', [CompletionResultType]::ParameterName, 'Username claim name')
            [CompletionResult]::new('--client-secret-file', '--client-secret-file', [CompletionResultType]::ParameterName, 'Read a replacement client secret from a protected regular file')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--clear-issuer', '--clear-issuer', [CompletionResultType]::ParameterName, 'Remove an existing explicit issuer')
            [CompletionResult]::new('--replace-other-audiences', '--replace-other-audiences', [CompletionResultType]::ParameterName, 'Replace all additional trusted token audiences, including with an empty list')
            [CompletionResult]::new('--clear-redirect-uri', '--clear-redirect-uri', [CompletionResultType]::ParameterName, 'Remove an existing explicit callback URI')
            [CompletionResult]::new('--static-redirect', '--static-redirect', [CompletionResultType]::ParameterName, 'Require the explicit callback URI instead of a server-derived URI')
            [CompletionResult]::new('--dynamic-redirect', '--dynamic-redirect', [CompletionResultType]::ParameterName, 'Use a server-derived callback URI')
            [CompletionResult]::new('--hide-from-ui', '--hide-from-ui', [CompletionResultType]::ParameterName, 'Hide this provider from the login UI')
            [CompletionResult]::new('--show-in-ui', '--show-in-ui', [CompletionResultType]::ParameterName, 'Show this provider in the login UI')
            [CompletionResult]::new('--client-secret-stdin', '--client-secret-stdin', [CompletionResultType]::ParameterName, 'Read a replacement client secret from standard input')
            [CompletionResult]::new('--replace-client-secret', '--replace-client-secret', [CompletionResultType]::ParameterName, 'Acknowledge that the currently persisted client secret will be replaced')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Validate and display the redacted change plan without saving')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;idp;openid;update' {
            [CompletionResult]::new('--config-url', '--config-url', [CompletionResultType]::ParameterName, 'Provider issuer or discovery base URL')
            [CompletionResult]::new('--client-id', '--client-id', [CompletionResultType]::ParameterName, 'OIDC client identifier')
            [CompletionResult]::new('--display-name', '--display-name', [CompletionResultType]::ParameterName, 'Human-readable provider name')
            [CompletionResult]::new('--issuer', '--issuer', [CompletionResultType]::ParameterName, 'Expected issuer URL')
            [CompletionResult]::new('--scope', '--scope', [CompletionResultType]::ParameterName, 'Requested scope; may be repeated and must include openid')
            [CompletionResult]::new('--other-audience', '--other-audience', [CompletionResultType]::ParameterName, 'Additional trusted token audience; may be repeated')
            [CompletionResult]::new('--redirect-uri', '--redirect-uri', [CompletionResultType]::ParameterName, 'Explicit callback URI')
            [CompletionResult]::new('--claim-name', '--claim-name', [CompletionResultType]::ParameterName, 'Policy claim name')
            [CompletionResult]::new('--claim-prefix', '--claim-prefix', [CompletionResultType]::ParameterName, 'Prefix applied to policy claims')
            [CompletionResult]::new('--role-policy', '--role-policy', [CompletionResultType]::ParameterName, 'Fixed fallback policy')
            [CompletionResult]::new('--groups-claim', '--groups-claim', [CompletionResultType]::ParameterName, 'Group claim name')
            [CompletionResult]::new('--roles-claim', '--roles-claim', [CompletionResultType]::ParameterName, 'Roles claim name')
            [CompletionResult]::new('--email-claim', '--email-claim', [CompletionResultType]::ParameterName, 'Email claim name')
            [CompletionResult]::new('--username-claim', '--username-claim', [CompletionResultType]::ParameterName, 'Username claim name')
            [CompletionResult]::new('--client-secret-file', '--client-secret-file', [CompletionResultType]::ParameterName, 'Read a replacement client secret from a protected regular file')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--clear-issuer', '--clear-issuer', [CompletionResultType]::ParameterName, 'Remove an existing explicit issuer')
            [CompletionResult]::new('--replace-other-audiences', '--replace-other-audiences', [CompletionResultType]::ParameterName, 'Replace all additional trusted token audiences, including with an empty list')
            [CompletionResult]::new('--clear-redirect-uri', '--clear-redirect-uri', [CompletionResultType]::ParameterName, 'Remove an existing explicit callback URI')
            [CompletionResult]::new('--static-redirect', '--static-redirect', [CompletionResultType]::ParameterName, 'Require the explicit callback URI instead of a server-derived URI')
            [CompletionResult]::new('--dynamic-redirect', '--dynamic-redirect', [CompletionResultType]::ParameterName, 'Use a server-derived callback URI')
            [CompletionResult]::new('--hide-from-ui', '--hide-from-ui', [CompletionResultType]::ParameterName, 'Hide this provider from the login UI')
            [CompletionResult]::new('--show-in-ui', '--show-in-ui', [CompletionResultType]::ParameterName, 'Show this provider in the login UI')
            [CompletionResult]::new('--client-secret-stdin', '--client-secret-stdin', [CompletionResultType]::ParameterName, 'Read a replacement client secret from standard input')
            [CompletionResult]::new('--replace-client-secret', '--replace-client-secret', [CompletionResultType]::ParameterName, 'Acknowledge that the currently persisted client secret will be replaced')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Validate and display the redacted change plan without saving')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;idp;openid;enable' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Validate and display the change without saving')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;idp;openid;disable' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Validate and display the change without saving')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;idp;openid;delete' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm deletion without an interactive prompt')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;idp;openid;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List effective OIDC provider configurations')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Display one effective OIDC provider configuration')
            [CompletionResult]::new('validate', 'validate', [CompletionResultType]::ParameterValue, 'Validate OIDC discovery without saving configuration')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Create or replace an OIDC provider while preserving omitted fields')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing OIDC provider while preserving omitted fields')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable an existing OIDC provider')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable an existing OIDC provider')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Delete an editable OIDC provider after explicit confirmation')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;idp;openid;help;list' {
            break
        }
        'rc;admin;idp;openid;help;get' {
            break
        }
        'rc;admin;idp;openid;help;validate' {
            break
        }
        'rc;admin;idp;openid;help;set' {
            break
        }
        'rc;admin;idp;openid;help;update' {
            break
        }
        'rc;admin;idp;openid;help;enable' {
            break
        }
        'rc;admin;idp;openid;help;disable' {
            break
        }
        'rc;admin;idp;openid;help;delete' {
            break
        }
        'rc;admin;idp;openid;help;help' {
            break
        }
        'rc;admin;idp;help' {
            [CompletionResult]::new('openid', 'openid', [CompletionResultType]::ParameterValue, 'Inspect and validate OpenID Connect providers')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;idp;help;openid' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List effective OIDC provider configurations')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Display one effective OIDC provider configuration')
            [CompletionResult]::new('validate', 'validate', [CompletionResultType]::ParameterValue, 'Validate OIDC discovery without saving configuration')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Create or replace an OIDC provider while preserving omitted fields')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing OIDC provider while preserving omitted fields')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable an existing OIDC provider')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable an existing OIDC provider')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Delete an editable OIDC provider after explicit confirmation')
            break
        }
        'rc;admin;idp;help;openid;list' {
            break
        }
        'rc;admin;idp;help;openid;get' {
            break
        }
        'rc;admin;idp;help;openid;validate' {
            break
        }
        'rc;admin;idp;help;openid;set' {
            break
        }
        'rc;admin;idp;help;openid;update' {
            break
        }
        'rc;admin;idp;help;openid;enable' {
            break
        }
        'rc;admin;idp;help;openid;disable' {
            break
        }
        'rc;admin;idp;help;openid;delete' {
            break
        }
        'rc;admin;idp;help;help' {
            break
        }
        'rc;admin;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('cluster', 'cluster', [CompletionResultType]::ParameterValue, 'Display cluster overview information')
            [CompletionResult]::new('server', 'server', [CompletionResultType]::ParameterValue, 'Display server information')
            [CompletionResult]::new('disk', 'disk', [CompletionResultType]::ParameterValue, 'Display disk information')
            [CompletionResult]::new('storage', 'storage', [CompletionResultType]::ParameterValue, 'Display storage topology and capacity information')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;info;cluster' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;info;server' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;info;disk' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--offline', '--offline', [CompletionResultType]::ParameterName, 'Show only offline disks')
            [CompletionResult]::new('--healing', '--healing', [CompletionResultType]::ParameterName, 'Show only healing disks')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;info;storage' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--metrics', '--metrics', [CompletionResultType]::ParameterName, 'Include observed drive metrics from storage information')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;info;help' {
            [CompletionResult]::new('cluster', 'cluster', [CompletionResultType]::ParameterValue, 'Display cluster overview information')
            [CompletionResult]::new('server', 'server', [CompletionResultType]::ParameterValue, 'Display server information')
            [CompletionResult]::new('disk', 'disk', [CompletionResultType]::ParameterValue, 'Display disk information')
            [CompletionResult]::new('storage', 'storage', [CompletionResultType]::ParameterValue, 'Display storage topology and capacity information')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;info;help;cluster' {
            break
        }
        'rc;admin;info;help;server' {
            break
        }
        'rc;admin;info;help;disk' {
            break
        }
        'rc;admin;info;help;storage' {
            break
        }
        'rc;admin;info;help;help' {
            break
        }
        'rc;admin;heal' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display current heal status')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a heal operation')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running heal operation')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;heal;status' {
            [CompletionResult]::new('-b', '-b', [CompletionResultType]::ParameterName, 'Bucket for token-scoped manual heal task status')
            [CompletionResult]::new('--bucket', '--bucket', [CompletionResultType]::ParameterName, 'Bucket for token-scoped manual heal task status')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Object prefix for token-scoped manual heal task status')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Object prefix for token-scoped manual heal task status')
            [CompletionResult]::new('--client-token', '--client-token', [CompletionResultType]::ParameterName, 'Client token returned by heal start')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;heal;start' {
            [CompletionResult]::new('-b', '-b', [CompletionResultType]::ParameterName, 'Bucket to heal; omit to recursively heal all buckets')
            [CompletionResult]::new('--bucket', '--bucket', [CompletionResultType]::ParameterName, 'Bucket to heal; omit to recursively heal all buckets')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Object prefix to heal')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Object prefix to heal')
            [CompletionResult]::new('--scan-mode', '--scan-mode', [CompletionResultType]::ParameterName, 'Scan mode (normal or deep)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--remove', '--remove', [CompletionResultType]::ParameterName, 'Remove dangling objects/parts')
            [CompletionResult]::new('--recreate', '--recreate', [CompletionResultType]::ParameterName, 'Recreate missing data')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Dry run mode - show what would be healed without actually healing')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;heal;stop' {
            [CompletionResult]::new('-b', '-b', [CompletionResultType]::ParameterName, 'Bucket for token-scoped manual heal task stop')
            [CompletionResult]::new('--bucket', '--bucket', [CompletionResultType]::ParameterName, 'Bucket for token-scoped manual heal task stop')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Object prefix for token-scoped manual heal task stop')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Object prefix for token-scoped manual heal task stop')
            [CompletionResult]::new('--client-token', '--client-token', [CompletionResultType]::ParameterName, 'Client token returned by heal start')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;heal;help' {
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display current heal status')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a heal operation')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running heal operation')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;heal;help;status' {
            break
        }
        'rc;admin;heal;help;start' {
            break
        }
        'rc;admin;heal;help;stop' {
            break
        }
        'rc;admin;heal;help;help' {
            break
        }
        'rc;admin;pool' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List server pools')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show server pool status')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;pool;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;pool;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--by-id', '--by-id', [CompletionResultType]::ParameterName, 'Interpret POOL as a zero-based pool ID')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;pool;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List server pools')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show server pool status')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;pool;help;list' {
            break
        }
        'rc;admin;pool;help;status' {
            break
        }
        'rc;admin;pool;help;help' {
            break
        }
        'rc;admin;expand' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start post-expansion data rebalancing')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show post-expansion rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running post-expansion rebalance')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;expand;start' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;expand;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;expand;stop' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;expand;help' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start post-expansion data rebalancing')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show post-expansion rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running post-expansion rebalance')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;expand;help;start' {
            break
        }
        'rc;admin;expand;help;status' {
            break
        }
        'rc;admin;expand;help;stop' {
            break
        }
        'rc;admin;expand;help;help' {
            break
        }
        'rc;admin;decommission' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start decommissioning a pool')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show decommissioning status')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Cancel decommissioning a pool')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear failed or canceled decommissioning metadata for a pool')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;decommission;start' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--by-id', '--by-id', [CompletionResultType]::ParameterName, 'Interpret POOL as zero-based pool ID values')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;decommission;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--by-id', '--by-id', [CompletionResultType]::ParameterName, 'Interpret POOL as a zero-based pool ID')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;decommission;cancel' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--by-id', '--by-id', [CompletionResultType]::ParameterName, 'Interpret POOL as a zero-based pool ID')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;decommission;clear' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--by-id', '--by-id', [CompletionResultType]::ParameterName, 'Interpret POOL as a zero-based pool ID')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;decommission;help' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start decommissioning a pool')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show decommissioning status')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Cancel decommissioning a pool')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear failed or canceled decommissioning metadata for a pool')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;decommission;help;start' {
            break
        }
        'rc;admin;decommission;help;status' {
            break
        }
        'rc;admin;decommission;help;cancel' {
            break
        }
        'rc;admin;decommission;help;clear' {
            break
        }
        'rc;admin;decommission;help;help' {
            break
        }
        'rc;admin;rebalance' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a rebalance operation')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running rebalance operation')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;rebalance;start' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;rebalance;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;rebalance;stop' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;rebalance;help' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a rebalance operation')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running rebalance operation')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;rebalance;help;start' {
            break
        }
        'rc;admin;rebalance;help;status' {
            break
        }
        'rc;admin;rebalance;help;stop' {
            break
        }
        'rc;admin;rebalance;help;help' {
            break
        }
        'rc;admin;user' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all users')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new user')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get user information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a user')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a user')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a user')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;user;ls' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;user;add' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;user;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;user;rm' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;user;enable' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;user;disable' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;user;help' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all users')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new user')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get user information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a user')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a user')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a user')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;user;help;ls' {
            break
        }
        'rc;admin;user;help;add' {
            break
        }
        'rc;admin;user;help;info' {
            break
        }
        'rc;admin;user;help;rm' {
            break
        }
        'rc;admin;user;help;enable' {
            break
        }
        'rc;admin;user;help;disable' {
            break
        }
        'rc;admin;user;help;help' {
            break
        }
        'rc;admin;policy' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all policies')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new policy')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get policy information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a policy')
            [CompletionResult]::new('attach', 'attach', [CompletionResultType]::ParameterValue, 'Attach policy to a user or group')
            [CompletionResult]::new('detach', 'detach', [CompletionResultType]::ParameterValue, 'Detach one or more policies from exactly one user or group')
            [CompletionResult]::new('entities', 'entities', [CompletionResultType]::ParameterValue, 'Inspect policy mappings for users, groups, or policies')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;policy;ls' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;policy;create' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;policy;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;policy;rm' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;policy;attach' {
            [CompletionResult]::new('--user', '--user', [CompletionResultType]::ParameterName, 'Target user access key')
            [CompletionResult]::new('--group', '--group', [CompletionResultType]::ParameterName, 'Target group name')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;policy;detach' {
            [CompletionResult]::new('--user', '--user', [CompletionResultType]::ParameterName, 'Target user access key')
            [CompletionResult]::new('--group', '--group', [CompletionResultType]::ParameterName, 'Target group name')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;policy;entities' {
            [CompletionResult]::new('--user', '--user', [CompletionResultType]::ParameterName, 'User access key to inspect; may be repeated')
            [CompletionResult]::new('--group', '--group', [CompletionResultType]::ParameterName, 'Group name to inspect; may be repeated')
            [CompletionResult]::new('--policy', '--policy', [CompletionResultType]::ParameterName, 'Policy name to inspect; may be repeated')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;policy;help' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all policies')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new policy')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get policy information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a policy')
            [CompletionResult]::new('attach', 'attach', [CompletionResultType]::ParameterValue, 'Attach policy to a user or group')
            [CompletionResult]::new('detach', 'detach', [CompletionResultType]::ParameterValue, 'Detach one or more policies from exactly one user or group')
            [CompletionResult]::new('entities', 'entities', [CompletionResultType]::ParameterValue, 'Inspect policy mappings for users, groups, or policies')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;policy;help;ls' {
            break
        }
        'rc;admin;policy;help;create' {
            break
        }
        'rc;admin;policy;help;info' {
            break
        }
        'rc;admin;policy;help;rm' {
            break
        }
        'rc;admin;policy;help;attach' {
            break
        }
        'rc;admin;policy;help;detach' {
            break
        }
        'rc;admin;policy;help;entities' {
            break
        }
        'rc;admin;policy;help;help' {
            break
        }
        'rc;admin;group' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all groups')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Create a new group')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get group information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a group')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a group')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a group')
            [CompletionResult]::new('add-members', 'add-members', [CompletionResultType]::ParameterValue, 'Add members to a group')
            [CompletionResult]::new('rm-members', 'rm-members', [CompletionResultType]::ParameterValue, 'Remove members from a group')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;group;ls' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;add' {
            [CompletionResult]::new('--members', '--members', [CompletionResultType]::ParameterName, 'Initial members (comma-separated access keys)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;rm' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;enable' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;disable' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;add-members' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;rm-members' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;help' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all groups')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Create a new group')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get group information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a group')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a group')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a group')
            [CompletionResult]::new('add-members', 'add-members', [CompletionResultType]::ParameterValue, 'Add members to a group')
            [CompletionResult]::new('rm-members', 'rm-members', [CompletionResultType]::ParameterValue, 'Remove members from a group')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;group;help;ls' {
            break
        }
        'rc;admin;group;help;add' {
            break
        }
        'rc;admin;group;help;info' {
            break
        }
        'rc;admin;group;help;rm' {
            break
        }
        'rc;admin;group;help;enable' {
            break
        }
        'rc;admin;group;help;disable' {
            break
        }
        'rc;admin;group;help;add-members' {
            break
        }
        'rc;admin;group;help;rm-members' {
            break
        }
        'rc;admin;group;help;help' {
            break
        }
        'rc;admin;service-account' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List service accounts')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new service account')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing service account')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get service account information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a service account')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;service-account;ls' {
            [CompletionResult]::new('--user', '--user', [CompletionResultType]::ParameterName, 'Filter by parent user')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service-account;create' {
            [CompletionResult]::new('--name', '--name', [CompletionResultType]::ParameterName, 'Optional name for the service account')
            [CompletionResult]::new('--description', '--description', [CompletionResultType]::ParameterName, 'Optional description')
            [CompletionResult]::new('--policy', '--policy', [CompletionResultType]::ParameterName, 'Optional policy document (JSON file path)')
            [CompletionResult]::new('--policy-json', '--policy-json', [CompletionResultType]::ParameterName, 'Optional inline policy document (JSON string)')
            [CompletionResult]::new('--expiry', '--expiry', [CompletionResultType]::ParameterName, 'Optional expiration time (ISO 8601 format)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service-account;update' {
            [CompletionResult]::new('--secret-key', '--secret-key', [CompletionResultType]::ParameterName, 'Replacement secret key')
            [CompletionResult]::new('--name', '--name', [CompletionResultType]::ParameterName, 'Replacement name for the service account')
            [CompletionResult]::new('--description', '--description', [CompletionResultType]::ParameterName, 'Replacement description')
            [CompletionResult]::new('--policy', '--policy', [CompletionResultType]::ParameterName, 'Replacement policy document (JSON file path)')
            [CompletionResult]::new('--policy-json', '--policy-json', [CompletionResultType]::ParameterName, 'Replacement inline policy document (JSON string)')
            [CompletionResult]::new('--expiry', '--expiry', [CompletionResultType]::ParameterName, 'Replacement expiration time (ISO 8601 format)')
            [CompletionResult]::new('--status', '--status', [CompletionResultType]::ParameterName, 'Replacement account status')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service-account;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service-account;rm' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service-account;help' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List service accounts')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new service account')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing service account')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get service account information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a service account')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;service-account;help;ls' {
            break
        }
        'rc;admin;service-account;help;create' {
            break
        }
        'rc;admin;service-account;help;update' {
            break
        }
        'rc;admin;service-account;help;info' {
            break
        }
        'rc;admin;service-account;help;rm' {
            break
        }
        'rc;admin;service-account;help;help' {
            break
        }
        'rc;admin;access-key' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get access key information')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List access keys across capability-advertised identity providers')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;access-key;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;access-key;ls' {
            [CompletionResult]::new('--provider', '--provider', [CompletionResultType]::ParameterName, 'Provider scope; repeat to inspect multiple providers')
            [CompletionResult]::new('--user', '--user', [CompletionResultType]::ParameterName, 'Parent identity to inspect; may be repeated')
            [CompletionResult]::new('--key-type', '--key-type', [CompletionResultType]::ParameterName, 'Access-key class to include')
            [CompletionResult]::new('--offset', '--offset', [CompletionResultType]::ParameterName, 'Zero-based offset into the deterministic aggregate result')
            [CompletionResult]::new('--limit', '--limit', [CompletionResultType]::ParameterName, 'Maximum records emitted in this output page')
            [CompletionResult]::new('--request-batch-size', '--request-batch-size', [CompletionResultType]::ParameterName, 'Maximum user selectors sent in one bounded server request')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Inspect all parent identities visible to the caller')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;access-key;help' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get access key information')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List access keys across capability-advertised identity providers')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;access-key;help;info' {
            break
        }
        'rc;admin;access-key;help;ls' {
            break
        }
        'rc;admin;access-key;help;help' {
            break
        }
        'rc;admin;bucket-metadata' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export a deterministic, redacted metadata archive')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Validate and import metadata using an explicit conflict strategy')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;bucket-metadata;export' {
            [CompletionResult]::new('--bucket', '--bucket', [CompletionResultType]::ParameterName, 'Select one or more buckets; omit to export every bucket')
            [CompletionResult]::new('--file', '--file', [CompletionResultType]::ParameterName, 'Destination ZIP path')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Atomically replace an existing destination')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;bucket-metadata;import' {
            [CompletionResult]::new('--file', '--file', [CompletionResultType]::ParameterName, 'Protected ZIP path, or ''-'' to read from standard input')
            [CompletionResult]::new('--bucket', '--bucket', [CompletionResultType]::ParameterName, 'Select one or more buckets from the archive')
            [CompletionResult]::new('--conflict', '--conflict', [CompletionResultType]::ParameterName, 'Required behavior when an existing config differs')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Validate and report the import plan without mutation')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm a mutating import')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;bucket-metadata;help' {
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export a deterministic, redacted metadata archive')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Validate and import metadata using an explicit conflict strategy')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;bucket-metadata;help;export' {
            break
        }
        'rc;admin;bucket-metadata;help;import' {
            break
        }
        'rc;admin;bucket-metadata;help;help' {
            break
        }
        'rc;admin;iam' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export IAM users, groups, policies, mappings, and service accounts')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Validate or import a previously exported IAM archive')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;iam;export' {
            [CompletionResult]::new('--file', '--file', [CompletionResultType]::ParameterName, 'New private archive file; existing files are never overwritten')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;iam;import' {
            [CompletionResult]::new('--file', '--file', [CompletionResultType]::ParameterName, 'Private archive file, or ''-'' to read from stdin')
            [CompletionResult]::new('--conflict', '--conflict', [CompletionResultType]::ParameterName, 'How to handle destination entities with the same name')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Validate and report the import plan without mutation')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Required before sending an import mutation')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;iam;help' {
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export IAM users, groups, policies, mappings, and service accounts')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Validate or import a previously exported IAM archive')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;iam;help;export' {
            break
        }
        'rc;admin;iam;help;import' {
            break
        }
        'rc;admin;iam;help;help' {
            break
        }
        'rc;admin;service' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('restart', 'restart', [CompletionResultType]::ParameterValue, 'Restart the server (graceful shutdown; process manager relaunches)')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop the server gracefully')
            [CompletionResult]::new('freeze', 'freeze', [CompletionResultType]::ParameterValue, 'Set the service freeze flag (advisory)')
            [CompletionResult]::new('unfreeze', 'unfreeze', [CompletionResultType]::ParameterValue, 'Clear the service freeze flag')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;service;restart' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service;stop' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service;freeze' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service;unfreeze' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service;help' {
            [CompletionResult]::new('restart', 'restart', [CompletionResultType]::ParameterValue, 'Restart the server (graceful shutdown; process manager relaunches)')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop the server gracefully')
            [CompletionResult]::new('freeze', 'freeze', [CompletionResultType]::ParameterValue, 'Set the service freeze flag (advisory)')
            [CompletionResult]::new('unfreeze', 'unfreeze', [CompletionResultType]::ParameterValue, 'Clear the service freeze flag')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;service;help;restart' {
            break
        }
        'rc;admin;service;help;stop' {
            break
        }
        'rc;admin;service;help;freeze' {
            break
        }
        'rc;admin;service;help;unfreeze' {
            break
        }
        'rc;admin;service;help;help' {
            break
        }
        'rc;admin;replicate' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add sites (given as alias names) to a site replication cluster')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show site replication configuration')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Safely edit one exact site replication peer')
            [CompletionResult]::new('resync', 'resync', [CompletionResultType]::ParameterValue, 'Manage persisted site resync operation snapshots')
            [CompletionResult]::new('repair', 'repair', [CompletionResultType]::ParameterValue, 'Plan, execute, or inspect durable site replication repair')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show site replication status')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove sites from the site replication cluster')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;replicate;add' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;edit' {
            [CompletionResult]::new('--site', '--site', [CompletionResultType]::ParameterName, 'Exact deployment ID or unique exact site name')
            [CompletionResult]::new('--endpoint', '--endpoint', [CompletionResultType]::ParameterName, 'Replace the peer endpoint with a safe HTTP(S) origin')
            [CompletionResult]::new('--name', '--name', [CompletionResultType]::ParameterName, 'Rename the selected peer')
            [CompletionResult]::new('--ca-cert', '--ca-cert', [CompletionResultType]::ParameterName, 'Replace the peer custom CA with a certificate-only PEM bundle')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--skip-tls-verify', '--skip-tls-verify', [CompletionResultType]::ParameterName, 'Disable TLS certificate verification for the peer')
            [CompletionResult]::new('--verify-tls', '--verify-tls', [CompletionResultType]::ParameterName, 'Enable TLS certificate verification for the peer')
            [CompletionResult]::new('--clear-ca-cert', '--clear-ca-cert', [CompletionResultType]::ParameterName, 'Clear the peer custom CA')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm the read-modify-write edit')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;resync' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start resync for one exact peer and retain the mutation snapshot')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Read the persisted snapshot from the last start or cancel request')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Cancel resync for one exact peer and retain the mutation snapshot')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;replicate;resync;start' {
            [CompletionResult]::new('--site', '--site', [CompletionResultType]::ParameterName, 'Exact deployment ID or unique exact site name')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm the resync mutation')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;resync;status' {
            [CompletionResult]::new('--site', '--site', [CompletionResultType]::ParameterName, 'Exact deployment ID or unique exact site name')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;resync;cancel' {
            [CompletionResult]::new('--site', '--site', [CompletionResultType]::ParameterName, 'Exact deployment ID or unique exact site name')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm the resync mutation')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;resync;help' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start resync for one exact peer and retain the mutation snapshot')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Read the persisted snapshot from the last start or cancel request')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Cancel resync for one exact peer and retain the mutation snapshot')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;replicate;resync;help;start' {
            break
        }
        'rc;admin;replicate;resync;help;status' {
            break
        }
        'rc;admin;replicate;resync;help;cancel' {
            break
        }
        'rc;admin;replicate;resync;help;help' {
            break
        }
        'rc;admin;replicate;repair' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('dry-run', 'dry-run', [CompletionResultType]::ParameterValue, 'Create a local-only repair plan and preflight token')
            [CompletionResult]::new('execute', 'execute', [CompletionResultType]::ParameterValue, 'Execute or resume a repair using the exact preflight token and operation ID')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Read a durable repair snapshot from a fresh process')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;replicate;repair;dry-run' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;repair;execute' {
            [CompletionResult]::new('--preflight-token', '--preflight-token', [CompletionResultType]::ParameterName, 'Complete server-issued preflight token from a separate dry-run')
            [CompletionResult]::new('--operation-id', '--operation-id', [CompletionResultType]::ParameterName, 'Stable UUID retained and reused for retries')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm the repair mutation')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;repair;status' {
            [CompletionResult]::new('--operation-id', '--operation-id', [CompletionResultType]::ParameterName, 'Durable operation UUID')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;repair;help' {
            [CompletionResult]::new('dry-run', 'dry-run', [CompletionResultType]::ParameterValue, 'Create a local-only repair plan and preflight token')
            [CompletionResult]::new('execute', 'execute', [CompletionResultType]::ParameterValue, 'Execute or resume a repair using the exact preflight token and operation ID')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Read a durable repair snapshot from a fresh process')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;replicate;repair;help;dry-run' {
            break
        }
        'rc;admin;replicate;repair;help;execute' {
            break
        }
        'rc;admin;replicate;repair;help;status' {
            break
        }
        'rc;admin;replicate;repair;help;help' {
            break
        }
        'rc;admin;replicate;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--buckets', '--buckets', [CompletionResultType]::ParameterName, 'Include bucket replication status')
            [CompletionResult]::new('--users', '--users', [CompletionResultType]::ParameterName, 'Include user replication status')
            [CompletionResult]::new('--groups', '--groups', [CompletionResultType]::ParameterName, 'Include group replication status')
            [CompletionResult]::new('--policies', '--policies', [CompletionResultType]::ParameterName, 'Include policy replication status')
            [CompletionResult]::new('--metrics', '--metrics', [CompletionResultType]::ParameterName, 'Include replication metrics')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;remove' {
            [CompletionResult]::new('--site', '--site', [CompletionResultType]::ParameterName, 'Site names to remove from the cluster')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Remove all sites (dissolve the cluster)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add sites (given as alias names) to a site replication cluster')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show site replication configuration')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Safely edit one exact site replication peer')
            [CompletionResult]::new('resync', 'resync', [CompletionResultType]::ParameterValue, 'Manage persisted site resync operation snapshots')
            [CompletionResult]::new('repair', 'repair', [CompletionResultType]::ParameterValue, 'Plan, execute, or inspect durable site replication repair')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show site replication status')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove sites from the site replication cluster')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;replicate;help;add' {
            break
        }
        'rc;admin;replicate;help;info' {
            break
        }
        'rc;admin;replicate;help;edit' {
            break
        }
        'rc;admin;replicate;help;resync' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start resync for one exact peer and retain the mutation snapshot')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Read the persisted snapshot from the last start or cancel request')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Cancel resync for one exact peer and retain the mutation snapshot')
            break
        }
        'rc;admin;replicate;help;resync;start' {
            break
        }
        'rc;admin;replicate;help;resync;status' {
            break
        }
        'rc;admin;replicate;help;resync;cancel' {
            break
        }
        'rc;admin;replicate;help;repair' {
            [CompletionResult]::new('dry-run', 'dry-run', [CompletionResultType]::ParameterValue, 'Create a local-only repair plan and preflight token')
            [CompletionResult]::new('execute', 'execute', [CompletionResultType]::ParameterValue, 'Execute or resume a repair using the exact preflight token and operation ID')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Read a durable repair snapshot from a fresh process')
            break
        }
        'rc;admin;replicate;help;repair;dry-run' {
            break
        }
        'rc;admin;replicate;help;repair;execute' {
            break
        }
        'rc;admin;replicate;help;repair;status' {
            break
        }
        'rc;admin;replicate;help;status' {
            break
        }
        'rc;admin;replicate;help;remove' {
            break
        }
        'rc;admin;replicate;help;help' {
            break
        }
        'rc;admin;help' {
            [CompletionResult]::new('capabilities', 'capabilities', [CompletionResultType]::ParameterValue, 'Discover effective RustFS runtime capabilities')
            [CompletionResult]::new('diagnostics', 'diagnostics', [CompletionResultType]::ParameterValue, 'Read bounded snapshots or run explicitly confirmed RustFS diagnostic probes')
            [CompletionResult]::new('config', 'config', [CompletionResultType]::ParameterValue, 'Manage RustFS server configuration')
            [CompletionResult]::new('metrics', 'metrics', [CompletionResultType]::ParameterValue, 'Query bounded RustFS realtime metrics')
            [CompletionResult]::new('kms', 'kms', [CompletionResultType]::ParameterValue, 'Inspect KMS state and manage key lifecycle operations')
            [CompletionResult]::new('scanner', 'scanner', [CompletionResultType]::ParameterValue, 'Inspect scanner health and freshness')
            [CompletionResult]::new('ilm', 'ilm', [CompletionResultType]::ParameterValue, 'Manage lifecycle transition operations')
            [CompletionResult]::new('idp', 'idp', [CompletionResultType]::ParameterValue, 'Inspect, validate, and manage identity-provider configuration')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Display cluster information (servers, disks, usage)')
            [CompletionResult]::new('heal', 'heal', [CompletionResultType]::ParameterValue, 'Manage cluster healing operations')
            [CompletionResult]::new('pool', 'pool', [CompletionResultType]::ParameterValue, 'Manage server pools and expansion status')
            [CompletionResult]::new('expand', 'expand', [CompletionResultType]::ParameterValue, 'Manage post-expansion data rebalancing')
            [CompletionResult]::new('decommission', 'decommission', [CompletionResultType]::ParameterValue, 'Manage server pool decommissioning')
            [CompletionResult]::new('rebalance', 'rebalance', [CompletionResultType]::ParameterValue, 'Manage post-expansion rebalancing')
            [CompletionResult]::new('user', 'user', [CompletionResultType]::ParameterValue, 'Manage IAM users')
            [CompletionResult]::new('policy', 'policy', [CompletionResultType]::ParameterValue, 'Manage IAM policies')
            [CompletionResult]::new('group', 'group', [CompletionResultType]::ParameterValue, 'Manage IAM groups')
            [CompletionResult]::new('service-account', 'service-account', [CompletionResultType]::ParameterValue, 'Manage service accounts')
            [CompletionResult]::new('access-key', 'access-key', [CompletionResultType]::ParameterValue, 'Inspect access key identities')
            [CompletionResult]::new('bucket-metadata', 'bucket-metadata', [CompletionResultType]::ParameterValue, 'Export or import validated per-bucket metadata archives')
            [CompletionResult]::new('iam', 'iam', [CompletionResultType]::ParameterValue, 'Export or import versioned IAM archives')
            [CompletionResult]::new('service', 'service', [CompletionResultType]::ParameterValue, 'Control the server process (restart, stop, freeze, unfreeze)')
            [CompletionResult]::new('replicate', 'replicate', [CompletionResultType]::ParameterValue, 'Manage site replication across clusters')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;help;capabilities' {
            break
        }
        'rc;admin;help;diagnostics' {
            [CompletionResult]::new('health', 'health', [CompletionResultType]::ParameterValue, 'Display authenticated host, process, and drive health observations')
            [CompletionResult]::new('cluster', 'cluster', [CompletionResultType]::ParameterValue, 'Display the read-only RustFS cluster snapshot')
            [CompletionResult]::new('extensions', 'extensions', [CompletionResultType]::ParameterValue, 'Display extension schemas and runtime capability summaries')
            [CompletionResult]::new('client-devnull', 'client-devnull', [CompletionResultType]::ParameterValue, 'Measure bounded client-to-server upload throughput without storing data')
            [CompletionResult]::new('inspect-archive', 'inspect-archive', [CompletionResultType]::ParameterValue, 'Retrieve and verify an encrypted drive-metadata archive')
            break
        }
        'rc;admin;help;diagnostics;health' {
            break
        }
        'rc;admin;help;diagnostics;cluster' {
            break
        }
        'rc;admin;help;diagnostics;extensions' {
            break
        }
        'rc;admin;help;diagnostics;client-devnull' {
            break
        }
        'rc;admin;help;diagnostics;inspect-archive' {
            break
        }
        'rc;admin;help;config' {
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Read a subsystem or target configuration')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set one or more keys after showing a preflight diff')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Delete a target or selected keys after showing a preflight diff')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Show server-provided configuration help')
            [CompletionResult]::new('history', 'history', [CompletionResultType]::ParameterValue, 'List configuration mutation history')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Replace configuration from a history entry')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export the full server configuration to a file')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Replace the full server configuration from a file')
            [CompletionResult]::new('module-switch', 'module-switch', [CompletionResultType]::ParameterValue, 'Inspect or update event notification and audit module switches')
            break
        }
        'rc;admin;help;config;get' {
            break
        }
        'rc;admin;help;config;set' {
            break
        }
        'rc;admin;help;config;delete' {
            break
        }
        'rc;admin;help;config;help' {
            break
        }
        'rc;admin;help;config;history' {
            break
        }
        'rc;admin;help;config;restore' {
            break
        }
        'rc;admin;help;config;export' {
            break
        }
        'rc;admin;help;config;import' {
            break
        }
        'rc;admin;help;config;module-switch' {
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'get')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'set')
            break
        }
        'rc;admin;help;config;module-switch;get' {
            break
        }
        'rc;admin;help;config;module-switch;set' {
            break
        }
        'rc;admin;help;metrics' {
            break
        }
        'rc;admin;help;kms' {
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display KMS service health and non-secret configuration summary')
            [CompletionResult]::new('key', 'key', [CompletionResultType]::ParameterValue, 'Inspect KMS keys')
            [CompletionResult]::new('configure', 'configure', [CompletionResultType]::ParameterValue, 'Configure KMS from a protected JSON file or standard input')
            [CompletionResult]::new('reconfigure', 'reconfigure', [CompletionResultType]::ParameterValue, 'Replace KMS configuration from a protected JSON file or standard input')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start the configured KMS service')
            [CompletionResult]::new('restart', 'restart', [CompletionResultType]::ParameterValue, 'Restart the KMS service after explicit confirmation')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop the KMS service after explicit confirmation')
            [CompletionResult]::new('roundtrip', 'roundtrip', [CompletionResultType]::ParameterValue, 'Verify SSE-KMS write and read behavior with a temporary object')
            break
        }
        'rc;admin;help;kms;status' {
            break
        }
        'rc;admin;help;kms;key' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List KMS keys')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display key lifecycle status; defaults to the configured KMS key')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a KMS key without exporting key material')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Schedule or immediately delete a KMS key')
            [CompletionResult]::new('cancel-deletion', 'cancel-deletion', [CompletionResultType]::ParameterValue, 'Cancel a scheduled KMS key deletion')
            break
        }
        'rc;admin;help;kms;key;list' {
            break
        }
        'rc;admin;help;kms;key;status' {
            break
        }
        'rc;admin;help;kms;key;create' {
            break
        }
        'rc;admin;help;kms;key;delete' {
            break
        }
        'rc;admin;help;kms;key;cancel-deletion' {
            break
        }
        'rc;admin;help;kms;configure' {
            break
        }
        'rc;admin;help;kms;reconfigure' {
            break
        }
        'rc;admin;help;kms;start' {
            break
        }
        'rc;admin;help;kms;restart' {
            break
        }
        'rc;admin;help;kms;stop' {
            break
        }
        'rc;admin;help;kms;roundtrip' {
            break
        }
        'rc;admin;help;scanner' {
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display scanner health, freshness, and current cycle details')
            break
        }
        'rc;admin;help;scanner;status' {
            break
        }
        'rc;admin;help;ilm' {
            [CompletionResult]::new('transition', 'transition', [CompletionResultType]::ParameterValue, 'Manage lifecycle transition operations')
            break
        }
        'rc;admin;help;ilm;transition' {
            [CompletionResult]::new('run', 'run', [CompletionResultType]::ParameterValue, 'Run bounded lifecycle transition evaluation for existing objects')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show durable lifecycle transition job status')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Request cancellation for a durable lifecycle transition job')
            [CompletionResult]::new('wait', 'wait', [CompletionResultType]::ParameterValue, 'Wait until a durable lifecycle transition job reaches a terminal state')
            break
        }
        'rc;admin;help;ilm;transition;run' {
            break
        }
        'rc;admin;help;ilm;transition;status' {
            break
        }
        'rc;admin;help;ilm;transition;cancel' {
            break
        }
        'rc;admin;help;ilm;transition;wait' {
            break
        }
        'rc;admin;help;idp' {
            [CompletionResult]::new('openid', 'openid', [CompletionResultType]::ParameterValue, 'Inspect and validate OpenID Connect providers')
            break
        }
        'rc;admin;help;idp;openid' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List effective OIDC provider configurations')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Display one effective OIDC provider configuration')
            [CompletionResult]::new('validate', 'validate', [CompletionResultType]::ParameterValue, 'Validate OIDC discovery without saving configuration')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Create or replace an OIDC provider while preserving omitted fields')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing OIDC provider while preserving omitted fields')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable an existing OIDC provider')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable an existing OIDC provider')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Delete an editable OIDC provider after explicit confirmation')
            break
        }
        'rc;admin;help;idp;openid;list' {
            break
        }
        'rc;admin;help;idp;openid;get' {
            break
        }
        'rc;admin;help;idp;openid;validate' {
            break
        }
        'rc;admin;help;idp;openid;set' {
            break
        }
        'rc;admin;help;idp;openid;update' {
            break
        }
        'rc;admin;help;idp;openid;enable' {
            break
        }
        'rc;admin;help;idp;openid;disable' {
            break
        }
        'rc;admin;help;idp;openid;delete' {
            break
        }
        'rc;admin;help;info' {
            [CompletionResult]::new('cluster', 'cluster', [CompletionResultType]::ParameterValue, 'Display cluster overview information')
            [CompletionResult]::new('server', 'server', [CompletionResultType]::ParameterValue, 'Display server information')
            [CompletionResult]::new('disk', 'disk', [CompletionResultType]::ParameterValue, 'Display disk information')
            [CompletionResult]::new('storage', 'storage', [CompletionResultType]::ParameterValue, 'Display storage topology and capacity information')
            break
        }
        'rc;admin;help;info;cluster' {
            break
        }
        'rc;admin;help;info;server' {
            break
        }
        'rc;admin;help;info;disk' {
            break
        }
        'rc;admin;help;info;storage' {
            break
        }
        'rc;admin;help;heal' {
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display current heal status')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a heal operation')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running heal operation')
            break
        }
        'rc;admin;help;heal;status' {
            break
        }
        'rc;admin;help;heal;start' {
            break
        }
        'rc;admin;help;heal;stop' {
            break
        }
        'rc;admin;help;pool' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List server pools')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show server pool status')
            break
        }
        'rc;admin;help;pool;list' {
            break
        }
        'rc;admin;help;pool;status' {
            break
        }
        'rc;admin;help;expand' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start post-expansion data rebalancing')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show post-expansion rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running post-expansion rebalance')
            break
        }
        'rc;admin;help;expand;start' {
            break
        }
        'rc;admin;help;expand;status' {
            break
        }
        'rc;admin;help;expand;stop' {
            break
        }
        'rc;admin;help;decommission' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start decommissioning a pool')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show decommissioning status')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Cancel decommissioning a pool')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear failed or canceled decommissioning metadata for a pool')
            break
        }
        'rc;admin;help;decommission;start' {
            break
        }
        'rc;admin;help;decommission;status' {
            break
        }
        'rc;admin;help;decommission;cancel' {
            break
        }
        'rc;admin;help;decommission;clear' {
            break
        }
        'rc;admin;help;rebalance' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a rebalance operation')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running rebalance operation')
            break
        }
        'rc;admin;help;rebalance;start' {
            break
        }
        'rc;admin;help;rebalance;status' {
            break
        }
        'rc;admin;help;rebalance;stop' {
            break
        }
        'rc;admin;help;user' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all users')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new user')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get user information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a user')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a user')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a user')
            break
        }
        'rc;admin;help;user;ls' {
            break
        }
        'rc;admin;help;user;add' {
            break
        }
        'rc;admin;help;user;info' {
            break
        }
        'rc;admin;help;user;rm' {
            break
        }
        'rc;admin;help;user;enable' {
            break
        }
        'rc;admin;help;user;disable' {
            break
        }
        'rc;admin;help;policy' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all policies')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new policy')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get policy information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a policy')
            [CompletionResult]::new('attach', 'attach', [CompletionResultType]::ParameterValue, 'Attach policy to a user or group')
            [CompletionResult]::new('detach', 'detach', [CompletionResultType]::ParameterValue, 'Detach one or more policies from exactly one user or group')
            [CompletionResult]::new('entities', 'entities', [CompletionResultType]::ParameterValue, 'Inspect policy mappings for users, groups, or policies')
            break
        }
        'rc;admin;help;policy;ls' {
            break
        }
        'rc;admin;help;policy;create' {
            break
        }
        'rc;admin;help;policy;info' {
            break
        }
        'rc;admin;help;policy;rm' {
            break
        }
        'rc;admin;help;policy;attach' {
            break
        }
        'rc;admin;help;policy;detach' {
            break
        }
        'rc;admin;help;policy;entities' {
            break
        }
        'rc;admin;help;group' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all groups')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Create a new group')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get group information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a group')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a group')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a group')
            [CompletionResult]::new('add-members', 'add-members', [CompletionResultType]::ParameterValue, 'Add members to a group')
            [CompletionResult]::new('rm-members', 'rm-members', [CompletionResultType]::ParameterValue, 'Remove members from a group')
            break
        }
        'rc;admin;help;group;ls' {
            break
        }
        'rc;admin;help;group;add' {
            break
        }
        'rc;admin;help;group;info' {
            break
        }
        'rc;admin;help;group;rm' {
            break
        }
        'rc;admin;help;group;enable' {
            break
        }
        'rc;admin;help;group;disable' {
            break
        }
        'rc;admin;help;group;add-members' {
            break
        }
        'rc;admin;help;group;rm-members' {
            break
        }
        'rc;admin;help;service-account' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List service accounts')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new service account')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing service account')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get service account information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a service account')
            break
        }
        'rc;admin;help;service-account;ls' {
            break
        }
        'rc;admin;help;service-account;create' {
            break
        }
        'rc;admin;help;service-account;update' {
            break
        }
        'rc;admin;help;service-account;info' {
            break
        }
        'rc;admin;help;service-account;rm' {
            break
        }
        'rc;admin;help;access-key' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get access key information')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List access keys across capability-advertised identity providers')
            break
        }
        'rc;admin;help;access-key;info' {
            break
        }
        'rc;admin;help;access-key;ls' {
            break
        }
        'rc;admin;help;bucket-metadata' {
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export a deterministic, redacted metadata archive')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Validate and import metadata using an explicit conflict strategy')
            break
        }
        'rc;admin;help;bucket-metadata;export' {
            break
        }
        'rc;admin;help;bucket-metadata;import' {
            break
        }
        'rc;admin;help;iam' {
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export IAM users, groups, policies, mappings, and service accounts')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Validate or import a previously exported IAM archive')
            break
        }
        'rc;admin;help;iam;export' {
            break
        }
        'rc;admin;help;iam;import' {
            break
        }
        'rc;admin;help;service' {
            [CompletionResult]::new('restart', 'restart', [CompletionResultType]::ParameterValue, 'Restart the server (graceful shutdown; process manager relaunches)')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop the server gracefully')
            [CompletionResult]::new('freeze', 'freeze', [CompletionResultType]::ParameterValue, 'Set the service freeze flag (advisory)')
            [CompletionResult]::new('unfreeze', 'unfreeze', [CompletionResultType]::ParameterValue, 'Clear the service freeze flag')
            break
        }
        'rc;admin;help;service;restart' {
            break
        }
        'rc;admin;help;service;stop' {
            break
        }
        'rc;admin;help;service;freeze' {
            break
        }
        'rc;admin;help;service;unfreeze' {
            break
        }
        'rc;admin;help;replicate' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add sites (given as alias names) to a site replication cluster')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show site replication configuration')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Safely edit one exact site replication peer')
            [CompletionResult]::new('resync', 'resync', [CompletionResultType]::ParameterValue, 'Manage persisted site resync operation snapshots')
            [CompletionResult]::new('repair', 'repair', [CompletionResultType]::ParameterValue, 'Plan, execute, or inspect durable site replication repair')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show site replication status')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove sites from the site replication cluster')
            break
        }
        'rc;admin;help;replicate;add' {
            break
        }
        'rc;admin;help;replicate;info' {
            break
        }
        'rc;admin;help;replicate;edit' {
            break
        }
        'rc;admin;help;replicate;resync' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start resync for one exact peer and retain the mutation snapshot')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Read the persisted snapshot from the last start or cancel request')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Cancel resync for one exact peer and retain the mutation snapshot')
            break
        }
        'rc;admin;help;replicate;resync;start' {
            break
        }
        'rc;admin;help;replicate;resync;status' {
            break
        }
        'rc;admin;help;replicate;resync;cancel' {
            break
        }
        'rc;admin;help;replicate;repair' {
            [CompletionResult]::new('dry-run', 'dry-run', [CompletionResultType]::ParameterValue, 'Create a local-only repair plan and preflight token')
            [CompletionResult]::new('execute', 'execute', [CompletionResultType]::ParameterValue, 'Execute or resume a repair using the exact preflight token and operation ID')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Read a durable repair snapshot from a fresh process')
            break
        }
        'rc;admin;help;replicate;repair;dry-run' {
            break
        }
        'rc;admin;help;replicate;repair;execute' {
            break
        }
        'rc;admin;help;replicate;repair;status' {
            break
        }
        'rc;admin;help;replicate;status' {
            break
        }
        'rc;admin;help;replicate;remove' {
            break
        }
        'rc;admin;help;help' {
            break
        }
        'rc;bucket' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List buckets for an alias, or objects within a bucket path')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a bucket')
            [CompletionResult]::new('event', 'event', [CompletionResultType]::ParameterValue, 'Manage bucket notification rules')
            [CompletionResult]::new('cors', 'cors', [CompletionResultType]::ParameterValue, 'Manage bucket CORS rules')
            [CompletionResult]::new('encryption', 'encryption', [CompletionResultType]::ParameterValue, 'Manage bucket default encryption')
            [CompletionResult]::new('version', 'version', [CompletionResultType]::ParameterValue, 'Manage bucket versioning')
            [CompletionResult]::new('lock', 'lock', [CompletionResultType]::ParameterValue, 'Manage bucket Object Lock and default retention')
            [CompletionResult]::new('quota', 'quota', [CompletionResultType]::ParameterValue, 'Manage bucket quota')
            [CompletionResult]::new('anonymous', 'anonymous', [CompletionResultType]::ParameterValue, 'Manage anonymous bucket access')
            [CompletionResult]::new('lifecycle', 'lifecycle', [CompletionResultType]::ParameterValue, 'Manage bucket lifecycle rules, tiers, and restores')
            [CompletionResult]::new('replication', 'replication', [CompletionResultType]::ParameterValue, 'Manage bucket replication rules and status')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'List recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'List recursively')
            [CompletionResult]::new('--versions', '--versions', [CompletionResultType]::ParameterName, 'Show versions (requires versioning support)')
            [CompletionResult]::new('--incomplete', '--incomplete', [CompletionResultType]::ParameterName, 'List incomplete multipart uploads')
            [CompletionResult]::new('--summarize', '--summarize', [CompletionResultType]::ParameterName, 'Summarize output (show totals only)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;create' {
            [CompletionResult]::new('--region', '--region', [CompletionResultType]::ParameterName, 'Region for the bucket (overrides alias default)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Ignore error if bucket already exists')
            [CompletionResult]::new('--ignore-existing', '--ignore-existing', [CompletionResultType]::ParameterName, 'Ignore error if bucket already exists')
            [CompletionResult]::new('--with-lock', '--with-lock', [CompletionResultType]::ParameterName, 'Enable object locking on the bucket')
            [CompletionResult]::new('--with-versioning', '--with-versioning', [CompletionResultType]::ParameterName, 'Enable versioning on the bucket')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Delete bucket contents before removing the bucket')
            [CompletionResult]::new('--dangerous', '--dangerous', [CompletionResultType]::ParameterName, 'Permit aborting discovered incomplete multipart uploads')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm the dangerous multipart cleanup')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;event' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add or replace a bucket notification rule for an ARN')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket notification rules')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket notification rules by target ARN')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;event;add' {
            [CompletionResult]::new('--event', '--event', [CompletionResultType]::ParameterName, 'Event pattern (repeatable; comma-separated values are also accepted)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;event;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;event;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;event;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add or replace a bucket notification rule for an ARN')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket notification rules')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket notification rules by target ARN')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;event;help;add' {
            break
        }
        'rc;bucket;event;help;list' {
            break
        }
        'rc;bucket;event;help;remove' {
            break
        }
        'rc;bucket;event;help;help' {
            break
        }
        'rc;bucket;cors' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket CORS rules')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Replace bucket CORS rules from a JSON or XML file')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket CORS rules')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;cors;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;cors;set' {
            [CompletionResult]::new('--file', '--file', [CompletionResultType]::ParameterName, 'Path to the CORS configuration file, or ''-'' to read from stdin')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;cors;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;cors;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket CORS rules')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Replace bucket CORS rules from a JSON or XML file')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket CORS rules')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;cors;help;list' {
            break
        }
        'rc;bucket;cors;help;set' {
            break
        }
        'rc;bucket;cors;help;remove' {
            break
        }
        'rc;bucket;cors;help;help' {
            break
        }
        'rc;bucket;encryption' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket default encryption')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket default encryption')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket default encryption')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;encryption;set' {
            [CompletionResult]::new('--mode', '--mode', [CompletionResultType]::ParameterName, 'Default encryption mode')
            [CompletionResult]::new('--key-id', '--key-id', [CompletionResultType]::ParameterName, 'Optional KMS key id for sse-kms mode')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;encryption;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;encryption;clear' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;encryption;help' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket default encryption')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket default encryption')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket default encryption')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;encryption;help;set' {
            break
        }
        'rc;bucket;encryption;help;info' {
            break
        }
        'rc;bucket;encryption;help;clear' {
            break
        }
        'rc;bucket;encryption;help;help' {
            break
        }
        'rc;bucket;version' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable versioning for a bucket')
            [CompletionResult]::new('suspend', 'suspend', [CompletionResultType]::ParameterValue, 'Suspend versioning for a bucket')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get versioning status for a bucket')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List object versions')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;version;enable' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;version;suspend' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;version;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;version;list' {
            [CompletionResult]::new('-n', '-n', [CompletionResultType]::ParameterName, 'Maximum number of versions to show')
            [CompletionResult]::new('--max', '--max', [CompletionResultType]::ParameterName, 'Maximum number of versions to show')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;version;help' {
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable versioning for a bucket')
            [CompletionResult]::new('suspend', 'suspend', [CompletionResultType]::ParameterValue, 'Suspend versioning for a bucket')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get versioning status for a bucket')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List object versions')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;version;help;enable' {
            break
        }
        'rc;bucket;version;help;suspend' {
            break
        }
        'rc;bucket;version;help;info' {
            break
        }
        'rc;bucket;version;help;list' {
            break
        }
        'rc;bucket;version;help;help' {
            break
        }
        'rc;bucket;lock' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket Object Lock and default retention configuration')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set a bucket default retention rule')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear the bucket default retention rule without disabling Object Lock')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;lock;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lock;set' {
            [CompletionResult]::new('--mode', '--mode', [CompletionResultType]::ParameterName, 'Default retention mode')
            [CompletionResult]::new('--days', '--days', [CompletionResultType]::ParameterName, 'Positive default retention duration in days')
            [CompletionResult]::new('--years', '--years', [CompletionResultType]::ParameterName, 'Positive default retention duration in years')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lock;clear' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lock;help' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket Object Lock and default retention configuration')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set a bucket default retention rule')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear the bucket default retention rule without disabling Object Lock')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;lock;help;info' {
            break
        }
        'rc;bucket;lock;help;set' {
            break
        }
        'rc;bucket;lock;help;clear' {
            break
        }
        'rc;bucket;lock;help;help' {
            break
        }
        'rc;bucket;quota' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket quota')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket quota information')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket quota')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;quota;set' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;quota;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;quota;clear' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;quota;help' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket quota')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket quota information')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket quota')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;quota;help;set' {
            break
        }
        'rc;bucket;quota;help;info' {
            break
        }
        'rc;bucket;quota;help;clear' {
            break
        }
        'rc;bucket;quota;help;help' {
            break
        }
        'rc;bucket;anonymous' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set anonymous access permission')
            [CompletionResult]::new('set-json', 'set-json', [CompletionResultType]::ParameterValue, 'Set anonymous access from a policy JSON file')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get anonymous access permission')
            [CompletionResult]::new('get-json', 'get-json', [CompletionResultType]::ParameterValue, 'Get anonymous policy JSON')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List anonymous policies')
            [CompletionResult]::new('links', 'links', [CompletionResultType]::ParameterValue, 'List public links for anonymous readable prefixes')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;anonymous;set' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;anonymous;set-json' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;anonymous;get' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;anonymous;get-json' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;anonymous;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;anonymous;links' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Recursively list links')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Recursively list links')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;anonymous;help' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set anonymous access permission')
            [CompletionResult]::new('set-json', 'set-json', [CompletionResultType]::ParameterValue, 'Set anonymous access from a policy JSON file')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get anonymous access permission')
            [CompletionResult]::new('get-json', 'get-json', [CompletionResultType]::ParameterValue, 'Get anonymous policy JSON')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List anonymous policies')
            [CompletionResult]::new('links', 'links', [CompletionResultType]::ParameterValue, 'List public links for anonymous readable prefixes')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;anonymous;help;set' {
            break
        }
        'rc;bucket;anonymous;help;set-json' {
            break
        }
        'rc;bucket;anonymous;help;get' {
            break
        }
        'rc;bucket;anonymous;help;get-json' {
            break
        }
        'rc;bucket;anonymous;help;list' {
            break
        }
        'rc;bucket;anonymous;help;links' {
            break
        }
        'rc;bucket;anonymous;help;help' {
            break
        }
        'rc;bucket;lifecycle' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('rule', 'rule', [CompletionResultType]::ParameterValue, 'Manage lifecycle rules on a bucket')
            [CompletionResult]::new('tier', 'tier', [CompletionResultType]::ParameterValue, 'Manage remote storage tiers')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Restore a transitioned (archived) object')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;lifecycle;rule' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;lifecycle;rule;add' {
            [CompletionResult]::new('--expiry-days', '--expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for current versions')
            [CompletionResult]::new('--expiry-date', '--expiry-date', [CompletionResultType]::ParameterName, 'Expiration date for current versions (ISO 8601)')
            [CompletionResult]::new('--transition-days', '--transition-days', [CompletionResultType]::ParameterName, 'Transition days for current versions')
            [CompletionResult]::new('--transition-date', '--transition-date', [CompletionResultType]::ParameterName, 'Transition date for current versions (ISO 8601)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Target storage class for transition')
            [CompletionResult]::new('--noncurrent-expiry-days', '--noncurrent-expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-days', '--noncurrent-transition-days', [CompletionResultType]::ParameterName, 'Transition days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-storage-class', '--noncurrent-transition-storage-class', [CompletionResultType]::ParameterName, 'Storage class for noncurrent version transition')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--newer-noncurrent-versions', '--newer-noncurrent-versions', [CompletionResultType]::ParameterName, 'Maximum number of noncurrent versions to retain')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--expired-object-delete-marker', '--expired-object-delete-marker', [CompletionResultType]::ParameterName, 'Remove expired delete markers')
            [CompletionResult]::new('--disable', '--disable', [CompletionResultType]::ParameterName, 'Create the rule in disabled state')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;rule;edit' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'ID of the rule to edit')
            [CompletionResult]::new('--expiry-days', '--expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for current versions')
            [CompletionResult]::new('--expiry-date', '--expiry-date', [CompletionResultType]::ParameterName, 'Expiration date for current versions (ISO 8601)')
            [CompletionResult]::new('--transition-days', '--transition-days', [CompletionResultType]::ParameterName, 'Transition days for current versions')
            [CompletionResult]::new('--transition-date', '--transition-date', [CompletionResultType]::ParameterName, 'Transition date for current versions (ISO 8601)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Target storage class for transition')
            [CompletionResult]::new('--noncurrent-expiry-days', '--noncurrent-expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-days', '--noncurrent-transition-days', [CompletionResultType]::ParameterName, 'Transition days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-storage-class', '--noncurrent-transition-storage-class', [CompletionResultType]::ParameterName, 'Storage class for noncurrent version transition')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--expired-object-delete-marker', '--expired-object-delete-marker', [CompletionResultType]::ParameterName, 'Remove expired delete markers')
            [CompletionResult]::new('--newer-noncurrent-versions', '--newer-noncurrent-versions', [CompletionResultType]::ParameterName, 'Maximum number of noncurrent versions to retain')
            [CompletionResult]::new('--disable', '--disable', [CompletionResultType]::ParameterName, 'Set the rule to disabled state')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;rule;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;rule;remove' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'ID of the rule to remove')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Remove all lifecycle rules')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;rule;export' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;rule;import' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;rule;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;lifecycle;rule;help;add' {
            break
        }
        'rc;bucket;lifecycle;rule;help;edit' {
            break
        }
        'rc;bucket;lifecycle;rule;help;list' {
            break
        }
        'rc;bucket;lifecycle;rule;help;remove' {
            break
        }
        'rc;bucket;lifecycle;rule;help;export' {
            break
        }
        'rc;bucket;lifecycle;rule;help;import' {
            break
        }
        'rc;bucket;lifecycle;rule;help;help' {
            break
        }
        'rc;bucket;lifecycle;tier' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;lifecycle;tier;add' {
            [CompletionResult]::new('--endpoint', '--endpoint', [CompletionResultType]::ParameterName, 'Remote endpoint URL')
            [CompletionResult]::new('--access-key', '--access-key', [CompletionResultType]::ParameterName, 'Access key for the remote backend')
            [CompletionResult]::new('--secret-key', '--secret-key', [CompletionResultType]::ParameterName, 'Secret key for the remote backend')
            [CompletionResult]::new('--bucket', '--bucket', [CompletionResultType]::ParameterName, 'Target bucket on the remote backend')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Object key prefix on the remote bucket')
            [CompletionResult]::new('--region', '--region', [CompletionResultType]::ParameterName, 'Region of the remote backend')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class on the remote backend (for S3/Azure/GCS tiers)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;tier;edit' {
            [CompletionResult]::new('--access-key', '--access-key', [CompletionResultType]::ParameterName, 'New access key')
            [CompletionResult]::new('--secret-key', '--secret-key', [CompletionResultType]::ParameterName, 'New secret key')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;tier;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;tier;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;tier;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force removal even if tier is in use')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;tier;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;lifecycle;tier;help;add' {
            break
        }
        'rc;bucket;lifecycle;tier;help;edit' {
            break
        }
        'rc;bucket;lifecycle;tier;help;list' {
            break
        }
        'rc;bucket;lifecycle;tier;help;info' {
            break
        }
        'rc;bucket;lifecycle;tier;help;remove' {
            break
        }
        'rc;bucket;lifecycle;tier;help;help' {
            break
        }
        'rc;bucket;lifecycle;restore' {
            [CompletionResult]::new('--days', '--days', [CompletionResultType]::ParameterName, 'Number of days to keep the restored copy')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;help' {
            [CompletionResult]::new('rule', 'rule', [CompletionResultType]::ParameterValue, 'Manage lifecycle rules on a bucket')
            [CompletionResult]::new('tier', 'tier', [CompletionResultType]::ParameterValue, 'Manage remote storage tiers')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Restore a transitioned (archived) object')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;lifecycle;help;rule' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            break
        }
        'rc;bucket;lifecycle;help;rule;add' {
            break
        }
        'rc;bucket;lifecycle;help;rule;edit' {
            break
        }
        'rc;bucket;lifecycle;help;rule;list' {
            break
        }
        'rc;bucket;lifecycle;help;rule;remove' {
            break
        }
        'rc;bucket;lifecycle;help;rule;export' {
            break
        }
        'rc;bucket;lifecycle;help;rule;import' {
            break
        }
        'rc;bucket;lifecycle;help;tier' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            break
        }
        'rc;bucket;lifecycle;help;tier;add' {
            break
        }
        'rc;bucket;lifecycle;help;tier;edit' {
            break
        }
        'rc;bucket;lifecycle;help;tier;list' {
            break
        }
        'rc;bucket;lifecycle;help;tier;info' {
            break
        }
        'rc;bucket;lifecycle;help;tier;remove' {
            break
        }
        'rc;bucket;lifecycle;help;restore' {
            break
        }
        'rc;bucket;lifecycle;help;help' {
            break
        }
        'rc;bucket;replication' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new replication rule')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing replication rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List replication rules for a bucket')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show replication status/metrics for a bucket')
            [CompletionResult]::new('mrf', 'mrf', [CompletionResultType]::ParameterValue, 'Show aggregate replication MRF backlog for a bucket')
            [CompletionResult]::new('diff', 'diff', [CompletionResultType]::ParameterValue, 'Scan for object versions that have not replicated')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove replication rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export replication configuration as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import replication configuration from a JSON file')
            [CompletionResult]::new('check', 'check', [CompletionResultType]::ParameterValue, 'Actively validate configured replication targets')
            [CompletionResult]::new('resync', 'resync', [CompletionResultType]::ParameterValue, 'Manage bucket replication resync operations')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;replication;add' {
            [CompletionResult]::new('--remote-bucket', '--remote-bucket', [CompletionResultType]::ParameterName, 'Remote target bucket (TARGET_ALIAS/BUCKET)')
            [CompletionResult]::new('--replicate', '--replicate', [CompletionResultType]::ParameterName, 'Replication flags (comma-separated: delete,delete-marker,existing-objects)')
            [CompletionResult]::new('--priority', '--priority', [CompletionResultType]::ParameterName, 'Rule priority (higher = more important)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class override at destination')
            [CompletionResult]::new('--bandwidth', '--bandwidth', [CompletionResultType]::ParameterName, 'Bandwidth limit in bytes/sec (0 = unlimited)')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'Rule identifier (auto-generated if not specified)')
            [CompletionResult]::new('--healthcheck-seconds', '--healthcheck-seconds', [CompletionResultType]::ParameterName, 'Health check interval in seconds')
            [CompletionResult]::new('--ca-cert', '--ca-cert', [CompletionResultType]::ParameterName, 'Read a local PEM CA certificate file and upload its content for this bucket replication target. The path is resolved on the CLI machine, not on the RustFS server')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--sync', '--sync', [CompletionResultType]::ParameterName, 'Enable synchronous replication')
            [CompletionResult]::new('--disable-proxy', '--disable-proxy', [CompletionResultType]::ParameterName, 'Disable replication proxy')
            [CompletionResult]::new('--insecure', '--insecure', [CompletionResultType]::ParameterName, 'Skip TLS certificate verification for this bucket replication target. Intended for development or test environments')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;update' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'Rule ID to update')
            [CompletionResult]::new('--replicate', '--replicate', [CompletionResultType]::ParameterName, 'Replication flags (comma-separated: delete,delete-marker,existing-objects)')
            [CompletionResult]::new('--priority', '--priority', [CompletionResultType]::ParameterName, 'Rule priority (higher = more important)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class override at destination')
            [CompletionResult]::new('--bandwidth', '--bandwidth', [CompletionResultType]::ParameterName, 'Bandwidth limit in bytes/sec (0 = unlimited)')
            [CompletionResult]::new('--sync', '--sync', [CompletionResultType]::ParameterName, 'Enable or disable synchronous replication')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--healthcheck-seconds', '--healthcheck-seconds', [CompletionResultType]::ParameterName, 'Health check interval in seconds')
            [CompletionResult]::new('--disable-proxy', '--disable-proxy', [CompletionResultType]::ParameterName, 'Disable replication proxy')
            [CompletionResult]::new('--ca-cert', '--ca-cert', [CompletionResultType]::ParameterName, 'Read a local PEM CA certificate file and upload its content for this bucket replication target. The path is resolved on the CLI machine, not on the RustFS server')
            [CompletionResult]::new('--status', '--status', [CompletionResultType]::ParameterName, 'Enable or disable the rule')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--insecure', '--insecure', [CompletionResultType]::ParameterName, 'Skip TLS certificate verification for this bucket replication target. Intended for development or test environments')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;mrf' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;diff' {
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Limit the scan to object keys below this prefix')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;remove' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'Rule ID to remove (omit for --all)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Remove all replication rules')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;export' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;import' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;check' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm the active remote write/delete validation probe')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if generic replication capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;resync' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start resyncing previously replicated objects')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show persisted server-side resync status')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;replication;resync;start' {
            [CompletionResult]::new('--target-arn', '--target-arn', [CompletionResultType]::ParameterName, 'Select a configured replication target ARN')
            [CompletionResult]::new('--older-than', '--older-than', [CompletionResultType]::ParameterName, 'Only resync objects older than this duration (for example, 7d10h31s)')
            [CompletionResult]::new('--reset-id', '--reset-id', [CompletionResultType]::ParameterName, 'Supply a stable resync identifier instead of using a server-generated ID')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm the active server-side resync')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if generic replication capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;resync;status' {
            [CompletionResult]::new('--target-arn', '--target-arn', [CompletionResultType]::ParameterName, 'Filter status to one configured replication target ARN')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if generic replication capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;resync;help' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start resyncing previously replicated objects')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show persisted server-side resync status')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;replication;resync;help;start' {
            break
        }
        'rc;bucket;replication;resync;help;status' {
            break
        }
        'rc;bucket;replication;resync;help;help' {
            break
        }
        'rc;bucket;replication;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new replication rule')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing replication rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List replication rules for a bucket')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show replication status/metrics for a bucket')
            [CompletionResult]::new('mrf', 'mrf', [CompletionResultType]::ParameterValue, 'Show aggregate replication MRF backlog for a bucket')
            [CompletionResult]::new('diff', 'diff', [CompletionResultType]::ParameterValue, 'Scan for object versions that have not replicated')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove replication rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export replication configuration as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import replication configuration from a JSON file')
            [CompletionResult]::new('check', 'check', [CompletionResultType]::ParameterValue, 'Actively validate configured replication targets')
            [CompletionResult]::new('resync', 'resync', [CompletionResultType]::ParameterValue, 'Manage bucket replication resync operations')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;replication;help;add' {
            break
        }
        'rc;bucket;replication;help;update' {
            break
        }
        'rc;bucket;replication;help;list' {
            break
        }
        'rc;bucket;replication;help;status' {
            break
        }
        'rc;bucket;replication;help;mrf' {
            break
        }
        'rc;bucket;replication;help;diff' {
            break
        }
        'rc;bucket;replication;help;remove' {
            break
        }
        'rc;bucket;replication;help;export' {
            break
        }
        'rc;bucket;replication;help;import' {
            break
        }
        'rc;bucket;replication;help;check' {
            break
        }
        'rc;bucket;replication;help;resync' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start resyncing previously replicated objects')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show persisted server-side resync status')
            break
        }
        'rc;bucket;replication;help;resync;start' {
            break
        }
        'rc;bucket;replication;help;resync;status' {
            break
        }
        'rc;bucket;replication;help;help' {
            break
        }
        'rc;bucket;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List buckets for an alias, or objects within a bucket path')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a bucket')
            [CompletionResult]::new('event', 'event', [CompletionResultType]::ParameterValue, 'Manage bucket notification rules')
            [CompletionResult]::new('cors', 'cors', [CompletionResultType]::ParameterValue, 'Manage bucket CORS rules')
            [CompletionResult]::new('encryption', 'encryption', [CompletionResultType]::ParameterValue, 'Manage bucket default encryption')
            [CompletionResult]::new('version', 'version', [CompletionResultType]::ParameterValue, 'Manage bucket versioning')
            [CompletionResult]::new('lock', 'lock', [CompletionResultType]::ParameterValue, 'Manage bucket Object Lock and default retention')
            [CompletionResult]::new('quota', 'quota', [CompletionResultType]::ParameterValue, 'Manage bucket quota')
            [CompletionResult]::new('anonymous', 'anonymous', [CompletionResultType]::ParameterValue, 'Manage anonymous bucket access')
            [CompletionResult]::new('lifecycle', 'lifecycle', [CompletionResultType]::ParameterValue, 'Manage bucket lifecycle rules, tiers, and restores')
            [CompletionResult]::new('replication', 'replication', [CompletionResultType]::ParameterValue, 'Manage bucket replication rules and status')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;help;list' {
            break
        }
        'rc;bucket;help;create' {
            break
        }
        'rc;bucket;help;remove' {
            break
        }
        'rc;bucket;help;event' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add or replace a bucket notification rule for an ARN')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket notification rules')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket notification rules by target ARN')
            break
        }
        'rc;bucket;help;event;add' {
            break
        }
        'rc;bucket;help;event;list' {
            break
        }
        'rc;bucket;help;event;remove' {
            break
        }
        'rc;bucket;help;cors' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket CORS rules')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Replace bucket CORS rules from a JSON or XML file')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket CORS rules')
            break
        }
        'rc;bucket;help;cors;list' {
            break
        }
        'rc;bucket;help;cors;set' {
            break
        }
        'rc;bucket;help;cors;remove' {
            break
        }
        'rc;bucket;help;encryption' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket default encryption')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket default encryption')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket default encryption')
            break
        }
        'rc;bucket;help;encryption;set' {
            break
        }
        'rc;bucket;help;encryption;info' {
            break
        }
        'rc;bucket;help;encryption;clear' {
            break
        }
        'rc;bucket;help;version' {
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable versioning for a bucket')
            [CompletionResult]::new('suspend', 'suspend', [CompletionResultType]::ParameterValue, 'Suspend versioning for a bucket')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get versioning status for a bucket')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List object versions')
            break
        }
        'rc;bucket;help;version;enable' {
            break
        }
        'rc;bucket;help;version;suspend' {
            break
        }
        'rc;bucket;help;version;info' {
            break
        }
        'rc;bucket;help;version;list' {
            break
        }
        'rc;bucket;help;lock' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket Object Lock and default retention configuration')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set a bucket default retention rule')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear the bucket default retention rule without disabling Object Lock')
            break
        }
        'rc;bucket;help;lock;info' {
            break
        }
        'rc;bucket;help;lock;set' {
            break
        }
        'rc;bucket;help;lock;clear' {
            break
        }
        'rc;bucket;help;quota' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket quota')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket quota information')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket quota')
            break
        }
        'rc;bucket;help;quota;set' {
            break
        }
        'rc;bucket;help;quota;info' {
            break
        }
        'rc;bucket;help;quota;clear' {
            break
        }
        'rc;bucket;help;anonymous' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set anonymous access permission')
            [CompletionResult]::new('set-json', 'set-json', [CompletionResultType]::ParameterValue, 'Set anonymous access from a policy JSON file')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get anonymous access permission')
            [CompletionResult]::new('get-json', 'get-json', [CompletionResultType]::ParameterValue, 'Get anonymous policy JSON')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List anonymous policies')
            [CompletionResult]::new('links', 'links', [CompletionResultType]::ParameterValue, 'List public links for anonymous readable prefixes')
            break
        }
        'rc;bucket;help;anonymous;set' {
            break
        }
        'rc;bucket;help;anonymous;set-json' {
            break
        }
        'rc;bucket;help;anonymous;get' {
            break
        }
        'rc;bucket;help;anonymous;get-json' {
            break
        }
        'rc;bucket;help;anonymous;list' {
            break
        }
        'rc;bucket;help;anonymous;links' {
            break
        }
        'rc;bucket;help;lifecycle' {
            [CompletionResult]::new('rule', 'rule', [CompletionResultType]::ParameterValue, 'Manage lifecycle rules on a bucket')
            [CompletionResult]::new('tier', 'tier', [CompletionResultType]::ParameterValue, 'Manage remote storage tiers')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Restore a transitioned (archived) object')
            break
        }
        'rc;bucket;help;lifecycle;rule' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            break
        }
        'rc;bucket;help;lifecycle;rule;add' {
            break
        }
        'rc;bucket;help;lifecycle;rule;edit' {
            break
        }
        'rc;bucket;help;lifecycle;rule;list' {
            break
        }
        'rc;bucket;help;lifecycle;rule;remove' {
            break
        }
        'rc;bucket;help;lifecycle;rule;export' {
            break
        }
        'rc;bucket;help;lifecycle;rule;import' {
            break
        }
        'rc;bucket;help;lifecycle;tier' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            break
        }
        'rc;bucket;help;lifecycle;tier;add' {
            break
        }
        'rc;bucket;help;lifecycle;tier;edit' {
            break
        }
        'rc;bucket;help;lifecycle;tier;list' {
            break
        }
        'rc;bucket;help;lifecycle;tier;info' {
            break
        }
        'rc;bucket;help;lifecycle;tier;remove' {
            break
        }
        'rc;bucket;help;lifecycle;restore' {
            break
        }
        'rc;bucket;help;replication' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new replication rule')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing replication rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List replication rules for a bucket')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show replication status/metrics for a bucket')
            [CompletionResult]::new('mrf', 'mrf', [CompletionResultType]::ParameterValue, 'Show aggregate replication MRF backlog for a bucket')
            [CompletionResult]::new('diff', 'diff', [CompletionResultType]::ParameterValue, 'Scan for object versions that have not replicated')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove replication rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export replication configuration as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import replication configuration from a JSON file')
            [CompletionResult]::new('check', 'check', [CompletionResultType]::ParameterValue, 'Actively validate configured replication targets')
            [CompletionResult]::new('resync', 'resync', [CompletionResultType]::ParameterValue, 'Manage bucket replication resync operations')
            break
        }
        'rc;bucket;help;replication;add' {
            break
        }
        'rc;bucket;help;replication;update' {
            break
        }
        'rc;bucket;help;replication;list' {
            break
        }
        'rc;bucket;help;replication;status' {
            break
        }
        'rc;bucket;help;replication;mrf' {
            break
        }
        'rc;bucket;help;replication;diff' {
            break
        }
        'rc;bucket;help;replication;remove' {
            break
        }
        'rc;bucket;help;replication;export' {
            break
        }
        'rc;bucket;help;replication;import' {
            break
        }
        'rc;bucket;help;replication;check' {
            break
        }
        'rc;bucket;help;replication;resync' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start resyncing previously replicated objects')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show persisted server-side resync status')
            break
        }
        'rc;bucket;help;replication;resync;start' {
            break
        }
        'rc;bucket;help;replication;resync;status' {
            break
        }
        'rc;bucket;help;help' {
            break
        }
        'rc;object' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List objects within a bucket path')
            [CompletionResult]::new('copy', 'copy', [CompletionResultType]::ParameterValue, 'Copy objects between local and remote locations')
            [CompletionResult]::new('move', 'move', [CompletionResultType]::ParameterValue, 'Move objects between local and remote locations')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove objects')
            [CompletionResult]::new('stat', 'stat', [CompletionResultType]::ParameterValue, 'Show object metadata')
            [CompletionResult]::new('show', 'show', [CompletionResultType]::ParameterValue, 'Print the full object body')
            [CompletionResult]::new('head', 'head', [CompletionResultType]::ParameterValue, 'Print the first lines or bytes of an object')
            [CompletionResult]::new('find', 'find', [CompletionResultType]::ParameterValue, 'Search for objects by filters')
            [CompletionResult]::new('tree', 'tree', [CompletionResultType]::ParameterValue, 'Display objects in a tree view')
            [CompletionResult]::new('share', 'share', [CompletionResultType]::ParameterValue, 'Generate a presigned object URL')
            [CompletionResult]::new('retention', 'retention', [CompletionResultType]::ParameterValue, 'Manage object retention')
            [CompletionResult]::new('legalhold', 'legalhold', [CompletionResultType]::ParameterValue, 'Manage object legal hold')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;object;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'List recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'List recursively')
            [CompletionResult]::new('--versions', '--versions', [CompletionResultType]::ParameterName, 'Show versions (requires versioning support)')
            [CompletionResult]::new('--incomplete', '--incomplete', [CompletionResultType]::ParameterName, 'List incomplete multipart uploads')
            [CompletionResult]::new('--summarize', '--summarize', [CompletionResultType]::ParameterName, 'Summarize output (show totals only)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;copy' {
            [CompletionResult]::new('--metadata-directive', '--metadata-directive', [CompletionResultType]::ParameterName, 'Source metadata handling for remote copies')
            [CompletionResult]::new('--tagging-directive', '--tagging-directive', [CompletionResultType]::ParameterName, 'Source tag handling for remote copies')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite destination if it exists')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class for destination (S3 only)')
            [CompletionResult]::new('--content-type', '--content-type', [CompletionResultType]::ParameterName, 'Content type for uploaded files')
            [CompletionResult]::new('--cache-control', '--cache-control', [CompletionResultType]::ParameterName, 'Cache policy stored with the destination object')
            [CompletionResult]::new('--content-disposition', '--content-disposition', [CompletionResultType]::ParameterName, 'Content-Disposition stored with the destination object')
            [CompletionResult]::new('--content-encoding', '--content-encoding', [CompletionResultType]::ParameterName, 'Content-Encoding stored with the destination object')
            [CompletionResult]::new('--content-language', '--content-language', [CompletionResultType]::ParameterName, 'Content-Language stored with the destination object')
            [CompletionResult]::new('--expires', '--expires', [CompletionResultType]::ParameterName, 'RFC3339 expiry timestamp stored with the destination object')
            [CompletionResult]::new('--metadata', '--metadata', [CompletionResultType]::ParameterName, 'User metadata as KEY=VALUE; may be repeated')
            [CompletionResult]::new('--tags', '--tags', [CompletionResultType]::ParameterName, 'Object tag as KEY=VALUE; may be repeated')
            [CompletionResult]::new('--checksum', '--checksum', [CompletionResultType]::ParameterName, 'Calculate and verify the destination checksum (SHA256 on RustFS beta.10)')
            [CompletionResult]::new('--retention-mode', '--retention-mode', [CompletionResultType]::ParameterName, 'Object retention mode (GOVERNANCE or COMPLIANCE)')
            [CompletionResult]::new('--retain-until', '--retain-until', [CompletionResultType]::ParameterName, 'RFC3339 UTC object retention deadline')
            [CompletionResult]::new('--legal-hold', '--legal-hold', [CompletionResultType]::ParameterName, 'Destination legal-hold state (ON or OFF)')
            [CompletionResult]::new('--enc-s3', '--enc-s3', [CompletionResultType]::ParameterName, 'Apply SSE-S3 to the remote destination path')
            [CompletionResult]::new('--enc-kms', '--enc-kms', [CompletionResultType]::ParameterName, 'Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID')
            [CompletionResult]::new('--enc-c-source-key-file', '--enc-c-source-key-file', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C source key from a protected file')
            [CompletionResult]::new('--enc-c-source-key-env', '--enc-c-source-key-env', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C source key from the named environment variable')
            [CompletionResult]::new('--enc-c-destination-key-file', '--enc-c-destination-key-file', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C destination key from a protected file')
            [CompletionResult]::new('--enc-c-destination-key-env', '--enc-c-destination-key-env', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C destination key from the named environment variable')
            [CompletionResult]::new('--include', '--include', [CompletionResultType]::ParameterName, 'Include source-relative paths matching this glob (repeatable)')
            [CompletionResult]::new('--exclude', '--exclude', [CompletionResultType]::ParameterName, 'Exclude source-relative paths matching this glob; exclusions always win (repeatable)')
            [CompletionResult]::new('--newer-than', '--newer-than', [CompletionResultType]::ParameterName, 'Select objects modified more recently than this age (for example 1h or 7d)')
            [CompletionResult]::new('--older-than', '--older-than', [CompletionResultType]::ParameterName, 'Select objects modified less recently than this age (for example 1h or 7d)')
            [CompletionResult]::new('--rewind', '--rewind', [CompletionResultType]::ParameterName, 'Select object state at or before a UTC timestamp or age')
            [CompletionResult]::new('--concurrency', '--concurrency', [CompletionResultType]::ParameterName, 'Maximum number of transfers in flight across the command')
            [CompletionResult]::new('--rate-limit', '--rate-limit', [CompletionResultType]::ParameterName, 'Aggregate transfer start rate in bytes per second (for example 10MiB/s)')
            [CompletionResult]::new('--retry-attempts', '--retry-attempts', [CompletionResultType]::ParameterName, 'Maximum attempts for transient transfer failures')
            [CompletionResult]::new('--retry-initial-backoff-ms', '--retry-initial-backoff-ms', [CompletionResultType]::ParameterName, 'Initial transient retry backoff in milliseconds')
            [CompletionResult]::new('--retry-max-backoff-ms', '--retry-max-backoff-ms', [CompletionResultType]::ParameterName, 'Maximum transient retry backoff in milliseconds')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Copy recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Copy recursively')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Preserve file attributes')
            [CompletionResult]::new('--preserve', '--preserve', [CompletionResultType]::ParameterName, 'Preserve file attributes')
            [CompletionResult]::new('--continue-on-error', '--continue-on-error', [CompletionResultType]::ParameterName, 'Continue on errors')
            [CompletionResult]::new('--skip-existing', '--skip-existing', [CompletionResultType]::ParameterName, 'Skip remote destinations that already exist')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show what would be copied (dry run)')
            [CompletionResult]::new('--clear-metadata', '--clear-metadata', [CompletionResultType]::ParameterName, 'Replace destination metadata with an explicit empty set')
            [CompletionResult]::new('--clear-tags', '--clear-tags', [CompletionResultType]::ParameterName, 'Replace destination tags with an explicit empty set')
            [CompletionResult]::new('--fail-empty', '--fail-empty', [CompletionResultType]::ParameterName, 'Return not-found when selection produces no transfer candidates')
            [CompletionResult]::new('--summary', '--summary', [CompletionResultType]::ParameterName, 'Print deterministic aggregate transfer counters (human output)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;move' {
            [CompletionResult]::new('--enc-s3', '--enc-s3', [CompletionResultType]::ParameterName, 'Apply SSE-S3 to the remote destination path')
            [CompletionResult]::new('--enc-kms', '--enc-kms', [CompletionResultType]::ParameterName, 'Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Move recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Move recursively')
            [CompletionResult]::new('--continue-on-error', '--continue-on-error', [CompletionResultType]::ParameterName, 'Continue on errors')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show what would be moved (dry run)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;remove' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Remove one exact object version')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Remove recursively (remove all objects with the given prefix)')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Remove recursively (remove all objects with the given prefix)')
            [CompletionResult]::new('-f', '-f', [CompletionResultType]::ParameterName, 'Force removal without confirmation')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force removal without confirmation')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show what would be deleted (dry run)')
            [CompletionResult]::new('--incomplete', '--incomplete', [CompletionResultType]::ParameterName, 'Remove incomplete multipart uploads')
            [CompletionResult]::new('--versions', '--versions', [CompletionResultType]::ParameterName, 'Remove all matching object versions and delete markers')
            [CompletionResult]::new('--bypass', '--bypass', [CompletionResultType]::ParameterName, 'Explicitly bypass Object Lock governance retention')
            [CompletionResult]::new('--purge', '--purge', [CompletionResultType]::ParameterName, 'Permanently delete objects using the RustFS force-delete header')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;stat' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Exact object version ID to inspect')
            [CompletionResult]::new('--rewind', '--rewind', [CompletionResultType]::ParameterName, 'Rewind to a specific time')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;show' {
            [CompletionResult]::new('--enc-key', '--enc-key', [CompletionResultType]::ParameterName, 'Encrypt/decrypt with the given key (base64 encoded)')
            [CompletionResult]::new('--rewind', '--rewind', [CompletionResultType]::ParameterName, 'Rewind to a specific time')
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Specific version ID to retrieve')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;head' {
            [CompletionResult]::new('-n', '-n', [CompletionResultType]::ParameterName, 'Number of lines to display (default: 10)')
            [CompletionResult]::new('--lines', '--lines', [CompletionResultType]::ParameterName, 'Number of lines to display (default: 10)')
            [CompletionResult]::new('-c', '-c', [CompletionResultType]::ParameterName, 'Display first N bytes instead of lines')
            [CompletionResult]::new('--bytes', '--bytes', [CompletionResultType]::ParameterName, 'Display first N bytes instead of lines')
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Specific version ID to retrieve')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;find' {
            [CompletionResult]::new('--name', '--name', [CompletionResultType]::ParameterName, 'Pattern to match object names (glob-style: *, ?)')
            [CompletionResult]::new('--larger', '--larger', [CompletionResultType]::ParameterName, 'Match objects larger than size (e.g., 1K, 1M, 1G)')
            [CompletionResult]::new('--smaller', '--smaller', [CompletionResultType]::ParameterName, 'Match objects smaller than size (e.g., 1K, 1M, 1G)')
            [CompletionResult]::new('--newer', '--newer', [CompletionResultType]::ParameterName, 'Match objects newer than duration (e.g., 1h, 1d, 7d)')
            [CompletionResult]::new('--older', '--older', [CompletionResultType]::ParameterName, 'Match objects older than duration (e.g., 1h, 1d, 7d)')
            [CompletionResult]::new('--maxdepth', '--maxdepth', [CompletionResultType]::ParameterName, 'Maximum depth to search (0 = unlimited)')
            [CompletionResult]::new('--exec', '--exec', [CompletionResultType]::ParameterName, 'Execute command for each match (use {} as placeholder)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--count', '--count', [CompletionResultType]::ParameterName, 'Print only count of matches')
            [CompletionResult]::new('--print', '--print', [CompletionResultType]::ParameterName, 'Print full path (default: relative to search path)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;tree' {
            [CompletionResult]::new('-L', '-L ', [CompletionResultType]::ParameterName, 'Maximum depth to display')
            [CompletionResult]::new('--level', '--level', [CompletionResultType]::ParameterName, 'Maximum depth to display')
            [CompletionResult]::new('-P', '-P ', [CompletionResultType]::ParameterName, 'Pattern to include (glob-style)')
            [CompletionResult]::new('--pattern', '--pattern', [CompletionResultType]::ParameterName, 'Pattern to include (glob-style)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-s', '-s', [CompletionResultType]::ParameterName, 'Show file sizes')
            [CompletionResult]::new('--size', '--size', [CompletionResultType]::ParameterName, 'Show file sizes')
            [CompletionResult]::new('-d', '-d', [CompletionResultType]::ParameterName, 'Show only directories')
            [CompletionResult]::new('--dirs-only', '--dirs-only', [CompletionResultType]::ParameterName, 'Show only directories')
            [CompletionResult]::new('-f', '-f', [CompletionResultType]::ParameterName, 'Show full path prefix')
            [CompletionResult]::new('--full-path', '--full-path', [CompletionResultType]::ParameterName, 'Show full path prefix')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;share' {
            [CompletionResult]::new('-e', '-e', [CompletionResultType]::ParameterName, 'Expiration time (e.g., 1h, 1d, 7d). Default: 7d')
            [CompletionResult]::new('--expire', '--expire', [CompletionResultType]::ParameterName, 'Expiration time (e.g., 1h, 1d, 7d). Default: 7d')
            [CompletionResult]::new('--content-type', '--content-type', [CompletionResultType]::ParameterName, 'Content-Type for upload URL')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--upload', '--upload', [CompletionResultType]::ParameterName, 'Generate upload URL instead of download URL')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;retention' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show retention for an object version or a bucket default')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set retention for an object version or a bucket default')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear retention for an object version or a bucket default')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;object;retention;info' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Read one exact object version')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--default', '--default', [CompletionResultType]::ParameterName, 'Read bucket default retention instead of object retention')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;retention;set' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Mutate one exact object version')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--bypass', '--bypass', [CompletionResultType]::ParameterName, 'Explicitly request governance retention bypass')
            [CompletionResult]::new('--default', '--default', [CompletionResultType]::ParameterName, 'Set bucket default retention instead of object retention')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;retention;clear' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Mutate one exact object version')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--bypass', '--bypass', [CompletionResultType]::ParameterName, 'Explicitly request governance retention bypass')
            [CompletionResult]::new('--default', '--default', [CompletionResultType]::ParameterName, 'Clear bucket default retention instead of object retention')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;retention;help' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show retention for an object version or a bucket default')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set retention for an object version or a bucket default')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear retention for an object version or a bucket default')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;object;retention;help;info' {
            break
        }
        'rc;object;retention;help;set' {
            break
        }
        'rc;object;retention;help;clear' {
            break
        }
        'rc;object;retention;help;help' {
            break
        }
        'rc;object;legalhold' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show legal-hold status')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set legal hold to ON')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Set legal hold to OFF')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;object;legalhold;info' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Read or mutate one exact object version')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;legalhold;set' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Read or mutate one exact object version')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;legalhold;clear' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Read or mutate one exact object version')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;legalhold;help' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show legal-hold status')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set legal hold to ON')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Set legal hold to OFF')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;object;legalhold;help;info' {
            break
        }
        'rc;object;legalhold;help;set' {
            break
        }
        'rc;object;legalhold;help;clear' {
            break
        }
        'rc;object;legalhold;help;help' {
            break
        }
        'rc;object;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List objects within a bucket path')
            [CompletionResult]::new('copy', 'copy', [CompletionResultType]::ParameterValue, 'Copy objects between local and remote locations')
            [CompletionResult]::new('move', 'move', [CompletionResultType]::ParameterValue, 'Move objects between local and remote locations')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove objects')
            [CompletionResult]::new('stat', 'stat', [CompletionResultType]::ParameterValue, 'Show object metadata')
            [CompletionResult]::new('show', 'show', [CompletionResultType]::ParameterValue, 'Print the full object body')
            [CompletionResult]::new('head', 'head', [CompletionResultType]::ParameterValue, 'Print the first lines or bytes of an object')
            [CompletionResult]::new('find', 'find', [CompletionResultType]::ParameterValue, 'Search for objects by filters')
            [CompletionResult]::new('tree', 'tree', [CompletionResultType]::ParameterValue, 'Display objects in a tree view')
            [CompletionResult]::new('share', 'share', [CompletionResultType]::ParameterValue, 'Generate a presigned object URL')
            [CompletionResult]::new('retention', 'retention', [CompletionResultType]::ParameterValue, 'Manage object retention')
            [CompletionResult]::new('legalhold', 'legalhold', [CompletionResultType]::ParameterValue, 'Manage object legal hold')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;object;help;list' {
            break
        }
        'rc;object;help;copy' {
            break
        }
        'rc;object;help;move' {
            break
        }
        'rc;object;help;remove' {
            break
        }
        'rc;object;help;stat' {
            break
        }
        'rc;object;help;show' {
            break
        }
        'rc;object;help;head' {
            break
        }
        'rc;object;help;find' {
            break
        }
        'rc;object;help;tree' {
            break
        }
        'rc;object;help;share' {
            break
        }
        'rc;object;help;retention' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show retention for an object version or a bucket default')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set retention for an object version or a bucket default')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear retention for an object version or a bucket default')
            break
        }
        'rc;object;help;retention;info' {
            break
        }
        'rc;object;help;retention;set' {
            break
        }
        'rc;object;help;retention;clear' {
            break
        }
        'rc;object;help;legalhold' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show legal-hold status')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set legal hold to ON')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Set legal hold to OFF')
            break
        }
        'rc;object;help;legalhold;info' {
            break
        }
        'rc;object;help;legalhold;set' {
            break
        }
        'rc;object;help;legalhold;clear' {
            break
        }
        'rc;object;help;help' {
            break
        }
        'rc;ls' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'List recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'List recursively')
            [CompletionResult]::new('--versions', '--versions', [CompletionResultType]::ParameterName, 'Show versions (requires versioning support)')
            [CompletionResult]::new('--incomplete', '--incomplete', [CompletionResultType]::ParameterName, 'List incomplete multipart uploads')
            [CompletionResult]::new('--summarize', '--summarize', [CompletionResultType]::ParameterName, 'Summarize output (show totals only)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;mb' {
            [CompletionResult]::new('--region', '--region', [CompletionResultType]::ParameterName, 'Region for the bucket (overrides alias default)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Ignore error if bucket already exists')
            [CompletionResult]::new('--ignore-existing', '--ignore-existing', [CompletionResultType]::ParameterName, 'Ignore error if bucket already exists')
            [CompletionResult]::new('--with-lock', '--with-lock', [CompletionResultType]::ParameterName, 'Enable object locking on the bucket')
            [CompletionResult]::new('--with-versioning', '--with-versioning', [CompletionResultType]::ParameterName, 'Enable versioning on the bucket')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;rb' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Delete bucket contents before removing the bucket')
            [CompletionResult]::new('--dangerous', '--dangerous', [CompletionResultType]::ParameterName, 'Permit aborting discovered incomplete multipart uploads')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm the dangerous multipart cleanup')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;cat' {
            [CompletionResult]::new('--enc-key', '--enc-key', [CompletionResultType]::ParameterName, 'Encrypt/decrypt with the given key (base64 encoded)')
            [CompletionResult]::new('--rewind', '--rewind', [CompletionResultType]::ParameterName, 'Rewind to a specific time')
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Specific version ID to retrieve')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;head' {
            [CompletionResult]::new('-n', '-n', [CompletionResultType]::ParameterName, 'Number of lines to display (default: 10)')
            [CompletionResult]::new('--lines', '--lines', [CompletionResultType]::ParameterName, 'Number of lines to display (default: 10)')
            [CompletionResult]::new('-c', '-c', [CompletionResultType]::ParameterName, 'Display first N bytes instead of lines')
            [CompletionResult]::new('--bytes', '--bytes', [CompletionResultType]::ParameterName, 'Display first N bytes instead of lines')
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Specific version ID to retrieve')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;stat' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Exact object version ID to inspect')
            [CompletionResult]::new('--rewind', '--rewind', [CompletionResultType]::ParameterName, 'Rewind to a specific time')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;cp' {
            [CompletionResult]::new('--metadata-directive', '--metadata-directive', [CompletionResultType]::ParameterName, 'Source metadata handling for remote copies')
            [CompletionResult]::new('--tagging-directive', '--tagging-directive', [CompletionResultType]::ParameterName, 'Source tag handling for remote copies')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite destination if it exists')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class for destination (S3 only)')
            [CompletionResult]::new('--content-type', '--content-type', [CompletionResultType]::ParameterName, 'Content type for uploaded files')
            [CompletionResult]::new('--cache-control', '--cache-control', [CompletionResultType]::ParameterName, 'Cache policy stored with the destination object')
            [CompletionResult]::new('--content-disposition', '--content-disposition', [CompletionResultType]::ParameterName, 'Content-Disposition stored with the destination object')
            [CompletionResult]::new('--content-encoding', '--content-encoding', [CompletionResultType]::ParameterName, 'Content-Encoding stored with the destination object')
            [CompletionResult]::new('--content-language', '--content-language', [CompletionResultType]::ParameterName, 'Content-Language stored with the destination object')
            [CompletionResult]::new('--expires', '--expires', [CompletionResultType]::ParameterName, 'RFC3339 expiry timestamp stored with the destination object')
            [CompletionResult]::new('--metadata', '--metadata', [CompletionResultType]::ParameterName, 'User metadata as KEY=VALUE; may be repeated')
            [CompletionResult]::new('--tags', '--tags', [CompletionResultType]::ParameterName, 'Object tag as KEY=VALUE; may be repeated')
            [CompletionResult]::new('--checksum', '--checksum', [CompletionResultType]::ParameterName, 'Calculate and verify the destination checksum (SHA256 on RustFS beta.10)')
            [CompletionResult]::new('--retention-mode', '--retention-mode', [CompletionResultType]::ParameterName, 'Object retention mode (GOVERNANCE or COMPLIANCE)')
            [CompletionResult]::new('--retain-until', '--retain-until', [CompletionResultType]::ParameterName, 'RFC3339 UTC object retention deadline')
            [CompletionResult]::new('--legal-hold', '--legal-hold', [CompletionResultType]::ParameterName, 'Destination legal-hold state (ON or OFF)')
            [CompletionResult]::new('--enc-s3', '--enc-s3', [CompletionResultType]::ParameterName, 'Apply SSE-S3 to the remote destination path')
            [CompletionResult]::new('--enc-kms', '--enc-kms', [CompletionResultType]::ParameterName, 'Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID')
            [CompletionResult]::new('--enc-c-source-key-file', '--enc-c-source-key-file', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C source key from a protected file')
            [CompletionResult]::new('--enc-c-source-key-env', '--enc-c-source-key-env', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C source key from the named environment variable')
            [CompletionResult]::new('--enc-c-destination-key-file', '--enc-c-destination-key-file', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C destination key from a protected file')
            [CompletionResult]::new('--enc-c-destination-key-env', '--enc-c-destination-key-env', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C destination key from the named environment variable')
            [CompletionResult]::new('--include', '--include', [CompletionResultType]::ParameterName, 'Include source-relative paths matching this glob (repeatable)')
            [CompletionResult]::new('--exclude', '--exclude', [CompletionResultType]::ParameterName, 'Exclude source-relative paths matching this glob; exclusions always win (repeatable)')
            [CompletionResult]::new('--newer-than', '--newer-than', [CompletionResultType]::ParameterName, 'Select objects modified more recently than this age (for example 1h or 7d)')
            [CompletionResult]::new('--older-than', '--older-than', [CompletionResultType]::ParameterName, 'Select objects modified less recently than this age (for example 1h or 7d)')
            [CompletionResult]::new('--rewind', '--rewind', [CompletionResultType]::ParameterName, 'Select object state at or before a UTC timestamp or age')
            [CompletionResult]::new('--concurrency', '--concurrency', [CompletionResultType]::ParameterName, 'Maximum number of transfers in flight across the command')
            [CompletionResult]::new('--rate-limit', '--rate-limit', [CompletionResultType]::ParameterName, 'Aggregate transfer start rate in bytes per second (for example 10MiB/s)')
            [CompletionResult]::new('--retry-attempts', '--retry-attempts', [CompletionResultType]::ParameterName, 'Maximum attempts for transient transfer failures')
            [CompletionResult]::new('--retry-initial-backoff-ms', '--retry-initial-backoff-ms', [CompletionResultType]::ParameterName, 'Initial transient retry backoff in milliseconds')
            [CompletionResult]::new('--retry-max-backoff-ms', '--retry-max-backoff-ms', [CompletionResultType]::ParameterName, 'Maximum transient retry backoff in milliseconds')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Copy recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Copy recursively')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Preserve file attributes')
            [CompletionResult]::new('--preserve', '--preserve', [CompletionResultType]::ParameterName, 'Preserve file attributes')
            [CompletionResult]::new('--continue-on-error', '--continue-on-error', [CompletionResultType]::ParameterName, 'Continue on errors')
            [CompletionResult]::new('--skip-existing', '--skip-existing', [CompletionResultType]::ParameterName, 'Skip remote destinations that already exist')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show what would be copied (dry run)')
            [CompletionResult]::new('--clear-metadata', '--clear-metadata', [CompletionResultType]::ParameterName, 'Replace destination metadata with an explicit empty set')
            [CompletionResult]::new('--clear-tags', '--clear-tags', [CompletionResultType]::ParameterName, 'Replace destination tags with an explicit empty set')
            [CompletionResult]::new('--fail-empty', '--fail-empty', [CompletionResultType]::ParameterName, 'Return not-found when selection produces no transfer candidates')
            [CompletionResult]::new('--summary', '--summary', [CompletionResultType]::ParameterName, 'Print deterministic aggregate transfer counters (human output)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;get' {
            [CompletionResult]::new('--metadata-directive', '--metadata-directive', [CompletionResultType]::ParameterName, 'Source metadata handling for remote copies')
            [CompletionResult]::new('--tagging-directive', '--tagging-directive', [CompletionResultType]::ParameterName, 'Source tag handling for remote copies')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite destination if it exists')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class for destination (S3 only)')
            [CompletionResult]::new('--content-type', '--content-type', [CompletionResultType]::ParameterName, 'Content type for uploaded files')
            [CompletionResult]::new('--cache-control', '--cache-control', [CompletionResultType]::ParameterName, 'Cache policy stored with the destination object')
            [CompletionResult]::new('--content-disposition', '--content-disposition', [CompletionResultType]::ParameterName, 'Content-Disposition stored with the destination object')
            [CompletionResult]::new('--content-encoding', '--content-encoding', [CompletionResultType]::ParameterName, 'Content-Encoding stored with the destination object')
            [CompletionResult]::new('--content-language', '--content-language', [CompletionResultType]::ParameterName, 'Content-Language stored with the destination object')
            [CompletionResult]::new('--expires', '--expires', [CompletionResultType]::ParameterName, 'RFC3339 expiry timestamp stored with the destination object')
            [CompletionResult]::new('--metadata', '--metadata', [CompletionResultType]::ParameterName, 'User metadata as KEY=VALUE; may be repeated')
            [CompletionResult]::new('--tags', '--tags', [CompletionResultType]::ParameterName, 'Object tag as KEY=VALUE; may be repeated')
            [CompletionResult]::new('--checksum', '--checksum', [CompletionResultType]::ParameterName, 'Calculate and verify the destination checksum (SHA256 on RustFS beta.10)')
            [CompletionResult]::new('--retention-mode', '--retention-mode', [CompletionResultType]::ParameterName, 'Object retention mode (GOVERNANCE or COMPLIANCE)')
            [CompletionResult]::new('--retain-until', '--retain-until', [CompletionResultType]::ParameterName, 'RFC3339 UTC object retention deadline')
            [CompletionResult]::new('--legal-hold', '--legal-hold', [CompletionResultType]::ParameterName, 'Destination legal-hold state (ON or OFF)')
            [CompletionResult]::new('--enc-s3', '--enc-s3', [CompletionResultType]::ParameterName, 'Apply SSE-S3 to the remote destination path')
            [CompletionResult]::new('--enc-kms', '--enc-kms', [CompletionResultType]::ParameterName, 'Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID')
            [CompletionResult]::new('--enc-c-source-key-file', '--enc-c-source-key-file', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C source key from a protected file')
            [CompletionResult]::new('--enc-c-source-key-env', '--enc-c-source-key-env', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C source key from the named environment variable')
            [CompletionResult]::new('--enc-c-destination-key-file', '--enc-c-destination-key-file', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C destination key from a protected file')
            [CompletionResult]::new('--enc-c-destination-key-env', '--enc-c-destination-key-env', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C destination key from the named environment variable')
            [CompletionResult]::new('--include', '--include', [CompletionResultType]::ParameterName, 'Include source-relative paths matching this glob (repeatable)')
            [CompletionResult]::new('--exclude', '--exclude', [CompletionResultType]::ParameterName, 'Exclude source-relative paths matching this glob; exclusions always win (repeatable)')
            [CompletionResult]::new('--newer-than', '--newer-than', [CompletionResultType]::ParameterName, 'Select objects modified more recently than this age (for example 1h or 7d)')
            [CompletionResult]::new('--older-than', '--older-than', [CompletionResultType]::ParameterName, 'Select objects modified less recently than this age (for example 1h or 7d)')
            [CompletionResult]::new('--rewind', '--rewind', [CompletionResultType]::ParameterName, 'Select object state at or before a UTC timestamp or age')
            [CompletionResult]::new('--concurrency', '--concurrency', [CompletionResultType]::ParameterName, 'Maximum number of transfers in flight across the command')
            [CompletionResult]::new('--rate-limit', '--rate-limit', [CompletionResultType]::ParameterName, 'Aggregate transfer start rate in bytes per second (for example 10MiB/s)')
            [CompletionResult]::new('--retry-attempts', '--retry-attempts', [CompletionResultType]::ParameterName, 'Maximum attempts for transient transfer failures')
            [CompletionResult]::new('--retry-initial-backoff-ms', '--retry-initial-backoff-ms', [CompletionResultType]::ParameterName, 'Initial transient retry backoff in milliseconds')
            [CompletionResult]::new('--retry-max-backoff-ms', '--retry-max-backoff-ms', [CompletionResultType]::ParameterName, 'Maximum transient retry backoff in milliseconds')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Copy recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Copy recursively')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Preserve file attributes')
            [CompletionResult]::new('--preserve', '--preserve', [CompletionResultType]::ParameterName, 'Preserve file attributes')
            [CompletionResult]::new('--continue-on-error', '--continue-on-error', [CompletionResultType]::ParameterName, 'Continue on errors')
            [CompletionResult]::new('--skip-existing', '--skip-existing', [CompletionResultType]::ParameterName, 'Skip remote destinations that already exist')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show what would be copied (dry run)')
            [CompletionResult]::new('--clear-metadata', '--clear-metadata', [CompletionResultType]::ParameterName, 'Replace destination metadata with an explicit empty set')
            [CompletionResult]::new('--clear-tags', '--clear-tags', [CompletionResultType]::ParameterName, 'Replace destination tags with an explicit empty set')
            [CompletionResult]::new('--fail-empty', '--fail-empty', [CompletionResultType]::ParameterName, 'Return not-found when selection produces no transfer candidates')
            [CompletionResult]::new('--summary', '--summary', [CompletionResultType]::ParameterName, 'Print deterministic aggregate transfer counters (human output)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;put' {
            [CompletionResult]::new('--metadata-directive', '--metadata-directive', [CompletionResultType]::ParameterName, 'Source metadata handling for remote copies')
            [CompletionResult]::new('--tagging-directive', '--tagging-directive', [CompletionResultType]::ParameterName, 'Source tag handling for remote copies')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite destination if it exists')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class for destination (S3 only)')
            [CompletionResult]::new('--content-type', '--content-type', [CompletionResultType]::ParameterName, 'Content type for uploaded files')
            [CompletionResult]::new('--cache-control', '--cache-control', [CompletionResultType]::ParameterName, 'Cache policy stored with the destination object')
            [CompletionResult]::new('--content-disposition', '--content-disposition', [CompletionResultType]::ParameterName, 'Content-Disposition stored with the destination object')
            [CompletionResult]::new('--content-encoding', '--content-encoding', [CompletionResultType]::ParameterName, 'Content-Encoding stored with the destination object')
            [CompletionResult]::new('--content-language', '--content-language', [CompletionResultType]::ParameterName, 'Content-Language stored with the destination object')
            [CompletionResult]::new('--expires', '--expires', [CompletionResultType]::ParameterName, 'RFC3339 expiry timestamp stored with the destination object')
            [CompletionResult]::new('--metadata', '--metadata', [CompletionResultType]::ParameterName, 'User metadata as KEY=VALUE; may be repeated')
            [CompletionResult]::new('--tags', '--tags', [CompletionResultType]::ParameterName, 'Object tag as KEY=VALUE; may be repeated')
            [CompletionResult]::new('--checksum', '--checksum', [CompletionResultType]::ParameterName, 'Calculate and verify the destination checksum (SHA256 on RustFS beta.10)')
            [CompletionResult]::new('--retention-mode', '--retention-mode', [CompletionResultType]::ParameterName, 'Object retention mode (GOVERNANCE or COMPLIANCE)')
            [CompletionResult]::new('--retain-until', '--retain-until', [CompletionResultType]::ParameterName, 'RFC3339 UTC object retention deadline')
            [CompletionResult]::new('--legal-hold', '--legal-hold', [CompletionResultType]::ParameterName, 'Destination legal-hold state (ON or OFF)')
            [CompletionResult]::new('--enc-s3', '--enc-s3', [CompletionResultType]::ParameterName, 'Apply SSE-S3 to the remote destination path')
            [CompletionResult]::new('--enc-kms', '--enc-kms', [CompletionResultType]::ParameterName, 'Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID')
            [CompletionResult]::new('--enc-c-source-key-file', '--enc-c-source-key-file', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C source key from a protected file')
            [CompletionResult]::new('--enc-c-source-key-env', '--enc-c-source-key-env', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C source key from the named environment variable')
            [CompletionResult]::new('--enc-c-destination-key-file', '--enc-c-destination-key-file', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C destination key from a protected file')
            [CompletionResult]::new('--enc-c-destination-key-env', '--enc-c-destination-key-env', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C destination key from the named environment variable')
            [CompletionResult]::new('--include', '--include', [CompletionResultType]::ParameterName, 'Include source-relative paths matching this glob (repeatable)')
            [CompletionResult]::new('--exclude', '--exclude', [CompletionResultType]::ParameterName, 'Exclude source-relative paths matching this glob; exclusions always win (repeatable)')
            [CompletionResult]::new('--newer-than', '--newer-than', [CompletionResultType]::ParameterName, 'Select objects modified more recently than this age (for example 1h or 7d)')
            [CompletionResult]::new('--older-than', '--older-than', [CompletionResultType]::ParameterName, 'Select objects modified less recently than this age (for example 1h or 7d)')
            [CompletionResult]::new('--rewind', '--rewind', [CompletionResultType]::ParameterName, 'Select object state at or before a UTC timestamp or age')
            [CompletionResult]::new('--concurrency', '--concurrency', [CompletionResultType]::ParameterName, 'Maximum number of transfers in flight across the command')
            [CompletionResult]::new('--rate-limit', '--rate-limit', [CompletionResultType]::ParameterName, 'Aggregate transfer start rate in bytes per second (for example 10MiB/s)')
            [CompletionResult]::new('--retry-attempts', '--retry-attempts', [CompletionResultType]::ParameterName, 'Maximum attempts for transient transfer failures')
            [CompletionResult]::new('--retry-initial-backoff-ms', '--retry-initial-backoff-ms', [CompletionResultType]::ParameterName, 'Initial transient retry backoff in milliseconds')
            [CompletionResult]::new('--retry-max-backoff-ms', '--retry-max-backoff-ms', [CompletionResultType]::ParameterName, 'Maximum transient retry backoff in milliseconds')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Copy recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Copy recursively')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Preserve file attributes')
            [CompletionResult]::new('--preserve', '--preserve', [CompletionResultType]::ParameterName, 'Preserve file attributes')
            [CompletionResult]::new('--continue-on-error', '--continue-on-error', [CompletionResultType]::ParameterName, 'Continue on errors')
            [CompletionResult]::new('--skip-existing', '--skip-existing', [CompletionResultType]::ParameterName, 'Skip remote destinations that already exist')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show what would be copied (dry run)')
            [CompletionResult]::new('--clear-metadata', '--clear-metadata', [CompletionResultType]::ParameterName, 'Replace destination metadata with an explicit empty set')
            [CompletionResult]::new('--clear-tags', '--clear-tags', [CompletionResultType]::ParameterName, 'Replace destination tags with an explicit empty set')
            [CompletionResult]::new('--fail-empty', '--fail-empty', [CompletionResultType]::ParameterName, 'Return not-found when selection produces no transfer candidates')
            [CompletionResult]::new('--summary', '--summary', [CompletionResultType]::ParameterName, 'Print deterministic aggregate transfer counters (human output)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;mv' {
            [CompletionResult]::new('--enc-s3', '--enc-s3', [CompletionResultType]::ParameterName, 'Apply SSE-S3 to the remote destination path')
            [CompletionResult]::new('--enc-kms', '--enc-kms', [CompletionResultType]::ParameterName, 'Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Move recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Move recursively')
            [CompletionResult]::new('--continue-on-error', '--continue-on-error', [CompletionResultType]::ParameterName, 'Continue on errors')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show what would be moved (dry run)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;rm' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Remove one exact object version')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Remove recursively (remove all objects with the given prefix)')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Remove recursively (remove all objects with the given prefix)')
            [CompletionResult]::new('-f', '-f', [CompletionResultType]::ParameterName, 'Force removal without confirmation')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force removal without confirmation')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show what would be deleted (dry run)')
            [CompletionResult]::new('--incomplete', '--incomplete', [CompletionResultType]::ParameterName, 'Remove incomplete multipart uploads')
            [CompletionResult]::new('--versions', '--versions', [CompletionResultType]::ParameterName, 'Remove all matching object versions and delete markers')
            [CompletionResult]::new('--bypass', '--bypass', [CompletionResultType]::ParameterName, 'Explicitly bypass Object Lock governance retention')
            [CompletionResult]::new('--purge', '--purge', [CompletionResultType]::ParameterName, 'Permanently delete objects using the RustFS force-delete header')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;undo' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Restore this exact data version or remove this exact current delete marker')
            [CompletionResult]::new('--concurrency', '--concurrency', [CompletionResultType]::ParameterName, 'Maximum number of object mutations in flight')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Plan all reversible objects under the prefix')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Plan all reversible objects under the prefix')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Show the complete plan without making changes')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;pipe' {
            [CompletionResult]::new('--content-type', '--content-type', [CompletionResultType]::ParameterName, 'Content type for the uploaded object')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class for the object')
            [CompletionResult]::new('--cache-control', '--cache-control', [CompletionResultType]::ParameterName, 'Cache policy stored with the destination object')
            [CompletionResult]::new('--content-disposition', '--content-disposition', [CompletionResultType]::ParameterName, 'Content-Disposition stored with the destination object')
            [CompletionResult]::new('--content-encoding', '--content-encoding', [CompletionResultType]::ParameterName, 'Content-Encoding stored with the destination object')
            [CompletionResult]::new('--content-language', '--content-language', [CompletionResultType]::ParameterName, 'Content-Language stored with the destination object')
            [CompletionResult]::new('--expires', '--expires', [CompletionResultType]::ParameterName, 'RFC3339 expiry timestamp stored with the destination object')
            [CompletionResult]::new('--metadata', '--metadata', [CompletionResultType]::ParameterName, 'User metadata as KEY=VALUE; may be repeated')
            [CompletionResult]::new('--tags', '--tags', [CompletionResultType]::ParameterName, 'Object tag as KEY=VALUE; may be repeated')
            [CompletionResult]::new('--checksum', '--checksum', [CompletionResultType]::ParameterName, 'Calculate and verify the destination checksum (SHA256 on RustFS beta.10)')
            [CompletionResult]::new('--retention-mode', '--retention-mode', [CompletionResultType]::ParameterName, 'Object retention mode (GOVERNANCE or COMPLIANCE)')
            [CompletionResult]::new('--retain-until', '--retain-until', [CompletionResultType]::ParameterName, 'RFC3339 UTC object retention deadline')
            [CompletionResult]::new('--legal-hold', '--legal-hold', [CompletionResultType]::ParameterName, 'Destination legal-hold state (ON or OFF)')
            [CompletionResult]::new('--enc-kms', '--enc-kms', [CompletionResultType]::ParameterName, 'Apply SSE-KMS to the upload target')
            [CompletionResult]::new('--enc-c-key-file', '--enc-c-key-file', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C destination key from a protected file')
            [CompletionResult]::new('--enc-c-key-env', '--enc-c-key-env', [CompletionResultType]::ParameterName, 'Read a 32-byte SSE-C destination key from the named environment variable')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--clear-metadata', '--clear-metadata', [CompletionResultType]::ParameterName, 'Replace destination metadata with an explicit empty set')
            [CompletionResult]::new('--clear-tags', '--clear-tags', [CompletionResultType]::ParameterName, 'Replace destination tags with an explicit empty set')
            [CompletionResult]::new('--enc-s3', '--enc-s3', [CompletionResultType]::ParameterName, 'Apply SSE-S3 to the upload target')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;find' {
            [CompletionResult]::new('--name', '--name', [CompletionResultType]::ParameterName, 'Pattern to match object names (glob-style: *, ?)')
            [CompletionResult]::new('--larger', '--larger', [CompletionResultType]::ParameterName, 'Match objects larger than size (e.g., 1K, 1M, 1G)')
            [CompletionResult]::new('--smaller', '--smaller', [CompletionResultType]::ParameterName, 'Match objects smaller than size (e.g., 1K, 1M, 1G)')
            [CompletionResult]::new('--newer', '--newer', [CompletionResultType]::ParameterName, 'Match objects newer than duration (e.g., 1h, 1d, 7d)')
            [CompletionResult]::new('--older', '--older', [CompletionResultType]::ParameterName, 'Match objects older than duration (e.g., 1h, 1d, 7d)')
            [CompletionResult]::new('--maxdepth', '--maxdepth', [CompletionResultType]::ParameterName, 'Maximum depth to search (0 = unlimited)')
            [CompletionResult]::new('--exec', '--exec', [CompletionResultType]::ParameterName, 'Execute command for each match (use {} as placeholder)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--count', '--count', [CompletionResultType]::ParameterName, 'Print only count of matches')
            [CompletionResult]::new('--print', '--print', [CompletionResultType]::ParameterName, 'Print full path (default: relative to search path)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;event' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add or replace a bucket notification rule for an ARN')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket notification rules')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket notification rules by target ARN')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;event;add' {
            [CompletionResult]::new('--event', '--event', [CompletionResultType]::ParameterName, 'Event pattern (repeatable; comma-separated values are also accepted)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;event;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;event;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;event;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add or replace a bucket notification rule for an ARN')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket notification rules')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket notification rules by target ARN')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;event;help;add' {
            break
        }
        'rc;event;help;list' {
            break
        }
        'rc;event;help;remove' {
            break
        }
        'rc;event;help;help' {
            break
        }
        'rc;cors' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket CORS rules')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Replace bucket CORS rules from a JSON or XML file')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket CORS rules')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;cors;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;cors;set' {
            [CompletionResult]::new('--file', '--file', [CompletionResultType]::ParameterName, 'Path to the CORS configuration file, or ''-'' to read from stdin')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;cors;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;cors;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket CORS rules')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Replace bucket CORS rules from a JSON or XML file')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket CORS rules')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;cors;help;list' {
            break
        }
        'rc;cors;help;set' {
            break
        }
        'rc;cors;help;remove' {
            break
        }
        'rc;cors;help;help' {
            break
        }
        'rc;diff' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Recursive comparison')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Recursive comparison')
            [CompletionResult]::new('--diff-only', '--diff-only', [CompletionResultType]::ParameterName, 'Show only differences (default: show all)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;mirror' {
            [CompletionResult]::new('--include', '--include', [CompletionResultType]::ParameterName, 'Include source-relative paths matching this glob (repeatable)')
            [CompletionResult]::new('--exclude', '--exclude', [CompletionResultType]::ParameterName, 'Exclude source-relative paths matching this glob; exclusions always win (repeatable)')
            [CompletionResult]::new('--newer-than', '--newer-than', [CompletionResultType]::ParameterName, 'Select files modified more recently than this age (for example 1h or 7d)')
            [CompletionResult]::new('--older-than', '--older-than', [CompletionResultType]::ParameterName, 'Select files modified less recently than this age (for example 1h or 7d)')
            [CompletionResult]::new('-P', '-P ', [CompletionResultType]::ParameterName, 'Maximum number of operations in flight across the command')
            [CompletionResult]::new('--concurrency', '--concurrency', [CompletionResultType]::ParameterName, 'Maximum number of operations in flight across the command')
            [CompletionResult]::new('--parallel', '--parallel', [CompletionResultType]::ParameterName, 'Maximum number of operations in flight across the command')
            [CompletionResult]::new('--rate-limit', '--rate-limit', [CompletionResultType]::ParameterName, 'Aggregate transfer start rate in bytes per second (for example 10MiB/s)')
            [CompletionResult]::new('--retry-attempts', '--retry-attempts', [CompletionResultType]::ParameterName, 'Maximum attempts for transient transfer failures')
            [CompletionResult]::new('--retry-initial-backoff-ms', '--retry-initial-backoff-ms', [CompletionResultType]::ParameterName, 'Initial transient retry backoff in milliseconds')
            [CompletionResult]::new('--retry-max-backoff-ms', '--retry-max-backoff-ms', [CompletionResultType]::ParameterName, 'Maximum transient retry backoff in milliseconds')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--remove', '--remove', [CompletionResultType]::ParameterName, 'Remove destination files that are absent from the selected source tree')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite changed destination files')
            [CompletionResult]::new('--continue-on-error', '--continue-on-error', [CompletionResultType]::ParameterName, 'Continue after per-file failures')
            [CompletionResult]::new('--skip-errors', '--skip-errors', [CompletionResultType]::ParameterName, 'Continue after per-file failures')
            [CompletionResult]::new('-n', '-n', [CompletionResultType]::ParameterName, 'Only show the deterministic plan without writing or deleting')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show the deterministic plan without writing or deleting')
            [CompletionResult]::new('--summary', '--summary', [CompletionResultType]::ParameterName, 'Print deterministic aggregate transfer counters')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error mirror output (legacy command-local alias)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;tree' {
            [CompletionResult]::new('-L', '-L ', [CompletionResultType]::ParameterName, 'Maximum depth to display')
            [CompletionResult]::new('--level', '--level', [CompletionResultType]::ParameterName, 'Maximum depth to display')
            [CompletionResult]::new('-P', '-P ', [CompletionResultType]::ParameterName, 'Pattern to include (glob-style)')
            [CompletionResult]::new('--pattern', '--pattern', [CompletionResultType]::ParameterName, 'Pattern to include (glob-style)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-s', '-s', [CompletionResultType]::ParameterName, 'Show file sizes')
            [CompletionResult]::new('--size', '--size', [CompletionResultType]::ParameterName, 'Show file sizes')
            [CompletionResult]::new('-d', '-d', [CompletionResultType]::ParameterName, 'Show only directories')
            [CompletionResult]::new('--dirs-only', '--dirs-only', [CompletionResultType]::ParameterName, 'Show only directories')
            [CompletionResult]::new('-f', '-f', [CompletionResultType]::ParameterName, 'Show full path prefix')
            [CompletionResult]::new('--full-path', '--full-path', [CompletionResultType]::ParameterName, 'Show full path prefix')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;share' {
            [CompletionResult]::new('-e', '-e', [CompletionResultType]::ParameterName, 'Expiration time (e.g., 1h, 1d, 7d). Default: 7d')
            [CompletionResult]::new('--expire', '--expire', [CompletionResultType]::ParameterName, 'Expiration time (e.g., 1h, 1d, 7d). Default: 7d')
            [CompletionResult]::new('--content-type', '--content-type', [CompletionResultType]::ParameterName, 'Content-Type for upload URL')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--upload', '--upload', [CompletionResultType]::ParameterName, 'Generate upload URL instead of download URL')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;sql' {
            [CompletionResult]::new('--query', '--query', [CompletionResultType]::ParameterName, 'SQL expression (S3 Select)')
            [CompletionResult]::new('--input-format', '--input-format', [CompletionResultType]::ParameterName, 'Input object format')
            [CompletionResult]::new('--output-format', '--output-format', [CompletionResultType]::ParameterName, 'Select result format')
            [CompletionResult]::new('--compression', '--compression', [CompletionResultType]::ParameterName, 'Compression of the stored object (input decompression)')
            [CompletionResult]::new('--csv-file-header-info', '--csv-file-header-info', [CompletionResultType]::ParameterName, 'CSV input header handling')
            [CompletionResult]::new('--csv-input-field-delimiter', '--csv-input-field-delimiter', [CompletionResultType]::ParameterName, 'CSV input field delimiter')
            [CompletionResult]::new('--csv-input-quote', '--csv-input-quote', [CompletionResultType]::ParameterName, 'CSV input quote character')
            [CompletionResult]::new('--csv-input-quote-escape', '--csv-input-quote-escape', [CompletionResultType]::ParameterName, 'CSV input quote escape character')
            [CompletionResult]::new('--csv-input-comment', '--csv-input-comment', [CompletionResultType]::ParameterName, 'CSV input comment character')
            [CompletionResult]::new('--csv-output-field-delimiter', '--csv-output-field-delimiter', [CompletionResultType]::ParameterName, 'CSV output field delimiter')
            [CompletionResult]::new('--csv-output-record-delimiter', '--csv-output-record-delimiter', [CompletionResultType]::ParameterName, 'CSV output record delimiter')
            [CompletionResult]::new('--csv-output-quote', '--csv-output-quote', [CompletionResultType]::ParameterName, 'CSV output quote character')
            [CompletionResult]::new('--csv-output-quote-escape', '--csv-output-quote-escape', [CompletionResultType]::ParameterName, 'CSV output quote escape character')
            [CompletionResult]::new('--csv-output-quote-fields', '--csv-output-quote-fields', [CompletionResultType]::ParameterName, 'CSV output quote behavior')
            [CompletionResult]::new('--json-type', '--json-type', [CompletionResultType]::ParameterName, 'JSON input shape')
            [CompletionResult]::new('--json-output-record-delimiter', '--json-output-record-delimiter', [CompletionResultType]::ParameterName, 'JSON output record delimiter')
            [CompletionResult]::new('--scan-start', '--scan-start', [CompletionResultType]::ParameterName, 'Select ScanRange start byte')
            [CompletionResult]::new('--scan-end', '--scan-end', [CompletionResultType]::ParameterName, 'Select ScanRange end byte')
            [CompletionResult]::new('--sse-customer-algorithm', '--sse-customer-algorithm', [CompletionResultType]::ParameterName, 'SSE-C customer algorithm, usually AES256')
            [CompletionResult]::new('--sse-customer-key', '--sse-customer-key', [CompletionResultType]::ParameterName, 'SSE-C customer key')
            [CompletionResult]::new('--sse-customer-key-md5', '--sse-customer-key-md5', [CompletionResultType]::ParameterName, 'SSE-C customer key MD5')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;version' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable versioning for a bucket')
            [CompletionResult]::new('suspend', 'suspend', [CompletionResultType]::ParameterValue, 'Suspend versioning for a bucket')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get versioning status for a bucket')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List object versions')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;version;enable' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;version;suspend' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;version;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;version;list' {
            [CompletionResult]::new('-n', '-n', [CompletionResultType]::ParameterName, 'Maximum number of versions to show')
            [CompletionResult]::new('--max', '--max', [CompletionResultType]::ParameterName, 'Maximum number of versions to show')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;version;help' {
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable versioning for a bucket')
            [CompletionResult]::new('suspend', 'suspend', [CompletionResultType]::ParameterValue, 'Suspend versioning for a bucket')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get versioning status for a bucket')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List object versions')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;version;help;enable' {
            break
        }
        'rc;version;help;suspend' {
            break
        }
        'rc;version;help;info' {
            break
        }
        'rc;version;help;list' {
            break
        }
        'rc;version;help;help' {
            break
        }
        'rc;tag' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List tags for a bucket or object')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set tags for a bucket or object')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove all tags from a bucket or object')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;tag;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;tag;set' {
            [CompletionResult]::new('-t', '-t', [CompletionResultType]::ParameterName, 'Tags to set (key=value format, can specify multiple)')
            [CompletionResult]::new('--tags', '--tags', [CompletionResultType]::ParameterName, 'Tags to set (key=value format, can specify multiple)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;tag;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;tag;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List tags for a bucket or object')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set tags for a bucket or object')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove all tags from a bucket or object')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;tag;help;list' {
            break
        }
        'rc;tag;help;set' {
            break
        }
        'rc;tag;help;remove' {
            break
        }
        'rc;tag;help;help' {
            break
        }
        'rc;anonymous' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set anonymous access permission')
            [CompletionResult]::new('set-json', 'set-json', [CompletionResultType]::ParameterValue, 'Set anonymous access from a policy JSON file')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get anonymous access permission')
            [CompletionResult]::new('get-json', 'get-json', [CompletionResultType]::ParameterValue, 'Get anonymous policy JSON')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List anonymous policies')
            [CompletionResult]::new('links', 'links', [CompletionResultType]::ParameterValue, 'List public links for anonymous readable prefixes')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;anonymous;set' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;anonymous;set-json' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;anonymous;get' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;anonymous;get-json' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;anonymous;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;anonymous;links' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Recursively list links')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Recursively list links')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;anonymous;help' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set anonymous access permission')
            [CompletionResult]::new('set-json', 'set-json', [CompletionResultType]::ParameterValue, 'Set anonymous access from a policy JSON file')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get anonymous access permission')
            [CompletionResult]::new('get-json', 'get-json', [CompletionResultType]::ParameterValue, 'Get anonymous policy JSON')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List anonymous policies')
            [CompletionResult]::new('links', 'links', [CompletionResultType]::ParameterValue, 'List public links for anonymous readable prefixes')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;anonymous;help;set' {
            break
        }
        'rc;anonymous;help;set-json' {
            break
        }
        'rc;anonymous;help;get' {
            break
        }
        'rc;anonymous;help;get-json' {
            break
        }
        'rc;anonymous;help;list' {
            break
        }
        'rc;anonymous;help;links' {
            break
        }
        'rc;anonymous;help;help' {
            break
        }
        'rc;quota' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket quota')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket quota information')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket quota')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;quota;set' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;quota;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;quota;clear' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;quota;help' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket quota')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket quota information')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket quota')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;quota;help;set' {
            break
        }
        'rc;quota;help;info' {
            break
        }
        'rc;quota;help;clear' {
            break
        }
        'rc;quota;help;help' {
            break
        }
        'rc;ilm' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('rule', 'rule', [CompletionResultType]::ParameterValue, 'Manage lifecycle rules on a bucket')
            [CompletionResult]::new('tier', 'tier', [CompletionResultType]::ParameterValue, 'Manage remote storage tiers')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Restore a transitioned (archived) object')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;ilm;rule' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;ilm;rule;add' {
            [CompletionResult]::new('--expiry-days', '--expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for current versions')
            [CompletionResult]::new('--expiry-date', '--expiry-date', [CompletionResultType]::ParameterName, 'Expiration date for current versions (ISO 8601)')
            [CompletionResult]::new('--transition-days', '--transition-days', [CompletionResultType]::ParameterName, 'Transition days for current versions')
            [CompletionResult]::new('--transition-date', '--transition-date', [CompletionResultType]::ParameterName, 'Transition date for current versions (ISO 8601)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Target storage class for transition')
            [CompletionResult]::new('--noncurrent-expiry-days', '--noncurrent-expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-days', '--noncurrent-transition-days', [CompletionResultType]::ParameterName, 'Transition days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-storage-class', '--noncurrent-transition-storage-class', [CompletionResultType]::ParameterName, 'Storage class for noncurrent version transition')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--newer-noncurrent-versions', '--newer-noncurrent-versions', [CompletionResultType]::ParameterName, 'Maximum number of noncurrent versions to retain')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--expired-object-delete-marker', '--expired-object-delete-marker', [CompletionResultType]::ParameterName, 'Remove expired delete markers')
            [CompletionResult]::new('--disable', '--disable', [CompletionResultType]::ParameterName, 'Create the rule in disabled state')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;rule;edit' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'ID of the rule to edit')
            [CompletionResult]::new('--expiry-days', '--expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for current versions')
            [CompletionResult]::new('--expiry-date', '--expiry-date', [CompletionResultType]::ParameterName, 'Expiration date for current versions (ISO 8601)')
            [CompletionResult]::new('--transition-days', '--transition-days', [CompletionResultType]::ParameterName, 'Transition days for current versions')
            [CompletionResult]::new('--transition-date', '--transition-date', [CompletionResultType]::ParameterName, 'Transition date for current versions (ISO 8601)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Target storage class for transition')
            [CompletionResult]::new('--noncurrent-expiry-days', '--noncurrent-expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-days', '--noncurrent-transition-days', [CompletionResultType]::ParameterName, 'Transition days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-storage-class', '--noncurrent-transition-storage-class', [CompletionResultType]::ParameterName, 'Storage class for noncurrent version transition')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--expired-object-delete-marker', '--expired-object-delete-marker', [CompletionResultType]::ParameterName, 'Remove expired delete markers')
            [CompletionResult]::new('--newer-noncurrent-versions', '--newer-noncurrent-versions', [CompletionResultType]::ParameterName, 'Maximum number of noncurrent versions to retain')
            [CompletionResult]::new('--disable', '--disable', [CompletionResultType]::ParameterName, 'Set the rule to disabled state')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;rule;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;rule;remove' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'ID of the rule to remove')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Remove all lifecycle rules')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;rule;export' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;rule;import' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;rule;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;ilm;rule;help;add' {
            break
        }
        'rc;ilm;rule;help;edit' {
            break
        }
        'rc;ilm;rule;help;list' {
            break
        }
        'rc;ilm;rule;help;remove' {
            break
        }
        'rc;ilm;rule;help;export' {
            break
        }
        'rc;ilm;rule;help;import' {
            break
        }
        'rc;ilm;rule;help;help' {
            break
        }
        'rc;ilm;tier' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;ilm;tier;add' {
            [CompletionResult]::new('--endpoint', '--endpoint', [CompletionResultType]::ParameterName, 'Remote endpoint URL')
            [CompletionResult]::new('--access-key', '--access-key', [CompletionResultType]::ParameterName, 'Access key for the remote backend')
            [CompletionResult]::new('--secret-key', '--secret-key', [CompletionResultType]::ParameterName, 'Secret key for the remote backend')
            [CompletionResult]::new('--bucket', '--bucket', [CompletionResultType]::ParameterName, 'Target bucket on the remote backend')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Object key prefix on the remote bucket')
            [CompletionResult]::new('--region', '--region', [CompletionResultType]::ParameterName, 'Region of the remote backend')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class on the remote backend (for S3/Azure/GCS tiers)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;tier;edit' {
            [CompletionResult]::new('--access-key', '--access-key', [CompletionResultType]::ParameterName, 'New access key')
            [CompletionResult]::new('--secret-key', '--secret-key', [CompletionResultType]::ParameterName, 'New secret key')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;tier;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;tier;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;tier;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force removal even if tier is in use')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;tier;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;ilm;tier;help;add' {
            break
        }
        'rc;ilm;tier;help;edit' {
            break
        }
        'rc;ilm;tier;help;list' {
            break
        }
        'rc;ilm;tier;help;info' {
            break
        }
        'rc;ilm;tier;help;remove' {
            break
        }
        'rc;ilm;tier;help;help' {
            break
        }
        'rc;ilm;restore' {
            [CompletionResult]::new('--days', '--days', [CompletionResultType]::ParameterName, 'Number of days to keep the restored copy')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;help' {
            [CompletionResult]::new('rule', 'rule', [CompletionResultType]::ParameterValue, 'Manage lifecycle rules on a bucket')
            [CompletionResult]::new('tier', 'tier', [CompletionResultType]::ParameterValue, 'Manage remote storage tiers')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Restore a transitioned (archived) object')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;ilm;help;rule' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            break
        }
        'rc;ilm;help;rule;add' {
            break
        }
        'rc;ilm;help;rule;edit' {
            break
        }
        'rc;ilm;help;rule;list' {
            break
        }
        'rc;ilm;help;rule;remove' {
            break
        }
        'rc;ilm;help;rule;export' {
            break
        }
        'rc;ilm;help;rule;import' {
            break
        }
        'rc;ilm;help;tier' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            break
        }
        'rc;ilm;help;tier;add' {
            break
        }
        'rc;ilm;help;tier;edit' {
            break
        }
        'rc;ilm;help;tier;list' {
            break
        }
        'rc;ilm;help;tier;info' {
            break
        }
        'rc;ilm;help;tier;remove' {
            break
        }
        'rc;ilm;help;restore' {
            break
        }
        'rc;ilm;help;help' {
            break
        }
        'rc;replicate' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new replication rule')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing replication rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List replication rules for a bucket')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show replication status/metrics for a bucket')
            [CompletionResult]::new('mrf', 'mrf', [CompletionResultType]::ParameterValue, 'Show aggregate replication MRF backlog for a bucket')
            [CompletionResult]::new('diff', 'diff', [CompletionResultType]::ParameterValue, 'Scan for object versions that have not replicated')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove replication rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export replication configuration as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import replication configuration from a JSON file')
            [CompletionResult]::new('check', 'check', [CompletionResultType]::ParameterValue, 'Actively validate configured replication targets')
            [CompletionResult]::new('resync', 'resync', [CompletionResultType]::ParameterValue, 'Manage bucket replication resync operations')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;replicate;add' {
            [CompletionResult]::new('--remote-bucket', '--remote-bucket', [CompletionResultType]::ParameterName, 'Remote target bucket (TARGET_ALIAS/BUCKET)')
            [CompletionResult]::new('--replicate', '--replicate', [CompletionResultType]::ParameterName, 'Replication flags (comma-separated: delete,delete-marker,existing-objects)')
            [CompletionResult]::new('--priority', '--priority', [CompletionResultType]::ParameterName, 'Rule priority (higher = more important)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class override at destination')
            [CompletionResult]::new('--bandwidth', '--bandwidth', [CompletionResultType]::ParameterName, 'Bandwidth limit in bytes/sec (0 = unlimited)')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'Rule identifier (auto-generated if not specified)')
            [CompletionResult]::new('--healthcheck-seconds', '--healthcheck-seconds', [CompletionResultType]::ParameterName, 'Health check interval in seconds')
            [CompletionResult]::new('--ca-cert', '--ca-cert', [CompletionResultType]::ParameterName, 'Read a local PEM CA certificate file and upload its content for this bucket replication target. The path is resolved on the CLI machine, not on the RustFS server')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--sync', '--sync', [CompletionResultType]::ParameterName, 'Enable synchronous replication')
            [CompletionResult]::new('--disable-proxy', '--disable-proxy', [CompletionResultType]::ParameterName, 'Disable replication proxy')
            [CompletionResult]::new('--insecure', '--insecure', [CompletionResultType]::ParameterName, 'Skip TLS certificate verification for this bucket replication target. Intended for development or test environments')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;update' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'Rule ID to update')
            [CompletionResult]::new('--replicate', '--replicate', [CompletionResultType]::ParameterName, 'Replication flags (comma-separated: delete,delete-marker,existing-objects)')
            [CompletionResult]::new('--priority', '--priority', [CompletionResultType]::ParameterName, 'Rule priority (higher = more important)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class override at destination')
            [CompletionResult]::new('--bandwidth', '--bandwidth', [CompletionResultType]::ParameterName, 'Bandwidth limit in bytes/sec (0 = unlimited)')
            [CompletionResult]::new('--sync', '--sync', [CompletionResultType]::ParameterName, 'Enable or disable synchronous replication')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--healthcheck-seconds', '--healthcheck-seconds', [CompletionResultType]::ParameterName, 'Health check interval in seconds')
            [CompletionResult]::new('--disable-proxy', '--disable-proxy', [CompletionResultType]::ParameterName, 'Disable replication proxy')
            [CompletionResult]::new('--ca-cert', '--ca-cert', [CompletionResultType]::ParameterName, 'Read a local PEM CA certificate file and upload its content for this bucket replication target. The path is resolved on the CLI machine, not on the RustFS server')
            [CompletionResult]::new('--status', '--status', [CompletionResultType]::ParameterName, 'Enable or disable the rule')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--insecure', '--insecure', [CompletionResultType]::ParameterName, 'Skip TLS certificate verification for this bucket replication target. Intended for development or test environments')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;mrf' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;diff' {
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Limit the scan to object keys below this prefix')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;remove' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'Rule ID to remove (omit for --all)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Remove all replication rules')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;export' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;import' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;check' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm the active remote write/delete validation probe')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if generic replication capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;resync' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start resyncing previously replicated objects')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show persisted server-side resync status')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;replicate;resync;start' {
            [CompletionResult]::new('--target-arn', '--target-arn', [CompletionResultType]::ParameterName, 'Select a configured replication target ARN')
            [CompletionResult]::new('--older-than', '--older-than', [CompletionResultType]::ParameterName, 'Only resync objects older than this duration (for example, 7d10h31s)')
            [CompletionResult]::new('--reset-id', '--reset-id', [CompletionResultType]::ParameterName, 'Supply a stable resync identifier instead of using a server-generated ID')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--yes', '--yes', [CompletionResultType]::ParameterName, 'Confirm the active server-side resync')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if generic replication capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;resync;status' {
            [CompletionResult]::new('--target-arn', '--target-arn', [CompletionResultType]::ParameterName, 'Filter status to one configured replication target ARN')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if generic replication capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;resync;help' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start resyncing previously replicated objects')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show persisted server-side resync status')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;replicate;resync;help;start' {
            break
        }
        'rc;replicate;resync;help;status' {
            break
        }
        'rc;replicate;resync;help;help' {
            break
        }
        'rc;replicate;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new replication rule')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing replication rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List replication rules for a bucket')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show replication status/metrics for a bucket')
            [CompletionResult]::new('mrf', 'mrf', [CompletionResultType]::ParameterValue, 'Show aggregate replication MRF backlog for a bucket')
            [CompletionResult]::new('diff', 'diff', [CompletionResultType]::ParameterValue, 'Scan for object versions that have not replicated')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove replication rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export replication configuration as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import replication configuration from a JSON file')
            [CompletionResult]::new('check', 'check', [CompletionResultType]::ParameterValue, 'Actively validate configured replication targets')
            [CompletionResult]::new('resync', 'resync', [CompletionResultType]::ParameterValue, 'Manage bucket replication resync operations')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;replicate;help;add' {
            break
        }
        'rc;replicate;help;update' {
            break
        }
        'rc;replicate;help;list' {
            break
        }
        'rc;replicate;help;status' {
            break
        }
        'rc;replicate;help;mrf' {
            break
        }
        'rc;replicate;help;diff' {
            break
        }
        'rc;replicate;help;remove' {
            break
        }
        'rc;replicate;help;export' {
            break
        }
        'rc;replicate;help;import' {
            break
        }
        'rc;replicate;help;check' {
            break
        }
        'rc;replicate;help;resync' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start resyncing previously replicated objects')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show persisted server-side resync status')
            break
        }
        'rc;replicate;help;resync;start' {
            break
        }
        'rc;replicate;help;resync;status' {
            break
        }
        'rc;replicate;help;help' {
            break
        }
        'rc;retention' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show retention for an object version or a bucket default')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set retention for an object version or a bucket default')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear retention for an object version or a bucket default')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;retention;info' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Read one exact object version')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--default', '--default', [CompletionResultType]::ParameterName, 'Read bucket default retention instead of object retention')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;retention;set' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Mutate one exact object version')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--bypass', '--bypass', [CompletionResultType]::ParameterName, 'Explicitly request governance retention bypass')
            [CompletionResult]::new('--default', '--default', [CompletionResultType]::ParameterName, 'Set bucket default retention instead of object retention')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;retention;clear' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Mutate one exact object version')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--bypass', '--bypass', [CompletionResultType]::ParameterName, 'Explicitly request governance retention bypass')
            [CompletionResult]::new('--default', '--default', [CompletionResultType]::ParameterName, 'Clear bucket default retention instead of object retention')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;retention;help' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show retention for an object version or a bucket default')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set retention for an object version or a bucket default')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear retention for an object version or a bucket default')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;retention;help;info' {
            break
        }
        'rc;retention;help;set' {
            break
        }
        'rc;retention;help;clear' {
            break
        }
        'rc;retention;help;help' {
            break
        }
        'rc;legalhold' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show legal-hold status')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set legal hold to ON')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Set legal hold to OFF')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;legalhold;info' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Read or mutate one exact object version')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;legalhold;set' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Read or mutate one exact object version')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;legalhold;clear' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Read or mutate one exact object version')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;legalhold;help' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show legal-hold status')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set legal hold to ON')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Set legal hold to OFF')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;legalhold;help;info' {
            break
        }
        'rc;legalhold;help;set' {
            break
        }
        'rc;legalhold;help;clear' {
            break
        }
        'rc;legalhold;help;help' {
            break
        }
        'rc;completions' {
            [CompletionResult]::new('--install-dir', '--install-dir', [CompletionResultType]::ParameterName, 'Override the completion installation directory')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--install', '--install', [CompletionResultType]::ParameterName, 'Install the completion script in the shell''s user completion directory')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Replace an existing installed completion script')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;du' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--fallback', '--fallback', [CompletionResultType]::ParameterName, 'Permit a slower client-side S3 scan when the server snapshot cannot be used')
            [CompletionResult]::new('--versions', '--versions', [CompletionResultType]::ParameterName, 'Include all object versions and delete markers during a client scan')
            [CompletionResult]::new('--incomplete', '--incomplete', [CompletionResultType]::ParameterName, 'Include incomplete multipart uploads and uploaded part bytes during a client scan')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ping' {
            [CompletionResult]::new('--timeout', '--timeout', [CompletionResultType]::ParameterName, 'Maximum probe duration in seconds')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ready' {
            [CompletionResult]::new('--timeout', '--timeout', [CompletionResultType]::ParameterName, 'Maximum probe duration in seconds')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;watch' {
            [CompletionResult]::new('-e', '-e', [CompletionResultType]::ParameterName, 'Event filter (put, delete, get, or an S3 event name; repeatable and comma-separated)')
            [CompletionResult]::new('--event', '--event', [CompletionResultType]::ParameterName, 'Event filter (put, delete, get, or an S3 event name; repeatable and comma-separated)')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Match decoded object keys with this prefix')
            [CompletionResult]::new('--suffix', '--suffix', [CompletionResultType]::ParameterName, 'Match decoded object keys with this suffix')
            [CompletionResult]::new('--ping', '--ping', [CompletionResultType]::ParameterName, 'Server keepalive interval in seconds')
            [CompletionResult]::new('--reconnect-attempts', '--reconnect-attempts', [CompletionResultType]::ParameterName, 'Maximum reconnects after the initial connection')
            [CompletionResult]::new('--reconnect-delay-ms', '--reconnect-delay-ms', [CompletionResultType]::ParameterName, 'Initial reconnect delay in milliseconds')
            [CompletionResult]::new('--reconnect-max-delay-ms', '--reconnect-max-delay-ms', [CompletionResultType]::ParameterName, 'Maximum reconnect delay in milliseconds')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;help' {
            [CompletionResult]::new('alias', 'alias', [CompletionResultType]::ParameterValue, 'Manage storage service aliases')
            [CompletionResult]::new('admin', 'admin', [CompletionResultType]::ParameterValue, 'Manage IAM users, policies, groups, and service accounts')
            [CompletionResult]::new('bucket', 'bucket', [CompletionResultType]::ParameterValue, 'Manage bucket-oriented workflows')
            [CompletionResult]::new('object', 'object', [CompletionResultType]::ParameterValue, 'Manage object-oriented workflows')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket list` or `rc object list`')
            [CompletionResult]::new('mb', 'mb', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket create`')
            [CompletionResult]::new('rb', 'rb', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket remove`')
            [CompletionResult]::new('cat', 'cat', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object show`')
            [CompletionResult]::new('head', 'head', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object head`')
            [CompletionResult]::new('stat', 'stat', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object stat`')
            [CompletionResult]::new('cp', 'cp', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object copy`')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Download one remote object to the local filesystem')
            [CompletionResult]::new('put', 'put', [CompletionResultType]::ParameterValue, 'Upload one or more local paths to remote object storage')
            [CompletionResult]::new('mv', 'mv', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object move`')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object remove`')
            [CompletionResult]::new('undo', 'undo', [CompletionResultType]::ParameterValue, 'Restore a versioned PUT or DELETE operation without removing data history')
            [CompletionResult]::new('pipe', 'pipe', [CompletionResultType]::ParameterValue, 'Stream stdin to an object')
            [CompletionResult]::new('find', 'find', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object find`')
            [CompletionResult]::new('event', 'event', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket event`')
            [CompletionResult]::new('cors', 'cors', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket cors`')
            [CompletionResult]::new('diff', 'diff', [CompletionResultType]::ParameterValue, 'Show differences between locations')
            [CompletionResult]::new('mirror', 'mirror', [CompletionResultType]::ParameterValue, 'Mirror objects between locations')
            [CompletionResult]::new('tree', 'tree', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object tree`')
            [CompletionResult]::new('share', 'share', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object share`')
            [CompletionResult]::new('sql', 'sql', [CompletionResultType]::ParameterValue, 'Run S3 Select SQL on an object')
            [CompletionResult]::new('version', 'version', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket version`')
            [CompletionResult]::new('tag', 'tag', [CompletionResultType]::ParameterValue, 'Manage bucket and object tags')
            [CompletionResult]::new('anonymous', 'anonymous', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket anonymous`')
            [CompletionResult]::new('quota', 'quota', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket quota`')
            [CompletionResult]::new('ilm', 'ilm', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket lifecycle`')
            [CompletionResult]::new('replicate', 'replicate', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket replication`')
            [CompletionResult]::new('retention', 'retention', [CompletionResultType]::ParameterValue, 'Manage object retention with mc-compatible command syntax')
            [CompletionResult]::new('legalhold', 'legalhold', [CompletionResultType]::ParameterValue, 'Manage object legal hold with mc-compatible command syntax')
            [CompletionResult]::new('completions', 'completions', [CompletionResultType]::ParameterValue, 'Generate shell completion scripts')
            [CompletionResult]::new('du', 'du', [CompletionResultType]::ParameterValue, 'Summarize storage usage')
            [CompletionResult]::new('ping', 'ping', [CompletionResultType]::ParameterValue, 'Check service liveness and round-trip latency')
            [CompletionResult]::new('ready', 'ready', [CompletionResultType]::ParameterValue, 'Check whether required dependencies are ready')
            [CompletionResult]::new('watch', 'watch', [CompletionResultType]::ParameterValue, 'Stream live object notifications')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;help;alias' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Add or update an alias')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List all configured aliases')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove an alias')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export aliases as a portable JSON document')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import aliases from a portable JSON document')
            break
        }
        'rc;help;alias;set' {
            break
        }
        'rc;help;alias;list' {
            break
        }
        'rc;help;alias;remove' {
            break
        }
        'rc;help;alias;export' {
            break
        }
        'rc;help;alias;import' {
            break
        }
        'rc;help;admin' {
            [CompletionResult]::new('capabilities', 'capabilities', [CompletionResultType]::ParameterValue, 'Discover effective RustFS runtime capabilities')
            [CompletionResult]::new('diagnostics', 'diagnostics', [CompletionResultType]::ParameterValue, 'Read bounded snapshots or run explicitly confirmed RustFS diagnostic probes')
            [CompletionResult]::new('config', 'config', [CompletionResultType]::ParameterValue, 'Manage RustFS server configuration')
            [CompletionResult]::new('metrics', 'metrics', [CompletionResultType]::ParameterValue, 'Query bounded RustFS realtime metrics')
            [CompletionResult]::new('kms', 'kms', [CompletionResultType]::ParameterValue, 'Inspect KMS state and manage key lifecycle operations')
            [CompletionResult]::new('scanner', 'scanner', [CompletionResultType]::ParameterValue, 'Inspect scanner health and freshness')
            [CompletionResult]::new('ilm', 'ilm', [CompletionResultType]::ParameterValue, 'Manage lifecycle transition operations')
            [CompletionResult]::new('idp', 'idp', [CompletionResultType]::ParameterValue, 'Inspect, validate, and manage identity-provider configuration')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Display cluster information (servers, disks, usage)')
            [CompletionResult]::new('heal', 'heal', [CompletionResultType]::ParameterValue, 'Manage cluster healing operations')
            [CompletionResult]::new('pool', 'pool', [CompletionResultType]::ParameterValue, 'Manage server pools and expansion status')
            [CompletionResult]::new('expand', 'expand', [CompletionResultType]::ParameterValue, 'Manage post-expansion data rebalancing')
            [CompletionResult]::new('decommission', 'decommission', [CompletionResultType]::ParameterValue, 'Manage server pool decommissioning')
            [CompletionResult]::new('rebalance', 'rebalance', [CompletionResultType]::ParameterValue, 'Manage post-expansion rebalancing')
            [CompletionResult]::new('user', 'user', [CompletionResultType]::ParameterValue, 'Manage IAM users')
            [CompletionResult]::new('policy', 'policy', [CompletionResultType]::ParameterValue, 'Manage IAM policies')
            [CompletionResult]::new('group', 'group', [CompletionResultType]::ParameterValue, 'Manage IAM groups')
            [CompletionResult]::new('service-account', 'service-account', [CompletionResultType]::ParameterValue, 'Manage service accounts')
            [CompletionResult]::new('access-key', 'access-key', [CompletionResultType]::ParameterValue, 'Inspect access key identities')
            [CompletionResult]::new('bucket-metadata', 'bucket-metadata', [CompletionResultType]::ParameterValue, 'Export or import validated per-bucket metadata archives')
            [CompletionResult]::new('iam', 'iam', [CompletionResultType]::ParameterValue, 'Export or import versioned IAM archives')
            [CompletionResult]::new('service', 'service', [CompletionResultType]::ParameterValue, 'Control the server process (restart, stop, freeze, unfreeze)')
            [CompletionResult]::new('replicate', 'replicate', [CompletionResultType]::ParameterValue, 'Manage site replication across clusters')
            break
        }
        'rc;help;admin;capabilities' {
            break
        }
        'rc;help;admin;diagnostics' {
            [CompletionResult]::new('health', 'health', [CompletionResultType]::ParameterValue, 'Display authenticated host, process, and drive health observations')
            [CompletionResult]::new('cluster', 'cluster', [CompletionResultType]::ParameterValue, 'Display the read-only RustFS cluster snapshot')
            [CompletionResult]::new('extensions', 'extensions', [CompletionResultType]::ParameterValue, 'Display extension schemas and runtime capability summaries')
            [CompletionResult]::new('client-devnull', 'client-devnull', [CompletionResultType]::ParameterValue, 'Measure bounded client-to-server upload throughput without storing data')
            [CompletionResult]::new('inspect-archive', 'inspect-archive', [CompletionResultType]::ParameterValue, 'Retrieve and verify an encrypted drive-metadata archive')
            break
        }
        'rc;help;admin;diagnostics;health' {
            break
        }
        'rc;help;admin;diagnostics;cluster' {
            break
        }
        'rc;help;admin;diagnostics;extensions' {
            break
        }
        'rc;help;admin;diagnostics;client-devnull' {
            break
        }
        'rc;help;admin;diagnostics;inspect-archive' {
            break
        }
        'rc;help;admin;config' {
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Read a subsystem or target configuration')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set one or more keys after showing a preflight diff')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Delete a target or selected keys after showing a preflight diff')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Show server-provided configuration help')
            [CompletionResult]::new('history', 'history', [CompletionResultType]::ParameterValue, 'List configuration mutation history')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Replace configuration from a history entry')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export the full server configuration to a file')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Replace the full server configuration from a file')
            [CompletionResult]::new('module-switch', 'module-switch', [CompletionResultType]::ParameterValue, 'Inspect or update event notification and audit module switches')
            break
        }
        'rc;help;admin;config;get' {
            break
        }
        'rc;help;admin;config;set' {
            break
        }
        'rc;help;admin;config;delete' {
            break
        }
        'rc;help;admin;config;help' {
            break
        }
        'rc;help;admin;config;history' {
            break
        }
        'rc;help;admin;config;restore' {
            break
        }
        'rc;help;admin;config;export' {
            break
        }
        'rc;help;admin;config;import' {
            break
        }
        'rc;help;admin;config;module-switch' {
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'get')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'set')
            break
        }
        'rc;help;admin;config;module-switch;get' {
            break
        }
        'rc;help;admin;config;module-switch;set' {
            break
        }
        'rc;help;admin;metrics' {
            break
        }
        'rc;help;admin;kms' {
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display KMS service health and non-secret configuration summary')
            [CompletionResult]::new('key', 'key', [CompletionResultType]::ParameterValue, 'Inspect KMS keys')
            [CompletionResult]::new('configure', 'configure', [CompletionResultType]::ParameterValue, 'Configure KMS from a protected JSON file or standard input')
            [CompletionResult]::new('reconfigure', 'reconfigure', [CompletionResultType]::ParameterValue, 'Replace KMS configuration from a protected JSON file or standard input')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start the configured KMS service')
            [CompletionResult]::new('restart', 'restart', [CompletionResultType]::ParameterValue, 'Restart the KMS service after explicit confirmation')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop the KMS service after explicit confirmation')
            [CompletionResult]::new('roundtrip', 'roundtrip', [CompletionResultType]::ParameterValue, 'Verify SSE-KMS write and read behavior with a temporary object')
            break
        }
        'rc;help;admin;kms;status' {
            break
        }
        'rc;help;admin;kms;key' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List KMS keys')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display key lifecycle status; defaults to the configured KMS key')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a KMS key without exporting key material')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Schedule or immediately delete a KMS key')
            [CompletionResult]::new('cancel-deletion', 'cancel-deletion', [CompletionResultType]::ParameterValue, 'Cancel a scheduled KMS key deletion')
            break
        }
        'rc;help;admin;kms;key;list' {
            break
        }
        'rc;help;admin;kms;key;status' {
            break
        }
        'rc;help;admin;kms;key;create' {
            break
        }
        'rc;help;admin;kms;key;delete' {
            break
        }
        'rc;help;admin;kms;key;cancel-deletion' {
            break
        }
        'rc;help;admin;kms;configure' {
            break
        }
        'rc;help;admin;kms;reconfigure' {
            break
        }
        'rc;help;admin;kms;start' {
            break
        }
        'rc;help;admin;kms;restart' {
            break
        }
        'rc;help;admin;kms;stop' {
            break
        }
        'rc;help;admin;kms;roundtrip' {
            break
        }
        'rc;help;admin;scanner' {
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display scanner health, freshness, and current cycle details')
            break
        }
        'rc;help;admin;scanner;status' {
            break
        }
        'rc;help;admin;ilm' {
            [CompletionResult]::new('transition', 'transition', [CompletionResultType]::ParameterValue, 'Manage lifecycle transition operations')
            break
        }
        'rc;help;admin;ilm;transition' {
            [CompletionResult]::new('run', 'run', [CompletionResultType]::ParameterValue, 'Run bounded lifecycle transition evaluation for existing objects')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show durable lifecycle transition job status')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Request cancellation for a durable lifecycle transition job')
            [CompletionResult]::new('wait', 'wait', [CompletionResultType]::ParameterValue, 'Wait until a durable lifecycle transition job reaches a terminal state')
            break
        }
        'rc;help;admin;ilm;transition;run' {
            break
        }
        'rc;help;admin;ilm;transition;status' {
            break
        }
        'rc;help;admin;ilm;transition;cancel' {
            break
        }
        'rc;help;admin;ilm;transition;wait' {
            break
        }
        'rc;help;admin;idp' {
            [CompletionResult]::new('openid', 'openid', [CompletionResultType]::ParameterValue, 'Inspect and validate OpenID Connect providers')
            break
        }
        'rc;help;admin;idp;openid' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List effective OIDC provider configurations')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Display one effective OIDC provider configuration')
            [CompletionResult]::new('validate', 'validate', [CompletionResultType]::ParameterValue, 'Validate OIDC discovery without saving configuration')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Create or replace an OIDC provider while preserving omitted fields')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing OIDC provider while preserving omitted fields')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable an existing OIDC provider')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable an existing OIDC provider')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Delete an editable OIDC provider after explicit confirmation')
            break
        }
        'rc;help;admin;idp;openid;list' {
            break
        }
        'rc;help;admin;idp;openid;get' {
            break
        }
        'rc;help;admin;idp;openid;validate' {
            break
        }
        'rc;help;admin;idp;openid;set' {
            break
        }
        'rc;help;admin;idp;openid;update' {
            break
        }
        'rc;help;admin;idp;openid;enable' {
            break
        }
        'rc;help;admin;idp;openid;disable' {
            break
        }
        'rc;help;admin;idp;openid;delete' {
            break
        }
        'rc;help;admin;info' {
            [CompletionResult]::new('cluster', 'cluster', [CompletionResultType]::ParameterValue, 'Display cluster overview information')
            [CompletionResult]::new('server', 'server', [CompletionResultType]::ParameterValue, 'Display server information')
            [CompletionResult]::new('disk', 'disk', [CompletionResultType]::ParameterValue, 'Display disk information')
            [CompletionResult]::new('storage', 'storage', [CompletionResultType]::ParameterValue, 'Display storage topology and capacity information')
            break
        }
        'rc;help;admin;info;cluster' {
            break
        }
        'rc;help;admin;info;server' {
            break
        }
        'rc;help;admin;info;disk' {
            break
        }
        'rc;help;admin;info;storage' {
            break
        }
        'rc;help;admin;heal' {
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display current heal status')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a heal operation')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running heal operation')
            break
        }
        'rc;help;admin;heal;status' {
            break
        }
        'rc;help;admin;heal;start' {
            break
        }
        'rc;help;admin;heal;stop' {
            break
        }
        'rc;help;admin;pool' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List server pools')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show server pool status')
            break
        }
        'rc;help;admin;pool;list' {
            break
        }
        'rc;help;admin;pool;status' {
            break
        }
        'rc;help;admin;expand' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start post-expansion data rebalancing')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show post-expansion rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running post-expansion rebalance')
            break
        }
        'rc;help;admin;expand;start' {
            break
        }
        'rc;help;admin;expand;status' {
            break
        }
        'rc;help;admin;expand;stop' {
            break
        }
        'rc;help;admin;decommission' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start decommissioning a pool')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show decommissioning status')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Cancel decommissioning a pool')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear failed or canceled decommissioning metadata for a pool')
            break
        }
        'rc;help;admin;decommission;start' {
            break
        }
        'rc;help;admin;decommission;status' {
            break
        }
        'rc;help;admin;decommission;cancel' {
            break
        }
        'rc;help;admin;decommission;clear' {
            break
        }
        'rc;help;admin;rebalance' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a rebalance operation')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running rebalance operation')
            break
        }
        'rc;help;admin;rebalance;start' {
            break
        }
        'rc;help;admin;rebalance;status' {
            break
        }
        'rc;help;admin;rebalance;stop' {
            break
        }
        'rc;help;admin;user' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all users')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new user')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get user information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a user')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a user')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a user')
            break
        }
        'rc;help;admin;user;ls' {
            break
        }
        'rc;help;admin;user;add' {
            break
        }
        'rc;help;admin;user;info' {
            break
        }
        'rc;help;admin;user;rm' {
            break
        }
        'rc;help;admin;user;enable' {
            break
        }
        'rc;help;admin;user;disable' {
            break
        }
        'rc;help;admin;policy' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all policies')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new policy')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get policy information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a policy')
            [CompletionResult]::new('attach', 'attach', [CompletionResultType]::ParameterValue, 'Attach policy to a user or group')
            [CompletionResult]::new('detach', 'detach', [CompletionResultType]::ParameterValue, 'Detach one or more policies from exactly one user or group')
            [CompletionResult]::new('entities', 'entities', [CompletionResultType]::ParameterValue, 'Inspect policy mappings for users, groups, or policies')
            break
        }
        'rc;help;admin;policy;ls' {
            break
        }
        'rc;help;admin;policy;create' {
            break
        }
        'rc;help;admin;policy;info' {
            break
        }
        'rc;help;admin;policy;rm' {
            break
        }
        'rc;help;admin;policy;attach' {
            break
        }
        'rc;help;admin;policy;detach' {
            break
        }
        'rc;help;admin;policy;entities' {
            break
        }
        'rc;help;admin;group' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all groups')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Create a new group')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get group information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a group')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a group')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a group')
            [CompletionResult]::new('add-members', 'add-members', [CompletionResultType]::ParameterValue, 'Add members to a group')
            [CompletionResult]::new('rm-members', 'rm-members', [CompletionResultType]::ParameterValue, 'Remove members from a group')
            break
        }
        'rc;help;admin;group;ls' {
            break
        }
        'rc;help;admin;group;add' {
            break
        }
        'rc;help;admin;group;info' {
            break
        }
        'rc;help;admin;group;rm' {
            break
        }
        'rc;help;admin;group;enable' {
            break
        }
        'rc;help;admin;group;disable' {
            break
        }
        'rc;help;admin;group;add-members' {
            break
        }
        'rc;help;admin;group;rm-members' {
            break
        }
        'rc;help;admin;service-account' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List service accounts')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new service account')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing service account')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get service account information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a service account')
            break
        }
        'rc;help;admin;service-account;ls' {
            break
        }
        'rc;help;admin;service-account;create' {
            break
        }
        'rc;help;admin;service-account;update' {
            break
        }
        'rc;help;admin;service-account;info' {
            break
        }
        'rc;help;admin;service-account;rm' {
            break
        }
        'rc;help;admin;access-key' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get access key information')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List access keys across capability-advertised identity providers')
            break
        }
        'rc;help;admin;access-key;info' {
            break
        }
        'rc;help;admin;access-key;ls' {
            break
        }
        'rc;help;admin;bucket-metadata' {
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export a deterministic, redacted metadata archive')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Validate and import metadata using an explicit conflict strategy')
            break
        }
        'rc;help;admin;bucket-metadata;export' {
            break
        }
        'rc;help;admin;bucket-metadata;import' {
            break
        }
        'rc;help;admin;iam' {
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export IAM users, groups, policies, mappings, and service accounts')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Validate or import a previously exported IAM archive')
            break
        }
        'rc;help;admin;iam;export' {
            break
        }
        'rc;help;admin;iam;import' {
            break
        }
        'rc;help;admin;service' {
            [CompletionResult]::new('restart', 'restart', [CompletionResultType]::ParameterValue, 'Restart the server (graceful shutdown; process manager relaunches)')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop the server gracefully')
            [CompletionResult]::new('freeze', 'freeze', [CompletionResultType]::ParameterValue, 'Set the service freeze flag (advisory)')
            [CompletionResult]::new('unfreeze', 'unfreeze', [CompletionResultType]::ParameterValue, 'Clear the service freeze flag')
            break
        }
        'rc;help;admin;service;restart' {
            break
        }
        'rc;help;admin;service;stop' {
            break
        }
        'rc;help;admin;service;freeze' {
            break
        }
        'rc;help;admin;service;unfreeze' {
            break
        }
        'rc;help;admin;replicate' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add sites (given as alias names) to a site replication cluster')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show site replication configuration')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Safely edit one exact site replication peer')
            [CompletionResult]::new('resync', 'resync', [CompletionResultType]::ParameterValue, 'Manage persisted site resync operation snapshots')
            [CompletionResult]::new('repair', 'repair', [CompletionResultType]::ParameterValue, 'Plan, execute, or inspect durable site replication repair')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show site replication status')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove sites from the site replication cluster')
            break
        }
        'rc;help;admin;replicate;add' {
            break
        }
        'rc;help;admin;replicate;info' {
            break
        }
        'rc;help;admin;replicate;edit' {
            break
        }
        'rc;help;admin;replicate;resync' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start resync for one exact peer and retain the mutation snapshot')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Read the persisted snapshot from the last start or cancel request')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Cancel resync for one exact peer and retain the mutation snapshot')
            break
        }
        'rc;help;admin;replicate;resync;start' {
            break
        }
        'rc;help;admin;replicate;resync;status' {
            break
        }
        'rc;help;admin;replicate;resync;cancel' {
            break
        }
        'rc;help;admin;replicate;repair' {
            [CompletionResult]::new('dry-run', 'dry-run', [CompletionResultType]::ParameterValue, 'Create a local-only repair plan and preflight token')
            [CompletionResult]::new('execute', 'execute', [CompletionResultType]::ParameterValue, 'Execute or resume a repair using the exact preflight token and operation ID')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Read a durable repair snapshot from a fresh process')
            break
        }
        'rc;help;admin;replicate;repair;dry-run' {
            break
        }
        'rc;help;admin;replicate;repair;execute' {
            break
        }
        'rc;help;admin;replicate;repair;status' {
            break
        }
        'rc;help;admin;replicate;status' {
            break
        }
        'rc;help;admin;replicate;remove' {
            break
        }
        'rc;help;bucket' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List buckets for an alias, or objects within a bucket path')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a bucket')
            [CompletionResult]::new('event', 'event', [CompletionResultType]::ParameterValue, 'Manage bucket notification rules')
            [CompletionResult]::new('cors', 'cors', [CompletionResultType]::ParameterValue, 'Manage bucket CORS rules')
            [CompletionResult]::new('encryption', 'encryption', [CompletionResultType]::ParameterValue, 'Manage bucket default encryption')
            [CompletionResult]::new('version', 'version', [CompletionResultType]::ParameterValue, 'Manage bucket versioning')
            [CompletionResult]::new('lock', 'lock', [CompletionResultType]::ParameterValue, 'Manage bucket Object Lock and default retention')
            [CompletionResult]::new('quota', 'quota', [CompletionResultType]::ParameterValue, 'Manage bucket quota')
            [CompletionResult]::new('anonymous', 'anonymous', [CompletionResultType]::ParameterValue, 'Manage anonymous bucket access')
            [CompletionResult]::new('lifecycle', 'lifecycle', [CompletionResultType]::ParameterValue, 'Manage bucket lifecycle rules, tiers, and restores')
            [CompletionResult]::new('replication', 'replication', [CompletionResultType]::ParameterValue, 'Manage bucket replication rules and status')
            break
        }
        'rc;help;bucket;list' {
            break
        }
        'rc;help;bucket;create' {
            break
        }
        'rc;help;bucket;remove' {
            break
        }
        'rc;help;bucket;event' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add or replace a bucket notification rule for an ARN')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket notification rules')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket notification rules by target ARN')
            break
        }
        'rc;help;bucket;event;add' {
            break
        }
        'rc;help;bucket;event;list' {
            break
        }
        'rc;help;bucket;event;remove' {
            break
        }
        'rc;help;bucket;cors' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket CORS rules')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Replace bucket CORS rules from a JSON or XML file')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket CORS rules')
            break
        }
        'rc;help;bucket;cors;list' {
            break
        }
        'rc;help;bucket;cors;set' {
            break
        }
        'rc;help;bucket;cors;remove' {
            break
        }
        'rc;help;bucket;encryption' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket default encryption')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket default encryption')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket default encryption')
            break
        }
        'rc;help;bucket;encryption;set' {
            break
        }
        'rc;help;bucket;encryption;info' {
            break
        }
        'rc;help;bucket;encryption;clear' {
            break
        }
        'rc;help;bucket;version' {
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable versioning for a bucket')
            [CompletionResult]::new('suspend', 'suspend', [CompletionResultType]::ParameterValue, 'Suspend versioning for a bucket')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get versioning status for a bucket')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List object versions')
            break
        }
        'rc;help;bucket;version;enable' {
            break
        }
        'rc;help;bucket;version;suspend' {
            break
        }
        'rc;help;bucket;version;info' {
            break
        }
        'rc;help;bucket;version;list' {
            break
        }
        'rc;help;bucket;lock' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket Object Lock and default retention configuration')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set a bucket default retention rule')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear the bucket default retention rule without disabling Object Lock')
            break
        }
        'rc;help;bucket;lock;info' {
            break
        }
        'rc;help;bucket;lock;set' {
            break
        }
        'rc;help;bucket;lock;clear' {
            break
        }
        'rc;help;bucket;quota' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket quota')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket quota information')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket quota')
            break
        }
        'rc;help;bucket;quota;set' {
            break
        }
        'rc;help;bucket;quota;info' {
            break
        }
        'rc;help;bucket;quota;clear' {
            break
        }
        'rc;help;bucket;anonymous' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set anonymous access permission')
            [CompletionResult]::new('set-json', 'set-json', [CompletionResultType]::ParameterValue, 'Set anonymous access from a policy JSON file')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get anonymous access permission')
            [CompletionResult]::new('get-json', 'get-json', [CompletionResultType]::ParameterValue, 'Get anonymous policy JSON')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List anonymous policies')
            [CompletionResult]::new('links', 'links', [CompletionResultType]::ParameterValue, 'List public links for anonymous readable prefixes')
            break
        }
        'rc;help;bucket;anonymous;set' {
            break
        }
        'rc;help;bucket;anonymous;set-json' {
            break
        }
        'rc;help;bucket;anonymous;get' {
            break
        }
        'rc;help;bucket;anonymous;get-json' {
            break
        }
        'rc;help;bucket;anonymous;list' {
            break
        }
        'rc;help;bucket;anonymous;links' {
            break
        }
        'rc;help;bucket;lifecycle' {
            [CompletionResult]::new('rule', 'rule', [CompletionResultType]::ParameterValue, 'Manage lifecycle rules on a bucket')
            [CompletionResult]::new('tier', 'tier', [CompletionResultType]::ParameterValue, 'Manage remote storage tiers')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Restore a transitioned (archived) object')
            break
        }
        'rc;help;bucket;lifecycle;rule' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            break
        }
        'rc;help;bucket;lifecycle;rule;add' {
            break
        }
        'rc;help;bucket;lifecycle;rule;edit' {
            break
        }
        'rc;help;bucket;lifecycle;rule;list' {
            break
        }
        'rc;help;bucket;lifecycle;rule;remove' {
            break
        }
        'rc;help;bucket;lifecycle;rule;export' {
            break
        }
        'rc;help;bucket;lifecycle;rule;import' {
            break
        }
        'rc;help;bucket;lifecycle;tier' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            break
        }
        'rc;help;bucket;lifecycle;tier;add' {
            break
        }
        'rc;help;bucket;lifecycle;tier;edit' {
            break
        }
        'rc;help;bucket;lifecycle;tier;list' {
            break
        }
        'rc;help;bucket;lifecycle;tier;info' {
            break
        }
        'rc;help;bucket;lifecycle;tier;remove' {
            break
        }
        'rc;help;bucket;lifecycle;restore' {
            break
        }
        'rc;help;bucket;replication' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new replication rule')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing replication rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List replication rules for a bucket')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show replication status/metrics for a bucket')
            [CompletionResult]::new('mrf', 'mrf', [CompletionResultType]::ParameterValue, 'Show aggregate replication MRF backlog for a bucket')
            [CompletionResult]::new('diff', 'diff', [CompletionResultType]::ParameterValue, 'Scan for object versions that have not replicated')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove replication rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export replication configuration as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import replication configuration from a JSON file')
            [CompletionResult]::new('check', 'check', [CompletionResultType]::ParameterValue, 'Actively validate configured replication targets')
            [CompletionResult]::new('resync', 'resync', [CompletionResultType]::ParameterValue, 'Manage bucket replication resync operations')
            break
        }
        'rc;help;bucket;replication;add' {
            break
        }
        'rc;help;bucket;replication;update' {
            break
        }
        'rc;help;bucket;replication;list' {
            break
        }
        'rc;help;bucket;replication;status' {
            break
        }
        'rc;help;bucket;replication;mrf' {
            break
        }
        'rc;help;bucket;replication;diff' {
            break
        }
        'rc;help;bucket;replication;remove' {
            break
        }
        'rc;help;bucket;replication;export' {
            break
        }
        'rc;help;bucket;replication;import' {
            break
        }
        'rc;help;bucket;replication;check' {
            break
        }
        'rc;help;bucket;replication;resync' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start resyncing previously replicated objects')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show persisted server-side resync status')
            break
        }
        'rc;help;bucket;replication;resync;start' {
            break
        }
        'rc;help;bucket;replication;resync;status' {
            break
        }
        'rc;help;object' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List objects within a bucket path')
            [CompletionResult]::new('copy', 'copy', [CompletionResultType]::ParameterValue, 'Copy objects between local and remote locations')
            [CompletionResult]::new('move', 'move', [CompletionResultType]::ParameterValue, 'Move objects between local and remote locations')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove objects')
            [CompletionResult]::new('stat', 'stat', [CompletionResultType]::ParameterValue, 'Show object metadata')
            [CompletionResult]::new('show', 'show', [CompletionResultType]::ParameterValue, 'Print the full object body')
            [CompletionResult]::new('head', 'head', [CompletionResultType]::ParameterValue, 'Print the first lines or bytes of an object')
            [CompletionResult]::new('find', 'find', [CompletionResultType]::ParameterValue, 'Search for objects by filters')
            [CompletionResult]::new('tree', 'tree', [CompletionResultType]::ParameterValue, 'Display objects in a tree view')
            [CompletionResult]::new('share', 'share', [CompletionResultType]::ParameterValue, 'Generate a presigned object URL')
            [CompletionResult]::new('retention', 'retention', [CompletionResultType]::ParameterValue, 'Manage object retention')
            [CompletionResult]::new('legalhold', 'legalhold', [CompletionResultType]::ParameterValue, 'Manage object legal hold')
            break
        }
        'rc;help;object;list' {
            break
        }
        'rc;help;object;copy' {
            break
        }
        'rc;help;object;move' {
            break
        }
        'rc;help;object;remove' {
            break
        }
        'rc;help;object;stat' {
            break
        }
        'rc;help;object;show' {
            break
        }
        'rc;help;object;head' {
            break
        }
        'rc;help;object;find' {
            break
        }
        'rc;help;object;tree' {
            break
        }
        'rc;help;object;share' {
            break
        }
        'rc;help;object;retention' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show retention for an object version or a bucket default')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set retention for an object version or a bucket default')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear retention for an object version or a bucket default')
            break
        }
        'rc;help;object;retention;info' {
            break
        }
        'rc;help;object;retention;set' {
            break
        }
        'rc;help;object;retention;clear' {
            break
        }
        'rc;help;object;legalhold' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show legal-hold status')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set legal hold to ON')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Set legal hold to OFF')
            break
        }
        'rc;help;object;legalhold;info' {
            break
        }
        'rc;help;object;legalhold;set' {
            break
        }
        'rc;help;object;legalhold;clear' {
            break
        }
        'rc;help;ls' {
            break
        }
        'rc;help;mb' {
            break
        }
        'rc;help;rb' {
            break
        }
        'rc;help;cat' {
            break
        }
        'rc;help;head' {
            break
        }
        'rc;help;stat' {
            break
        }
        'rc;help;cp' {
            break
        }
        'rc;help;get' {
            break
        }
        'rc;help;put' {
            break
        }
        'rc;help;mv' {
            break
        }
        'rc;help;rm' {
            break
        }
        'rc;help;undo' {
            break
        }
        'rc;help;pipe' {
            break
        }
        'rc;help;find' {
            break
        }
        'rc;help;event' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add or replace a bucket notification rule for an ARN')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket notification rules')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket notification rules by target ARN')
            break
        }
        'rc;help;event;add' {
            break
        }
        'rc;help;event;list' {
            break
        }
        'rc;help;event;remove' {
            break
        }
        'rc;help;cors' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket CORS rules')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Replace bucket CORS rules from a JSON or XML file')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket CORS rules')
            break
        }
        'rc;help;cors;list' {
            break
        }
        'rc;help;cors;set' {
            break
        }
        'rc;help;cors;remove' {
            break
        }
        'rc;help;diff' {
            break
        }
        'rc;help;mirror' {
            break
        }
        'rc;help;tree' {
            break
        }
        'rc;help;share' {
            break
        }
        'rc;help;sql' {
            break
        }
        'rc;help;version' {
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable versioning for a bucket')
            [CompletionResult]::new('suspend', 'suspend', [CompletionResultType]::ParameterValue, 'Suspend versioning for a bucket')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get versioning status for a bucket')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List object versions')
            break
        }
        'rc;help;version;enable' {
            break
        }
        'rc;help;version;suspend' {
            break
        }
        'rc;help;version;info' {
            break
        }
        'rc;help;version;list' {
            break
        }
        'rc;help;tag' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List tags for a bucket or object')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set tags for a bucket or object')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove all tags from a bucket or object')
            break
        }
        'rc;help;tag;list' {
            break
        }
        'rc;help;tag;set' {
            break
        }
        'rc;help;tag;remove' {
            break
        }
        'rc;help;anonymous' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set anonymous access permission')
            [CompletionResult]::new('set-json', 'set-json', [CompletionResultType]::ParameterValue, 'Set anonymous access from a policy JSON file')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get anonymous access permission')
            [CompletionResult]::new('get-json', 'get-json', [CompletionResultType]::ParameterValue, 'Get anonymous policy JSON')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List anonymous policies')
            [CompletionResult]::new('links', 'links', [CompletionResultType]::ParameterValue, 'List public links for anonymous readable prefixes')
            break
        }
        'rc;help;anonymous;set' {
            break
        }
        'rc;help;anonymous;set-json' {
            break
        }
        'rc;help;anonymous;get' {
            break
        }
        'rc;help;anonymous;get-json' {
            break
        }
        'rc;help;anonymous;list' {
            break
        }
        'rc;help;anonymous;links' {
            break
        }
        'rc;help;quota' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket quota')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket quota information')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket quota')
            break
        }
        'rc;help;quota;set' {
            break
        }
        'rc;help;quota;info' {
            break
        }
        'rc;help;quota;clear' {
            break
        }
        'rc;help;ilm' {
            [CompletionResult]::new('rule', 'rule', [CompletionResultType]::ParameterValue, 'Manage lifecycle rules on a bucket')
            [CompletionResult]::new('tier', 'tier', [CompletionResultType]::ParameterValue, 'Manage remote storage tiers')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Restore a transitioned (archived) object')
            break
        }
        'rc;help;ilm;rule' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            break
        }
        'rc;help;ilm;rule;add' {
            break
        }
        'rc;help;ilm;rule;edit' {
            break
        }
        'rc;help;ilm;rule;list' {
            break
        }
        'rc;help;ilm;rule;remove' {
            break
        }
        'rc;help;ilm;rule;export' {
            break
        }
        'rc;help;ilm;rule;import' {
            break
        }
        'rc;help;ilm;tier' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            break
        }
        'rc;help;ilm;tier;add' {
            break
        }
        'rc;help;ilm;tier;edit' {
            break
        }
        'rc;help;ilm;tier;list' {
            break
        }
        'rc;help;ilm;tier;info' {
            break
        }
        'rc;help;ilm;tier;remove' {
            break
        }
        'rc;help;ilm;restore' {
            break
        }
        'rc;help;replicate' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new replication rule')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing replication rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List replication rules for a bucket')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show replication status/metrics for a bucket')
            [CompletionResult]::new('mrf', 'mrf', [CompletionResultType]::ParameterValue, 'Show aggregate replication MRF backlog for a bucket')
            [CompletionResult]::new('diff', 'diff', [CompletionResultType]::ParameterValue, 'Scan for object versions that have not replicated')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove replication rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export replication configuration as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import replication configuration from a JSON file')
            [CompletionResult]::new('check', 'check', [CompletionResultType]::ParameterValue, 'Actively validate configured replication targets')
            [CompletionResult]::new('resync', 'resync', [CompletionResultType]::ParameterValue, 'Manage bucket replication resync operations')
            break
        }
        'rc;help;replicate;add' {
            break
        }
        'rc;help;replicate;update' {
            break
        }
        'rc;help;replicate;list' {
            break
        }
        'rc;help;replicate;status' {
            break
        }
        'rc;help;replicate;mrf' {
            break
        }
        'rc;help;replicate;diff' {
            break
        }
        'rc;help;replicate;remove' {
            break
        }
        'rc;help;replicate;export' {
            break
        }
        'rc;help;replicate;import' {
            break
        }
        'rc;help;replicate;check' {
            break
        }
        'rc;help;replicate;resync' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start resyncing previously replicated objects')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show persisted server-side resync status')
            break
        }
        'rc;help;replicate;resync;start' {
            break
        }
        'rc;help;replicate;resync;status' {
            break
        }
        'rc;help;retention' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show retention for an object version or a bucket default')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set retention for an object version or a bucket default')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear retention for an object version or a bucket default')
            break
        }
        'rc;help;retention;info' {
            break
        }
        'rc;help;retention;set' {
            break
        }
        'rc;help;retention;clear' {
            break
        }
        'rc;help;legalhold' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show legal-hold status')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set legal hold to ON')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Set legal hold to OFF')
            break
        }
        'rc;help;legalhold;info' {
            break
        }
        'rc;help;legalhold;set' {
            break
        }
        'rc;help;legalhold;clear' {
            break
        }
        'rc;help;completions' {
            break
        }
        'rc;help;du' {
            break
        }
        'rc;help;ping' {
            break
        }
        'rc;help;ready' {
            break
        }
        'rc;help;watch' {
            break
        }
        'rc;help;help' {
            break
        }
    })

    $completions.Where{ $_.CompletionText -like "$wordToComplete*" } |
        Sort-Object -Property ListItemText
}
